@@ -1,4 +1,3 @@
-# emacs: -*- coding: utf-8; mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 #
 # sampledoc documentation build configuration file, created by
@@ -12,17 +11,19 @@
 # All configuration values have a default value; values that are commented out
 # serve to show the default value.
 
-import sys, os
+import os
+import sys
 from importlib import import_module
 
 import sphinx
+import sphinx.ext.doctest
 
 # Doc generation depends on being able to import project
 project = 'nipy'
 try:
     project_module = import_module(project)
 except ImportError:
-    raise RuntimeError('Cannot import {}, please investigate'.format(project))
+    raise RuntimeError(f'Cannot import {project}, please investigate')
 
 # If your extensions are in another directory, add it here. If the directory
 # is relative to the documentation root, use os.path.abspath to make it
@@ -64,7 +65,7 @@ master_doc = 'index'
 
 # copyright = ':ref:`2005-2018, Neuroimaging in Python team.
 # <nipy-software-license>`'
-copyright = '2005-2021, Neuroimaging in Python team'
+copyright = '2005-2023, Neuroimaging in Python team'
 
 # The default replacements for |version| and |release|, also used in various
 # other places throughout the built documents.
