@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import print_function # Python 2/3 compatibility
 """
 Example of script to parcellate mutli-subject data.
 
@@ -10,16 +9,18 @@ May take some time to complete.
 Author: Bertrand Thirion, 2005-2009
 """
 
-from os import mkdir, getcwd, path
-
-from numpy import array
-
-from nipy.labs.spatial_models.parcel_io import parcel_input, \
-    write_parcellation_images, parcellation_based_analysis
-from nipy.labs.spatial_models.hierarchical_parcellation import hparcel
+from os import getcwd, mkdir, path
 
 # Local import
 from get_data_light import DATA_DIR, get_second_level_dataset
+from numpy import array
+
+from nipy.labs.spatial_models.hierarchical_parcellation import hparcel
+from nipy.labs.spatial_models.parcel_io import (
+    parcel_input,
+    parcellation_based_analysis,
+    write_parcellation_images,
+)
 
 # Get the data
 nb_subj = 12
@@ -64,6 +65,6 @@ test_images = [path.join(data_dir, 'spmT_%s_subj_%02d.nii' % (nbeta, n))
                for n in range(nb_subj)]
 
 # compute and write the parcel-based statistics
-rfx_path = path.join(write_dir, 'prfx_%s.nii' % nbeta)
+rfx_path = path.join(write_dir, f'prfx_{nbeta}.nii')
 parcellation_based_analysis(fpa, test_images, 'one_sample', rfx_path=rfx_path)
-print("Wrote everything in %s" % write_dir)
+print(f"Wrote everything in {write_dir}")
