@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import print_function
 __doc__ = """
 This examples performs sifferent kinds of (2D and 3D) plots
 of a given activation map.
@@ -19,12 +18,11 @@ try:
 except ImportError:
     raise RuntimeError("This script needs the matplotlib library")
 
-from nibabel import load
-
-from nipy.labs.viz import plot_map, cm
-
 # Local import
 from get_data_light import DATA_DIR, get_second_level_dataset
+from nibabel import load
+
+from nipy.labs.viz import cm, plot_map
 
 #######################################
 # Data and analysis parameters
@@ -35,10 +33,10 @@ if not path.exists(input_image):
     get_second_level_dataset()
 
 brain_map = load(input_image)
-vmin, vmax = brain_map.get_data().min(), brain_map.get_data().max()
+vmin, vmax = brain_map.get_fdata().min(), brain_map.get_fdata().max()
 
 # make a simple 2D plot
-plot_map(brain_map.get_data(), brain_map.get_affine(),
+plot_map(brain_map.get_fdata(), brain_map.affine,
          cmap=cm.cold_hot,
          vmin=vmin,
          vmax=vmax,
@@ -48,7 +46,7 @@ plot_map(brain_map.get_data(), brain_map.get_affine(),
 
 # More plots using 3D
 if True:  # replace with False to skip this
-    plot_map(brain_map.get_data(), brain_map.get_affine(),
+    plot_map(brain_map.get_fdata(), brain_map.affine,
              cmap=cm.cold_hot,
              vmin=vmin,
              vmax=vmax,
@@ -58,7 +56,7 @@ if True:  # replace with False to skip this
 
     from nipy.labs import viz3d
     try:
-        viz3d.plot_map_3d(brain_map.get_data(), brain_map.get_affine(),
+        viz3d.plot_map_3d(brain_map.get_fdata(), brain_map.affine,
                         cmap=cm.cold_hot,
                         vmin=vmin,
                         vmax=vmax,
