@@ -1,17 +1,15 @@
-# emacs: -*- coding: utf-8; mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
-# vi: set fileencoding=utf-8 ft=python sts=4 ts=4 sw=4 et:
-from __future__ import absolute_import
+""" Nipy
+
+Nipy is a library for neuroimaging analysis.
+"""
 
 import os
 
-from .info import (LONG_DESCRIPTION as __doc__,
-                   URL as __url__,
-                   STATUS as __status__,
-                   __version__)
-
-from nipy.testing import Tester
-test = Tester().test
-bench = Tester().bench
+# When updating here, also update meson.build file.
+# Form for development.
+# __version__ = "0.5.1.dev1"
+# Form for release.
+__version__ = "0.6.0"
 
 
 def _test_local_install():
@@ -29,19 +27,13 @@ _test_local_install()
 
 
 # Add to top-level namespace
-from nipy.io.api import load_image, save_image, as_image
 from nipy.core.api import is_image
+from nipy.io.api import as_image, load_image, save_image
 
 # Set up package information function
 from .pkg_info import get_pkg_info as _get_pkg_info
+
 get_info = lambda : _get_pkg_info(os.path.dirname(__file__))
 
 # Cleanup namespace
 del _test_local_install
-# If this file is exec after being imported, the following lines will
-# fail
-try:
-    del version
-    del Tester
-except:
-    pass
