@@ -5,7 +5,7 @@ Bayesian Gaussian Mixture Model Classes:
 contains the basic fields and methods of Bayesian GMMs
 the high level functions are/should be binded in C
 
-The base class BGMM relies on an implementation that perfoms Gibbs sampling
+The base class BGMM relies on an implementation that performs Gibbs sampling
 
 A derived class VBGMM uses Variational Bayes inference instead
 
@@ -14,17 +14,16 @@ but it is limited to diagonal covariance models
 
 Author : Bertrand Thirion, 2008-2011
 """
-from __future__ import print_function
-from __future__ import absolute_import
+
+import math
 
 import numpy as np
 import numpy.random as nr
-from scipy.linalg import inv, cholesky, eigvalsh
+from scipy.linalg import cholesky, eigvalsh, inv
 from scipy.special import gammaln
-import math
 
-from .utils import kmeans
 from .gmm import GMM
+from .utils import kmeans
 
 ##################################################################
 # ancillary functions ############################################
@@ -146,7 +145,7 @@ def wishart_eval(n, V, W, dV=None, dW=None, piV=None):
     ltr = - np.trace(np.dot(piV, W)) / 2
     la = (n * p * math.log(2) + math.log(dV) * n) / 2
     lg = math.log(math.pi) * p * (p - 1) / 4
-    lg += gammaln(np.arange(n - p + 1, n + 1).astype(np.float) / 2).sum()
+    lg += gammaln(np.arange(n - p + 1, n + 1).astype(np.float64) / 2).sum()
     lt = ldW + ltr - la - lg
     return math.exp(lt)
 
@@ -197,19 +196,19 @@ def generate_perm(k, nperm=100):
     """
     from scipy.special import gamma
     if k == 1:
-        return np.reshape(np.array([0]), (1, 1)).astype(np.int)
+        return np.reshape(np.array([0]), (1, 1)).astype(np.int_)
     if gamma(k + 1) < nperm:
         # exhaustive permutations
         aux = generate_perm(k - 1)
         n = aux.shape[0]
-        perm = np.zeros((n * k, k)).astype(np.int)
+        perm = np.zeros((n * k, k)).astype(np.int_)
         for i in range(k):
             perm[i * n:(i + 1) * n, :i] = aux[:, :i]
             perm[i * n:(i + 1) * n, i] = k-1
             perm[i * n:(i + 1) * n, i + 1:] = aux[:, i:]
     else:
         from numpy.random import rand
-        perm = np.zeros((nperm, k)).astype(np.int)
+        perm = np.zeros((nperm, k)).astype(np.int_)
         for i in range(nperm):
             p = np.argsort(rand(k))
             perm[i] = p
@@ -293,7 +292,7 @@ def dkl_wishart(a1, B1, a2, B2):
     -------
     dkl: float, the Kullback-Leibler divergence
     """
-    from scipy.special import psi, gammaln
+    from scipy.special import gammaln, psi
     tiny = 1.e-15
     if B1.shape != B2.shape:
         raise ValueError("incompatible dimensions for B1 and B2")
@@ -350,7 +349,7 @@ class BGMM(GMM):
     """
     This class implements Bayesian GMMs
 
-    this class contains the follwing fields
+    this class contains the following fields
     k: int,
        the number of components in the mixture
     dim: int,
@@ -358,7 +357,7 @@ class BGMM(GMM):
     means: array of shape (k, dim)
            all the means of the components
     precisions: array of shape (k, dim, dim)
-                the precisions of the componenets
+                the precisions of the components
     weights: array of shape (k):
              weights of the mixture
     shrinkage: array of shape (k):
@@ -488,7 +487,7 @@ class BGMM(GMM):
 
     def initialize(self, x):
         """
-        initialize z using a k-means algorithm, then upate the parameters
+        initialize z using a k-means algorithm, then update the parameters
 
         Parameters
         ----------
@@ -498,7 +497,7 @@ class BGMM(GMM):
         if self.k > 1:
             cent, z, J = kmeans(x, self.k)
         else:
-            z = np.zeros(x.shape[0]).astype(np.int)
+            z = np.zeros(x.shape[0]).astype(np.int_)
         self.update(x, z)
 
     def pop(self, z):
@@ -507,7 +506,7 @@ class BGMM(GMM):
 
         Parameters
         ----------
-        z array of shape (nb_samples), type = np.int
+        z array of shape (nb_samples), type = np.int_
           the allocation variable
 
         Returns
@@ -523,7 +522,7 @@ class BGMM(GMM):
 
         Parameters
         ----------
-        z array of shape (nb_samples), type = np.int
+        z array of shape (nb_samples), type = np.int_
           the allocation variable
         """
         pop = self.pop(z)
@@ -540,7 +539,7 @@ class BGMM(GMM):
         ----------
         x: array of shape (nb_samples,self.dim)
           the data used in the estimation process
-        z: array of shape (nb_samples), type = np.int
+        z: array of shape (nb_samples), type = np.int_
           the corresponding classification
         """
         pop = self.pop(z)
@@ -568,7 +567,7 @@ class BGMM(GMM):
         ----------
         x array of shape (nb_samples,self.dim)
           the data used in the estimation process
-        z array of shape (nb_samples), type = np.int
+        z array of shape (nb_samples), type = np.int_
           the corresponding classification
         """
         pop = self.pop(z)
@@ -604,7 +603,7 @@ class BGMM(GMM):
         ----------
         x array of shape (nb_samples,self.dim)
           the data used in the estimation process
-        z array of shape (nb_samples), type = np.int
+        z array of shape (nb_samples), type = np.int_
           the corresponding classification
         """
         self.update_weights(z)
@@ -653,7 +652,7 @@ class BGMM(GMM):
         """
         self.check_x(x)
         if mem:
-            possibleZ = - np.ones((x.shape[0], niter)).astype(np.int)
+            possibleZ = - np.ones((x.shape[0], niter)).astype(np.int_)
 
         score = - np.inf
         bpz = - np.inf
@@ -750,14 +749,14 @@ class BGMM(GMM):
         ----------
         x: array of shape (nb_samples, dim),
            the data from which bic is computed
-        z: array of shape (nb_samples), type = np.int,
+        z: array of shape (nb_samples), type = np.int_,
            the corresponding classification
-        perm: array ok shape(nperm, self.k),typ=np.int, optional
+        perm: array ok shape(nperm, self.k),typ=np.int_, optional
               all permutation of z under which things will be recomputed
               By default, no permutation is performed
         """
         pop = self.pop(z)
-        rpop = (pop + (pop == 0)).astype(np.float)
+        rpop = (pop + (pop == 0)).astype(np.float64)
         dof = self.prior_dof + pop + 1
         shrinkage = self.prior_shrinkage + pop
         weights = pop + self.prior_weights
@@ -824,7 +823,7 @@ class BGMM(GMM):
         ----------
         x: array of shape (nb_samples,dim)
            the data from which bic is computed
-        z: array of shape (nb_samples), type = np.int
+        z: array of shape (nb_samples), type = np.int_
            the corresponding classification
         nperm=0: int
             the number of permutations to sample
@@ -938,8 +937,8 @@ class VBGMM(BGMM):
         -------
         ev (float) the computed evidence
         """
-        from scipy.special import psi
         from numpy.linalg import inv
+        from scipy.special import psi
         tiny = 1.e-15
         if like is None:
             like = self._Estep(x)
@@ -1035,7 +1034,7 @@ class VBGMM(BGMM):
 
     def initialize(self, x):
         """
-        initialize z using a k-means algorithm, then upate the parameters
+        initialize z using a k-means algorithm, then update the parameters
 
         Parameters
         ----------
@@ -1046,7 +1045,7 @@ class VBGMM(BGMM):
         if self.k > 1:
             cent, z, J = kmeans(x, self.k)
         else:
-            z = np.zeros(x.shape[0]).astype(np.int)
+            z = np.zeros(x.shape[0]).astype(np.int_)
         l = np.zeros((n, self.k))
         l[np.arange(n), z] = 1
         self._Mstep(x, l)
