@@ -8,14 +8,12 @@ computationally and memory efficient.
 
 Author : Bertrand Thirion, 2006-2009
 """
-from __future__ import print_function
-from __future__ import absolute_import
 
 import numpy as np
 from scipy.linalg import eigvalsh
 
 
-class GridDescriptor(object):
+class GridDescriptor:
     """
     A tiny class to handle cartesian grids
     """
@@ -154,7 +152,7 @@ def plot2D(x, my_gmm, z=None, with_dots=True, log_scale=False, mpaxes=None,
     x: array of shape (npoints, dim=2),
         sample points
     my_gmm: GMM instance,
-            whose density has to be ploted
+            whose density has to be plotted
     z: array of shape (npoints), optional
        that gives a labelling of the points in x
        by default, it is not taken into account
@@ -209,10 +207,10 @@ def plot2D(x, my_gmm, z=None, with_dots=True, log_scale=False, mpaxes=None,
     Pdens = np.reshape(L, (gdx, -1))
     extent = [xm, xs, ym, ys]
     if log_scale:
-        plt.imshow(np.log(Pdens.T), alpha=2.0, origin='lower',
+        plt.imshow(np.log(Pdens.T), origin='lower',
                   extent=extent)
     else:
-        plt.imshow(Pdens.T, alpha=2.0, origin='lower', extent=extent)
+        plt.imshow(Pdens.T, origin='lower', extent=extent)
 
     if with_dots:
         if z is None:
@@ -228,7 +226,7 @@ def plot2D(x, my_gmm, z=None, with_dots=True, log_scale=False, mpaxes=None,
     return gd1, ax
 
 
-class GMM(object):
+class GMM:
     """Standard GMM.
 
     this class contains the following members
@@ -356,7 +354,7 @@ class GMM(object):
         """Initializes self according to a certain dataset x:
         1. sets the regularizing hyper-parameters
         2. initializes z using a k-means algorithm, then
-        3. upate the parameters
+        3. update the parameters
 
         Parameters
         ----------
@@ -373,7 +371,7 @@ class GMM(object):
         if self.k > 1:
             _, z, _ = kmeans(x, self.k)
         else:
-            z = np.zeros(n).astype(np.int)
+            z = np.zeros(n).astype(np.int_)
 
         l = np.zeros((n, self.k))
         l[np.arange(n), z] = 1
@@ -882,8 +880,7 @@ class GMM(object):
             axes = plt.figure()
 
         if gd.dim == 1:
-            from ..statistics.empirical_pvalue import \
-                smoothed_histogram_from_samples
+            from ..statistics.empirical_pvalue import smoothed_histogram_from_samples
             h, c = smoothed_histogram_from_samples(x, normalized=True)
             offset = (c.max() - c.min()) / (2 * c.size)
             grid = gd.make_grid()
