@@ -19,19 +19,17 @@ represents the number of wanted clusters)
 
 Author : Bertrand Thirion,Pamela Guevara, 2006-2009
 """
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
 
 #---------------------------------------------------------------------------
 # ------ Routines for Agglomerative Hierarchical Clustering ----------------
 # --------------------------------------------------------------------------
 
-import numpy as np
 from warnings import warn
 
-from ..graph.graph import WeightedGraph
+import numpy as np
+
 from ..graph.forest import Forest
+from ..graph.graph import WeightedGraph
 
 
 class WeightedForest(Forest):
@@ -134,7 +132,7 @@ class WeightedForest(Forest):
         -------
         ax, the axis handle
         """
-        import matplotlib.pylab as mp
+        import matplotlib.pyplot as plt
         if self.check_compatible_height() == False:
             raise ValueError('cannot plot myself in my current state')
 
@@ -159,13 +157,13 @@ class WeightedForest(Forest):
 
         # 3. plot
         if ax is None:
-            mp.figure()
-            ax = mp.subplot(1, 1, 1)
+            plt.figure()
+            ax = plt.subplot(1, 1, 1)
 
         for i in range(self.V):
             h1 = self.height[i]
             h2 = self.height[self.parents[i]]
-            mp.plot([idx[i], idx[i]], [h1, h2], 'k')
+            plt.plot([idx[i], idx[i]], [h1, h2], 'k')
 
         ch = self.get_children()
         for i in range(self.V):
@@ -174,11 +172,11 @@ class WeightedForest(Forest):
                 m = lidx.min()
                 M = lidx.max()
                 h = self.height[i]
-                mp.plot([m, M], [h, h], 'k')
+                plt.plot([m, M], [h, h], 'k')
 
         cM = 1.05 * self.height.max() - 0.05 * self.height.min()
         cm = 1.05 * self.height.min() - 0.05 * self.height.max()
-        mp.axis([-1, idx.max() + 1, cm, cM])
+        plt.axis([-1, idx.max() + 1, cm, cM])
         return ax
 
     def partition(self, threshold):
@@ -210,25 +208,25 @@ class WeightedForest(Forest):
     def plot_height(self):
         """Plot the height of the non-leaves nodes
         """
-        import matplotlib.pylab as mp
-        mp.figure()
+        import matplotlib.pyplot as plt
+        plt.figure()
         sh = np.sort(self.height[self.isleaf() == False])
         n = np.sum(self.isleaf() == False)
-        mp.bar(np.arange(n), sh)
+        plt.bar(np.arange(n), sh)
 
     def list_of_subtrees(self):
         """
         returns the list of all non-trivial subtrees in the graph
-        Caveat: theis function assumes that the vertices are sorted in a
-        way such that parent[i]>i forall i
+        Caveat: this function assumes that the vertices are sorted in a
+        way such that parent[i]>i for all i
         Only the leaves are listeed, not the subtrees themselves
         """
         lst = []
         n = np.sum(self.isleaf())
         for i in range(self.V):
-            lst.append(np.array([], np.int))
+            lst.append(np.array([], np.int_))
         for i in range(n):
-            lst[i] = np.array([i], np.int)
+            lst[i] = np.array([i], np.int_)
         for i in range(self.V - 1):
             j = self.parents[i]
             lst[j] = np.hstack((lst[i], lst[j]))
@@ -319,7 +317,7 @@ def average_link_graph(G):
     negated affinity values, in roder to respect the traditional
     ordering of cluster potentials. individual points have the
     potential (-np.inf).
-    This problem is handled transparently inthe associated segment functionp.
+    This problem is handled transparently in the associated segment function.
     """
     warn('Function average_link_graph deprecated, will be removed',
          FutureWarning,
@@ -332,8 +330,8 @@ def average_link_graph(G):
     K.edges = G.edges.copy()
     K.weights = G.weights.copy()
 
-    parent = np.arange(2 * n - nbcc, dtype=np.int)
-    pop = np.ones(2 * n - nbcc, np.int)
+    parent = np.arange(2 * n - nbcc, dtype=np.int_)
+    pop = np.ones(2 * n - nbcc, np.int_)
     height = np.inf * np.ones(2 * n - nbcc)
 
     # iteratively merge clusters
@@ -401,8 +399,8 @@ def average_link_graph_segment(G, stop=0, qmax=1, verbose=False):
     if verbose:
         t.plot()
 
-    u1 = np.zeros(n, np.int)
-    u2 = np.zeros(n, np.int)
+    u1 = np.zeros(n, np.int_)
+    u2 = np.zeros(n, np.int_)
     if stop >= 0:
         u1 = t.partition( - stop)
     if qmax > 0:
@@ -453,7 +451,7 @@ def _inertia(i, j, Features):
 def _initial_inertia(K, Features, seeds=None):
     """ Compute the variance associated with each
     edge-related pair of vertices
-    Thre sult is written in K;weights
+    The result is written in K;weights
     if seeds if provided (seeds!=None)
     this is done only for vertices adjacent to the seeds
     """
@@ -486,7 +484,7 @@ def _auxiliary_graph(G, Features):
     K.edges = G.edges.copy()
     K.weights = np.ones(K.E)
     K.symmeterize()
-    if K.E > 0:    
+    if K.E > 0:
         valid = K.edges[:, 0] < K.edges[:, 1]
         K.remove_edges(valid)
     #
@@ -514,7 +512,7 @@ def _remap(K, i, j, k, Features, linc, rinc):
     # -------
     # replace i by k
     # --------
-    idxi = np.array(linc[i]).astype(np.int)
+    idxi = np.array(linc[i]).astype(np.int_)
     if np.size(idxi) > 1:
         for l in idxi:
             K.weights[l] = _inertia(k, K.edges[l, 1], Features)
@@ -523,7 +521,7 @@ def _remap(K, i, j, k, Features, linc, rinc):
     if np.size(idxi) > 0:
         K.edges[idxi, 0] = k
 
-    idxi = np.array(rinc[i]).astype(np.int)
+    idxi = np.array(rinc[i]).astype(np.int_)
     if np.size(idxi) > 1:
         for l in idxi:
             K.weights[l] = _inertia(K.edges[l, 0], k, Features)
@@ -535,7 +533,7 @@ def _remap(K, i, j, k, Features, linc, rinc):
     #------
     # replace j by k
     #-------
-    idxj = np.array(linc[j]).astype(np.int)
+    idxj = np.array(linc[j]).astype(np.int_)
     if np.size(idxj) > 1:
         for l in idxj:
             K.weights[l] = _inertia(k, K.edges[l, 1], Features)
@@ -544,7 +542,7 @@ def _remap(K, i, j, k, Features, linc, rinc):
     if np.size(idxj) > 0:
         K.edges[idxj, 0] = k
 
-    idxj = np.array(rinc[j]).astype(np.int)
+    idxj = np.array(rinc[j]).astype(np.int_)
     if np.size(idxj) > 1:
         for l in idxj:
             K.weights[l] = _inertia(k, K.edges[l, 0], Features)
@@ -577,7 +575,7 @@ def _remap(K, i, j, k, Features, linc, rinc):
     #remove double edges
     #------
     #left side
-    idxk = np.array(linc[k]).astype(np.int)
+    idxk = np.array(linc[k]).astype(np.int_)
     if np.size(idxk) > 0:
         corr = K.edges[idxk, 1]
         scorr = np.sort(corr)
@@ -591,7 +589,7 @@ def _remap(K, i, j, k, Features, linc, rinc):
                 linc[k].remove(i2)
 
     #right side
-    idxk = np.array(rinc[k]).astype(np.int)
+    idxk = np.array(rinc[k]).astype(np.int_)
     if np.size(idxk) > 0:
         corr = K.edges[idxk, 0]
         scorr = np.sort(corr)
@@ -632,8 +630,8 @@ def ward_quick(G, feature, verbose=False):
 
     Caveat : only approximate
     """
-    warn('Function ward_quick from ' + 
-         'nipy.algorithms.clustering.hierrachical_clustering ' + 
+    warn('Function ward_quick from ' +
+         'nipy.algorithms.clustering.hierrachical_clustering ' +
          'deprecated, will be removed',
          FutureWarning,
          stacklevel=2)
@@ -655,7 +653,7 @@ def ward_quick(G, feature, verbose=False):
 
     # prepare a graph with twice the number of vertices
     K = _auxiliary_graph(G, Features)
-    parent = np.arange(2 * n - nbcc).astype(np.int)
+    parent = np.arange(2 * n - nbcc).astype(np.int_)
     height = np.zeros(2 * n - nbcc)
     linc = K.left_incidence()
     rinc = K.right_incidence()
@@ -798,8 +796,8 @@ def ward_quick_segment(G, feature, stop=-1, qmax=1, verbose=False):
     if verbose:
         t.plot()
 
-    u1 = np.zeros(n, np.int)
-    u2 = np.zeros(n, np.int)
+    u1 = np.zeros(n, np.int_)
+    u2 = np.zeros(n, np.int_)
     if stop >= 0:
         u1 = t.partition(stop)
     if qmax > 0:
@@ -865,8 +863,8 @@ def ward_segment(G, feature, stop=-1, qmax=1, verbose=False):
     qmax = int(np.minimum(qmax, n - 1))
 
     t = ward(G, feature, verbose)
-    u1 = np.zeros(n, np.int)
-    u2 = np.zeros(n, np.int)
+    u1 = np.zeros(n, np.int_)
+    u2 = np.zeros(n, np.int_)
     if stop >= 0:
         u1 = t.partition(stop)
     if qmax > 0:
@@ -906,8 +904,8 @@ def ward(G, feature, verbose=False):
     When G has more than 1 connected component, t is no longer a tree.  This
     case is handled cleanly now
     """
-    warn('Function ward from ' + 
-         'nipy.algorithms.clustering.hierrachical_clustering ' + 
+    warn('Function ward from ' +
+         'nipy.algorithms.clustering.hierrachical_clustering ' +
          'deprecated, will be removed',
          FutureWarning,
          stacklevel=2)
@@ -933,7 +931,7 @@ def ward(G, feature, verbose=False):
     K = _auxiliary_graph(G, Features)
 
     # prepare some variables that are useful tp speed up the algorithm
-    parent = np.arange(2 * n - nbcc).astype(np.int)
+    parent = np.arange(2 * n - nbcc).astype(np.int_)
     height = np.zeros(2 * n - nbcc)
     linc = K.left_incidence()
     rinc = K.right_incidence()
