@@ -2,18 +2,15 @@
 Infinite mixture model : A generalization of Bayesian mixture models
 with an unspecified number of classes
 """
-from __future__ import print_function
-from __future__ import absolute_import
-from __future__ import division
 
 import math
 
 import numpy as np
-
 from scipy.special import gammaln
 
 from .bgmm import BGMM, detsh
 
+
 def co_labelling(z, kmax=None, kmin=None):
     """
     return a sparse co-labelling matrix given the label vector z
@@ -54,8 +51,8 @@ def co_labelling(z, kmax=None, kmin=None):
 class IMM(BGMM):
     """
     The class implements Infinite Gaussian Mixture model
-    or Dirichlet Proces Mixture Model.
-    This simply a generalization of Bayesian Gaussian Mixture Models
+    or Dirichlet Process Mixture model.
+    This is simply a generalization of Bayesian Gaussian Mixture Models
     with an unknown number of classes.
     """
 
@@ -236,7 +233,7 @@ class IMM(BGMM):
 
         if np.isscalar(kfold):
             aux = np.argsort(np.random.rand(n_samples))
-            idx = - np.ones(n_samples).astype(np.int)
+            idx = - np.ones(n_samples).astype(np.int_)
             j = int(math.ceil(n_samples / kfold))
             kmax = kfold
             for k in range(kmax):
@@ -246,7 +243,7 @@ class IMM(BGMM):
                 raise ValueError('kfold and x do not have the same size')
             uk = np.unique(kfold)
             np.random.shuffle(uk)
-            idx = np.zeros(n_samples).astype(np.int)
+            idx = np.zeros(n_samples).astype(np.int_)
             for i, k in enumerate(uk):
                 idx += (i * (kfold == k))
             kmax = uk.max() + 1
@@ -297,7 +294,7 @@ class IMM(BGMM):
         ----------
         x array of shape (n_samples,self.dim)
           the data used in the estimation process
-        z array of shape (n_samples), type = np.int
+        z array of shape (n_samples), type = np.int_
           the corresponding classification
         """
         # re-dimension the priors in order to match self.k
@@ -320,7 +317,7 @@ class IMM(BGMM):
 
         Parameters
         ----------
-        z array of shape (n_samples), type = np.int
+        z array of shape (n_samples), type = np.int_
           the allocation variable
         """
         pop = np.hstack((self.pop(z), 0))
@@ -392,12 +389,12 @@ class IMM(BGMM):
         ----------
         x: array of shape (n_samples, self.dim),
            the data used in the estimation process
-        plike: array os shape (n_samples), optional,x
-               the desnity of each point under the prior
+        plike: array of shape (n_samples), optional,
+               the density of each point under the prior
 
         Returns
         -------
-        like, array of shape(nbitem,self.k)
+        like, array of shape (nbitem, self.k)
         component-wise likelihood
         """
         if plike is None:
@@ -601,7 +598,7 @@ class MixedIMM(IMM):
 
         if np.isscalar(kfold):
             aux = np.argsort(np.random.rand(n_samples))
-            idx = - np.ones(n_samples).astype(np.int)
+            idx = - np.ones(n_samples).astype(np.int_)
             j = int(math.ceil(n_samples / kfold))
             kmax = kfold
             for k in range(kmax):
@@ -611,7 +608,7 @@ class MixedIMM(IMM):
                 raise ValueError('kfold and x do not have the same size')
             uk = np.unique(kfold)
             np.random.shuffle(uk)
-            idx = np.zeros(n_samples).astype(np.int)
+            idx = np.zeros(n_samples).astype(np.int_)
             for i, k in enumerate(uk):
                 idx += (i * (kfold == k))
             kmax = uk.max() + 1
