@@ -1,21 +1,20 @@
 """
 Implementation of Von-Mises-Fisher Mixture models,
-i.e. the equaivalent of mixture of Gaussian on the sphere.
+i.e. the equivalent of mixture of Gaussian on the sphere.
 
 Author: Bertrand Thirion, 2010-2011
 """
-from __future__ import print_function
-from __future__ import absolute_import
 
-import numpy as np
 from warnings import warn
 
-warn('Module nipy.algorithms.clustering.von_mises_fisher_mixture' + 
+import numpy as np
+
+warn('Module nipy.algorithms.clustering.von_mises_fisher_mixture' +
      'deprecated, will be removed',
      FutureWarning,
      stacklevel=2)
 
-class VonMisesMixture(object):
+class VonMisesMixture:
     """
     Model for Von Mises mixture distribution with fixed variance
     on a two-dimensional sphere
@@ -56,7 +55,7 @@ class VonMisesMixture(object):
 
         Parameters
         ----------
-        x: array fo shape(n,3)
+        x: array of shape(n,3)
            should be on the unit sphere
 
         Returns
@@ -80,7 +79,7 @@ class VonMisesMixture(object):
 
         Parameters
         ----------
-        x: array fo shape(n,3)
+        x: array of shape(n,3)
            should be on the unit sphere
 
         Returns
@@ -110,7 +109,7 @@ class VonMisesMixture(object):
 
         Parameters
         ----------
-        x: array fo shape(n,3)
+        x: array of shape(n,3)
            should be on the unit sphere
 
         Returns
@@ -124,7 +123,7 @@ class VonMisesMixture(object):
 
         Parameters
         ----------
-        x: array fo shape(n,3)
+        x: array of shape(n,3)
            should be on the unit sphere
 
         Returns
@@ -139,7 +138,7 @@ class VonMisesMixture(object):
 
         Parameters
         ----------
-        x: array fo shape(n,3)
+        x: array of shape(n,3)
            should be on the unit sphere
 
         Returns
@@ -166,7 +165,7 @@ class VonMisesMixture(object):
 
         Parameters
         ----------
-        x: array fo shape(n,3)
+        x: array of shape(n,3)
            should be on the unit sphere
         z: array of shape(self.k)
         """
@@ -243,9 +242,9 @@ class VonMisesMixture(object):
         """
         # label the data
         z = np.argmax(self.responsibilities(x), 1)
-        import pylab
+        import matplotlib.pyplot as plt
         import mpl_toolkits.mplot3d.axes3d as p3
-        fig = pylab.figure()
+        fig = plt.figure()
         ax = p3.Axes3D(fig)
         colors = (['b', 'g', 'r', 'c', 'm', 'y', 'k', 'w'] * \
                       (1 + (1 + self.k) // 8))[:self.k + 1]
@@ -268,7 +267,7 @@ class VonMisesMixture(object):
                               color=colors[k])
                 ax.plot3D([self.means[k, 0]], [self.means[k, 1]],
                       [self.means[k, 2]], 'o', color=colors[k])
-        pylab.show()
+        plt.show()
 
 
 def estimate_robust_vmm(k, precision, null_class, x, ninit=10, bias=None,
@@ -281,7 +280,7 @@ def estimate_robust_vmm(k, precision, null_class, x, ninit=10, bias=None,
     precision: float, priori precision parameter
     null class: bool, optional,
                 should a null class be included or not
-    x: array fo shape(n,3)
+    x: array of shape(n,3)
        input data, should be on the unit sphere
     ninit: int, optional,
            number of iterations
@@ -310,7 +309,7 @@ def select_vmm(krange, precision, null_class, x, ninit=10, bias=None,
             number of classes to consider
     precision:
     null class:
-    x: array fo shape(n,3)
+    x: array of shape(n,3)
        should be on the unit sphere
     ninit: int, optional,
            number of iterations
@@ -346,7 +345,7 @@ def select_vmm_cv(krange, precision, x, null_class, cv_index,
             number of classes to consider
     precision: float,
                precision parameter of the von-mises densities
-    x: array fo shape(n, 3)
+    x: array of shape(n, 3)
        should be on the unit sphere
     null class: bool, whether a null class should be included or not
     cv_index: set of indices for cross validation
@@ -360,7 +359,7 @@ def select_vmm_cv(krange, precision, x, null_class, cv_index,
     for k in krange:
         mll.append( - np.inf)
         for j in range(1):
-            ll = np.zeros_like(cv_index).astype(np.float)
+            ll = np.zeros_like(cv_index).astype(np.float64)
             for i in np.unique(cv_index):
                 xl = x[cv_index != i]
                 xt = x[cv_index == i]
