@@ -1,15 +1,13 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 ''' Diagnostic 4d image screen '''
-from __future__ import absolute_import
-from os.path import join as pjoin
-
 import warnings
+from os.path import join as pjoin
 
 import numpy as np
 
 from ...core.api import Image, drop_io_dim
-from ...core.reference.coordinate_map import input_axis_index, AxisError
+from ...core.reference.coordinate_map import AxisError, input_axis_index
 from ...io.api import save_image
 from ..utils import pca
 from .timediff import time_slice_diffs
@@ -62,7 +60,7 @@ def screen(img4d, ncomp=10, time_axis='t', slice_axis=None):
     '''
     if img4d.ndim != 4:
         raise ValueError('Expecting a 4d image')
-    data = img4d.get_data()
+    data = img4d.get_fdata()
     cmap = img4d.coordmap
     # Get numerical index for time axis in data array
     time_axis = input_axis_index(cmap, time_axis)
@@ -131,16 +129,14 @@ def write_screen_res(res, out_path, out_root,
     import matplotlib.pyplot as plt
     # save volume images
     for key in ('mean', 'min', 'max', 'std', 'pca'):
-        fname = pjoin(out_path, '%s_%s%s' % (key,
-                                             out_root,
-                                             out_img_ext))
+        fname = pjoin(out_path, f'{key}_{out_root}{out_img_ext}')
         save_image(res[key], fname)
     # plot, save component time courses and some tsdiffana stuff
     pca_axis = res['pca_res']['axis']
     n_comp = res['pca_res']['basis_projections'].shape[pca_axis]
     vectors = res['pca_res']['basis_vectors']
     pcnt_var = res['pca_res']['pcnt_var']
-    np.savez(pjoin(out_path, 'vectors_components_%s.npz' % out_root),
+    np.savez(pjoin(out_path, f'vectors_components_{out_root}.npz'),
              basis_vectors=vectors,
              pcnt_var=pcnt_var,
              volume_means=res['ts_res']['volume_means'],
@@ -152,16 +148,16 @@ def write_screen_res(res, out_path, out_root,
         plt.plot(vectors[:,c])
         plt.axis('tight')
     plt.suptitle(out_root + ': PCA basis vectors')
-    plt.savefig(pjoin(out_path, 'components_%s.png' % out_root))
+    plt.savefig(pjoin(out_path, f'components_{out_root}.png'))
     # plot percent variance
     plt.figure()
     plt.plot(pcnt_var[pcnt_var >= pcnt_var_thresh])
     plt.axis('tight')
     plt.suptitle(out_root + ': PCA percent variance')
-    plt.savefig(pjoin(out_path, 'pcnt_var_%s.png' % out_root))    
+    plt.savefig(pjoin(out_path, f'pcnt_var_{out_root}.png'))
     # plot tsdiffana
     plt.figure()
     axes = [plt.subplot(4, 1, i+1) for i in range(4)]
     plot_tsdiffs(res['ts_res'], axes)
     plt.suptitle(out_root + ': tsdiffana')
-    plt.savefig(pjoin(out_path, 'tsdiff_%s.png' % out_root))
+    plt.savefig(pjoin(out_path, f'tsdiff_{out_root}.png'))
