@@ -13,9 +13,8 @@ based on a 4d Image:
 
     fastFHWM: used if the entire 4d Image is available
     iterFWHM: used when 4d Image is being filled in by slices of residuals
-    
+
 """
-from __future__ import absolute_import
 
 __docformat__ = 'restructuredtext'
 
@@ -26,9 +25,8 @@ from nipy.core.api import Image
 
 from .utils.matrices import pos_recipr
 
-from ..externals.six import Iterator
 
-class Resels(Iterator):
+class Resels:
     """The Resels class.
     """
     def __init__(self, coordmap, normalized=False, fwhm=None, resels=None,
@@ -204,7 +202,7 @@ def _calc_detlam(xx, yy, zz, yx, zx, zy):
      [yx,yy,zy],
      [zx,zy,zz]]
      """
-    
+
     return zz * (yy*xx - yx**2) - \
            zy * (zy*xx - zx*yx) + \
            zx * (zy*yx - zx*yy)
