@@ -2,9 +2,9 @@
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
 This module implements the Field class, which simply a WeightedGraph
-(see the graph.py) module, plus an arrray that yields (possibly
+(see the graph.py) module, plus an array that yields (possibly
 multi-dimnesional) features associated with graph vertices. This
-allows some kinds of computations (all thoses relating to mathematical
+allows some kinds of computations (all those relating to mathematical
 morphology, diffusion etc.)
 
 Certain functions are provided to Instantiate Fields easily, given a
@@ -12,13 +12,12 @@ WeightedGraph and feature data.
 
 Author:Bertrand Thirion, 2006--2011
 """
-from __future__ import print_function
-from __future__ import absolute_import
 
 from warnings import warn
+
 import numpy as np
 
-from .graph import WeightedGraph, Graph
+from .graph import Graph, WeightedGraph
 
 NEGINF = -np.inf
 
@@ -83,7 +82,7 @@ class Field(WeightedGraph):
         ----------
         V (int > 0) the number of vertices of the graph
         edges=None: the edge array of the graph
-        weights=None: the asociated weights array
+        weights=None: the associated weights array
         field=None: the field data itself
         """
         V = int(V)
@@ -128,7 +127,7 @@ class Field(WeightedGraph):
             self.field = field
 
     def closing(self, nbiter=1):
-        """Morphological closing of the field data. 
+        """Morphological closing of the field data.
         self.field is changed inplace
 
         Parameters
@@ -192,7 +191,7 @@ class Field(WeightedGraph):
 
         Returns
         -------
-        hneighb: array of shape(self.V), 
+        hneighb: array of shape(self.V),
                  index of the neighbor with highest value
         """
         from scipy.sparse import dia_matrix
@@ -205,7 +204,7 @@ class Field(WeightedGraph):
         return hneighb
 
     def erosion(self, nbiter=1):
-        """Morphological openeing of the field
+        """Morphological opening of the field
 
         Parameters
         ----------
@@ -265,7 +264,7 @@ class Field(WeightedGraph):
             raise ValueError('No field has been defined so far')
         if self.field.shape[1] - 1 < refdim:
             raise ValueError(refdim > self.shape[1])
-        depth = np.zeros(self.V, np.int)
+        depth = np.zeros(self.V, np.int_)
 
         # create a subfield(thresholding)
         sf = self.subfield(self.field.T[refdim] >= th)
@@ -273,7 +272,7 @@ class Field(WeightedGraph):
         sf.field = initial_field.astype(np.float64)
 
         # compute the depth in the subgraph
-        ldepth = sf.V * np.ones(sf.V, np.int)
+        ldepth = sf.V * np.ones(sf.V, np.int_)
         for k in range(sf.V):
             dilated_field_old = sf.field.ravel().copy()
             sf.dilation(1)
@@ -321,14 +320,14 @@ class Field(WeightedGraph):
         label : array of shape (self.V)
               labelling of the vertices according to their bassin
         """
-        import numpy.ma as ma
+        from numpy import ma
 
         if (np.size(self.field) == 0):
             raise ValueError('No field has been defined so far')
         if self.field.shape[1] - 1 < refdim:
             raise ValueError('refdim>field.shape[1]')
 
-        label = - np.ones(self.V, np.int)
+        label = - np.ones(self.V, np.int_)
 
         # create a subfield(thresholding)
         sf = self.subfield(self.field[:, refdim] >= th)
@@ -374,13 +373,13 @@ class Field(WeightedGraph):
         label: array of shape (self.V)
                a labelling of thevertices according to their bassin
         """
-        import numpy.ma as ma
+        from numpy import ma
         if (np.size(self.field) == 0):
             raise ValueError('No field has been defined so far')
         if self.field.shape[1] - 1 < refdim:
             raise ValueError('refdim>field.shape[1]')
 
-        label = - np.ones(self.V, np.int)
+        label = - np.ones(self.V, np.int_)
 
         # create a subfield(thresholding)
         sf = self.subfield(self.field[:, refdim] >= th)
@@ -390,7 +389,7 @@ class Field(WeightedGraph):
         # explore the subfield
         order = np.argsort(- initial_field)
         rows = sf.to_coo_matrix().tolil().rows
-        llabel = - np.ones(sf.V, np.int)
+        llabel = - np.ones(sf.V, np.int_)
         parent, root =  np.arange(2 * self.V), np.arange(2 * self.V)
         # q will denote the region index
         q = 0
@@ -441,7 +440,7 @@ class Field(WeightedGraph):
         """
         if np.size(self.field) == 0:
             raise ValueError('No field has been defined so far')
-        seed = seed.astype(np.int)
+        seed = seed.astype(np.int_)
         weights = np.sqrt(np.sum((self.field[self.edges.T[0]] -
                                   self.field[self.edges.T[1]]) ** 2, 1))
         g = WeightedGraph(self.V, self.edges, weights)
@@ -487,7 +486,7 @@ class Field(WeightedGraph):
             k = label.max() + 1
             if np.size(np.unique(label)) != k:
                 raise ValueError('missing values, cannot proceed')
-            seeds = np.zeros(k).astype(np.int)
+            seeds = np.zeros(k).astype(np.int_)
             for  j in range(k):
                 lj = np.nonzero(label == j)[0]
                 cent = np.mean(self.field[lj], 0)
@@ -531,8 +530,7 @@ class Field(WeightedGraph):
                the resulting field label
         J (float): the resulting inertia
         """
-        from nipy.algorithms.clustering.hierarchical_clustering\
-             import ward_segment
+        from nipy.algorithms.clustering.hierarchical_clustering import ward_segment
         label, J = ward_segment(self, self.field, qmax=nbcluster)
 
         # compute the resulting inertia
