@@ -20,13 +20,12 @@ instantiate WeightedGraphs from data:
 
 Author: Bertrand Thirion, 2006--2011
 """
-from __future__ import absolute_import
 
 import numpy as np
-
 from scipy.sparse import coo_matrix
 
-class Graph(object):
+
+class Graph:
     """ Basic topological (non-weighted) directed Graph class
 
     Member variables:
@@ -219,7 +218,7 @@ class Graph(object):
         -------
         ax, axis handle
         """
-        import matplotlib.pylab as plt
+        import matplotlib.pyplot as plt
 
         if ax is None:
             plt.figure()
@@ -292,15 +291,15 @@ def mst(X):
     the corresponding WeightedGraph instance
     """
     n = X.shape[0]
-    label = np.arange(n).astype(np.int)
+    label = np.arange(n).astype(np.int_)
 
-    edges = np.zeros((0, 2)).astype(np.int)
+    edges = np.zeros((0, 2)).astype(np.int_)
     # upper bound on maxdist**2
     maxdist = 4 * np.sum((X - X[0]) ** 2, 1).max()
     nbcc = n
     while nbcc > 1:
         mindist = maxdist * np.ones(nbcc)
-        link = - np.ones((nbcc, 2)).astype(np.int)
+        link = - np.ones((nbcc, 2)).astype(np.int_)
 
         # find nearest neighbors
         for n1 in range(n):
@@ -412,7 +411,7 @@ def eps_nn(X, eps=1.):
 
 
 def lil_cc(lil):
-    """ Returns the connected comonents of a graph represented as a
+    """ Returns the connected components of a graph represented as a
     list of lists
 
     Parameters
@@ -428,8 +427,8 @@ def lil_cc(lil):
     Dramatically slow for non-sparse graphs
     """
     n = len(lil)
-    visited = np.zeros(n).astype(np.int)
-    label = - np.ones(n).astype(np.int)
+    visited = np.zeros(n).astype(np.int_)
+    label = - np.ones(n).astype(np.int_)
     k = 0
     while (visited == 0).any():
         front = [np.argmin(visited)]
@@ -501,7 +500,7 @@ def graph_3d_grid(xyz, k=18):
         i, j, d = create_edges(lxyz, n18, 2, i, j, d)
     if k == 26:
         i, j, d = create_edges(lxyz, n26, 3, i, j, d)
-    i, j = i.astype(np.int), j.astype(np.int)
+    i, j = i.astype(np.int_), j.astype(np.int_)
 
     # reorder the edges to have a more standard order
     order = np.argsort(i + j * (len(i) + 1))
@@ -516,7 +515,7 @@ def wgraph_from_3d_grid(xyz, k=18):
 
     Parameters
     ----------
-    xyz: array of shape (nsamples, 3) and type np.int,
+    xyz: array of shape (nsamples, 3) and type np.int_,
     k = 18: the number of neighbours considered. (6, 18 or 26)
 
     Returns
@@ -585,7 +584,7 @@ class WeightedGraph(Graph):
         edges : (E, 2) array, type int
             edges of the graph
         weights : (E, 2) array, type=int
-            weights/lenghts of the edges
+            weights/lengths of the edges
         """
         Graph.__init__(self, V, edges=edges)
 
@@ -618,7 +617,7 @@ class WeightedGraph(Graph):
 
         Parameters
         ----------
-        xyz: array of shape (self.V, 3) and type np.int,
+        xyz: array of shape (self.V, 3) and type np.int_,
         k = 18: the number of neighbours considered. (6, 18 or 26)
 
         Returns
@@ -638,7 +637,7 @@ class WeightedGraph(Graph):
             raise TypeError('Creating graph from grid failed. '\
                 'Maybe the grid is too big')
         self.E = np.size(i)
-        self.edges = np.zeros((self.E, 2), np.int)
+        self.edges = np.zeros((self.E, 2), np.int_)
         self.edges[:, 0] = i
         self.edges[:, 1] = j
         self.weights = np.array(d)
@@ -646,7 +645,7 @@ class WeightedGraph(Graph):
 
     def cut_redundancies(self):
         """ Returns a graph with redundant edges removed:
-        ecah edge (ab) is present ony once in the edge matrix:
+        ecah edge (ab) is present only once in the edge matrix:
         the correspondng weights are added.
 
         Returns
@@ -699,7 +698,7 @@ x
                 break
             dwin, win = node
             active[win] = False
-            # the folllowing loop might be vectorized
+            # the following loop might be vectorized
             l = neighb[idx[win]: idx[win + 1]]
             newdist = dwin + weight[idx[win]: idx[win + 1]]
             who = newdist < dist[l]
@@ -714,16 +713,16 @@ x
         Returns
         -------
         idx: array of of shape(self.V + 1):
-             the positions where to find the neighors of each node
+             the positions where to find the neighbors of each node
              within neighb and weights
         neighb: array of shape(self.E), concatenated list of neighbors
         weights: array of shape(self.E), concatenated list of weights
         """
         order = np.argsort(self.edges[:, 0] * float(self.V) + self.edges[:, 1])
-        neighb = self.edges[order, 1].astype(np.int)
+        neighb = self.edges[order, 1].astype(np.int_)
         weights = self.weights[order]
         degree, _ = self.degrees()
-        idx = np.hstack((0, np.cumsum(degree))).astype(np.int)
+        idx = np.hstack((0, np.cumsum(degree))).astype(np.int_)
         return idx, neighb, weights
 
     def floyd(self, seed=None):
@@ -731,7 +730,7 @@ x
 
         Parameters
         ----------
-        seed= None: array of shape (nbseed), type np.int
+        seed= None: array of shape (nbseed), type np.int_
              vertex indexes from which the distances are computed
              if seed==None, then every edge is a seed point
 
@@ -775,7 +774,7 @@ x
         """
         from scipy.sparse import dia_matrix
         c = int(c)
-        if not c in [0, 1, 2]:
+        if c not in [0, 1, 2]:
             raise ValueError('c must be equal to 0, 1 or 2')
 
         if self.E == 0:
@@ -808,7 +807,7 @@ x
     def set_euclidian(self, X):
         """
         Compute the weights of the graph as the distances between the
-        corresponding rows of X, which represents an embdedding of self
+        corresponding rows of X, which represents an embedding of self
 
         Parameters
         ----------
@@ -827,7 +826,7 @@ x
         """
         Compute the weights  of the graph as a gaussian function
         of the distance  between the corresponding rows of X,
-        which represents an embdedding of self
+        which represents an embedding of self
 
         Parameters
         ----------
@@ -881,7 +880,7 @@ x
 
         Parameters
         ----------
-        seed: array of shape (nseeds), type (np.int),
+        seed: array of shape (nseeds), type (np.int_),
               vertices from which the cells are built
 
         Returns
@@ -897,7 +896,7 @@ x
         except:
             raise ValueError('undefined weights')
         dist, active = np.inf * np.ones(self.V), np.ones(self.V)
-        label = - np.ones(self.V, np.int)
+        label = - np.ones(self.V, np.int_)
         idx, neighb, weight = self.compact_neighb()
         dist[seed] = 0
         label[seed] = np.arange(len(seed))
@@ -916,7 +915,7 @@ x
                 break
             dwin, win = node
             active[win] = False
-            # the folllowing loop might be vectorized
+            # the following loop might be vectorized
             for i in range(idx[win], idx[win + 1]):
                 l, newdist = neighb[i], dwin + weight[i]
                 if  newdist < dist[l]:
@@ -931,7 +930,7 @@ x
 
         Returns
         -------
-        cliques: array of shape (self.V), type (np.int)
+        cliques: array of shape (self.V), type (np.int_)
           labelling of the vertices according to the clique they belong to
         """
         if (self.weights < 0).any():
@@ -986,7 +985,7 @@ x
 
     def subgraph(self, valid):
         """ Creates a subgraph with the vertices for which valid>0
-        and with the correponding set of edges
+        and with the corresponding set of edges
 
         Parameters
         ----------
@@ -1035,7 +1034,7 @@ x
         k = self.cc().max() + 1
         E = 2 * self.V - 2
         V = self.V
-        Kedges = np.zeros((E, 2)).astype(np.int)
+        Kedges = np.zeros((E, 2)).astype(np.int_)
         Kweights = np.zeros(E)
         iw = np.argsort(self.weights)
         label = np.arange(V)
@@ -1124,10 +1123,10 @@ x
             return Graph.show()
 
         wm = self.weights.max()
-        import matplotlib.pylab as mp
+        import matplotlib.pyplot as plt
         if ax is None:
-            mp.figure()
-            ax = mp.subplot(1, 1, 1)
+            plt.figure()
+            ax = plt.subplot(1, 1, 1)
 
         ml = 5.
         if (X is None):
@@ -1135,11 +1134,11 @@ x
                 A = (self.edges[e, 0] * 2 * np.pi) / self.V
                 B = (self.edges[e, 1] * 2 * np.pi) / self.V
                 C = max(1, int(self.weights[e] * ml / wm))
-                mp.plot([np.cos(A), np.cos(B)], [np.sin(A), np.sin(B)], 'k',
+                plt.plot([np.cos(A), np.cos(B)], [np.sin(A), np.sin(B)], 'k',
                         linewidth=C)
                 t = (2 * np.pi * np.arange(self.V)) / self.V
-            mp.plot(np.cos(t), np.sin(t), 'o', linewidth=ml)
-            mp.axis([-1.1, 1.1, -1.1, 1.1])
+            plt.plot(np.cos(t), np.sin(t), 'o', linewidth=ml)
+            plt.axis([-1.1, 1.1, -1.1, 1.1])
             return ax
 
         if (X.shape[0] != self.V):
@@ -1153,11 +1152,11 @@ x
                 A = x[self.edges[e, 0]]
                 B = x[self.edges[e, 1]]
                 C = max(1, int(self.weights[e] * ml / wm))
-                mp.plot([np.cos(A), np.cos(B)], [np.sin(A), np.sin(B)],
+                plt.plot([np.cos(A), np.cos(B)], [np.sin(A), np.sin(B)],
                          'k', linewidth=C)
 
-            mp.plot(np.cos(x), np.sin(x), 'o', linewidth=ml)
-            mp.axis([-1.1, 1.1, -0.1, 1.1])
+            plt.plot(np.cos(x), np.sin(x), 'o', linewidth=ml)
+            plt.axis([-1.1, 1.1, -0.1, 1.1])
 
         if X.shape[1] > 2:
             Y = X.copy()
@@ -1173,17 +1172,17 @@ x
                 A = self.edges[e, 0]
                 B = self.edges[e, 1]
                 C = max(1, int(self.weights[e] * ml / wm))
-                mp.plot([Y[A, 0], Y[B, 0]], [Y[A, 1], Y[B, 1]], 'k',
+                plt.plot([Y[A, 0], Y[B, 0]], [Y[A, 1], Y[B, 1]], 'k',
                         linewidth=C)
 
-            mp.plot(Y[:, 0], Y[:, 1], 'o', linewidth=ml)
+            plt.plot(Y[:, 0], Y[:, 1], 'o', linewidth=ml)
             xmin, xmax = Y[:, 0].min(), Y[:, 0].max()
             ymin, ymax = Y[:, 1].min(), Y[:, 1].max()
             xmin = 1.1 * xmin - 0.1 * xmax
             xmax = 1.1 * xmax - 0.1 * xmin
             ymin = 1.1 * ymin - 0.1 * ymax
             ymax = 1.1 * ymax - 0.1 * ymin
-            mp.axis([xmin, xmax, ymin, ymax])
+            plt.axis([xmin, xmax, ymin, ymax])
 
         return ax
 
