@@ -1,26 +1,21 @@
-from __future__ import absolute_import
 import numpy as np
 import numpy.random as nr
-
-from ..field import (field_from_coo_matrix_and_data,
-                     field_from_graph_and_data)
-from ..graph import wgraph_from_3d_grid
-
-from nose.tools import assert_true, assert_equal
-
 from numpy.testing import assert_array_equal
 
+from ..field import field_from_coo_matrix_and_data, field_from_graph_and_data
+from ..graph import wgraph_from_3d_grid
+
 
 def basic_field(nx=10, ny=10, nz=10):
     xyz = np.reshape(np.indices((nx, ny, nz)), (3, nx * ny * nz)).T
-    data = np.sum(xyz, 1).astype(np.float)
+    data = np.sum(xyz, 1).astype(np.float64)
     myfield = field_from_graph_and_data(wgraph_from_3d_grid(xyz, 26), data)
     return myfield
 
 
 def basic_field_random(nx=10, ny=10, nz=1):
     xyz = np.reshape(np.indices((nx, ny, nz)), (3, nx * ny * nz)).T
-    data = 0.5 * nr.randn(nx * ny * nz, 1) + np.sum(xyz, 1).astype(np.float)
+    data = 0.5 * nr.randn(nx * ny * nz, 1) + np.sum(xyz, 1).astype(np.float64)
     myfield = field_from_graph_and_data(wgraph_from_3d_grid(xyz, 26), data)
     return myfield
 
@@ -59,17 +54,17 @@ def test_max_1():
     myfield  = basic_field()
     myfield.field[555] = 30
     depth = myfield.local_maxima()
-    dep = np.zeros(1000, np.int)
+    dep = np.zeros(1000, np.int_)
     dep[555] = 5
     dep[999] = 3
-    assert_true(sum(np.absolute(dep-depth)) < 1.e-7)
+    assert sum(np.absolute(dep-depth)) < 1.e-7
 
 
 def test_max_2():
     myfield  = basic_field()
     myfield.field[555] = 28
     idx, depth = myfield.get_local_maxima()
-    assert_true(len(idx) == 2)
+    assert len(idx) == 2
     assert_array_equal(idx, np.array([555, 999]))
     assert_array_equal(depth, np.array([5, 3]))
 
@@ -78,20 +73,20 @@ def test_max_3():
     myfield  = basic_field()
     myfield.field[555] = 27
     idx, depth = myfield.get_local_maxima()
-    assert_equal(np.size(idx), 2)
-    assert_equal(idx[0], 555)
-    assert_equal(idx[1], 999)
-    assert_equal(depth[0], 5)
-    assert_equal(depth[1], 5)
+    assert np.size(idx) == 2
+    assert idx[0] == 555
+    assert idx[1] == 999
+    assert depth[0] == 5
+    assert depth[1] == 5
 
 
 def test_max_4():
     myfield  = basic_field()
     myfield.field[555] = 28
     idx, depth = myfield.get_local_maxima(0, 27.5)
-    assert_equal(np.size(idx), 1)
-    assert_equal(idx[0], 555)
-    assert_equal(depth[0], 1)
+    assert np.size(idx) == 1
+    assert idx[0] == 555
+    assert depth[0] == 1
 
 
 def test_smooth_1():
@@ -101,10 +96,10 @@ def test_smooth_1():
     G.set_field(field)
     G.diffusion()
     sfield = G.get_field()
-    assert_equal(sfield[555], 0)
-    assert_equal(sfield[554], 1)
-    assert_true(np.abs(sfield[566] - np.sqrt(2)) < 1.e-7)
-    assert_true(np.abs(sfield[446] - np.sqrt(3)) < 1.e-7)
+    assert sfield[555] == 0
+    assert sfield[554] == 1
+    assert np.abs(sfield[566] - np.sqrt(2)) < 1.e-7
+    assert np.abs(sfield[446] - np.sqrt(3)) < 1.e-7
 
 
 def test_smooth_2():
@@ -114,21 +109,21 @@ def test_smooth_2():
     G.set_field(field)
     G.diffusion(1)
     sfield = G.get_field()
-    assert_equal(sfield[555], 0)
-    assert_equal(sfield[554], 1)
-    assert_true(np.abs(sfield[566] - np.sqrt(2)) < 1.e-7)
-    assert_true(np.abs(sfield[446] - np.sqrt(3)) < 1.e-7)
-    
+    assert sfield[555] == 0
+    assert sfield[554] == 1
+    assert np.abs(sfield[566] - np.sqrt(2)) < 1.e-7
+    assert np.abs(sfield[446] - np.sqrt(3)) < 1.e-7
+
 
 def test_dilation():
     myfield  = basic_field()
     myfield.field[555] = 30
     myfield.field[664] = 0
     myfield.dilation(2)
-    assert_true(myfield.field[737] == 30)
-    assert_true(myfield.field[0] == 6)
-    assert_true(myfield.field[999] == 27)
-    assert_true(myfield.field[664] == 30)
+    assert myfield.field[737] == 30
+    assert myfield.field[0] == 6
+    assert myfield.field[999] == 27
+    assert myfield.field[664] == 30
 
 
 def test_dilation2():
@@ -149,10 +144,10 @@ def test_erosion():
     myfield.field[664] = 0
     myfield.erosion(2)
     field = myfield.get_field()
-    assert_true(field[737] == 11)
-    assert_true(field[0] == 0)
-    assert_true(field[999] == 21)
-    assert_true(field[664] == 0)
+    assert field[737] == 11
+    assert field[0] == 0
+    assert field[999] == 21
+    assert field[664] == 0
 
 
 def test_opening():
@@ -161,10 +156,10 @@ def test_opening():
     myfield.field[664] = 0
     myfield.opening(2)
     field = myfield.get_field()
-    assert_true(field[737] == 17)
-    assert_true(field[0] == 0)
-    assert_true(field[999] == 21)
-    assert_true(field[555] == 16)
+    assert field[737] == 17
+    assert field[0] == 0
+    assert field[999] == 21
+    assert field[555] == 16
 
 
 def test_closing():
@@ -173,10 +168,10 @@ def test_closing():
     myfield.field[664] = 0
     myfield.closing(2)
     field = myfield.get_field()
-    assert_true(field[737] == 17)
-    assert_true(field[0] == 6)
-    assert_true(field[999] == 27)
-    assert_true(field[555] == 30)
+    assert field[737] == 17
+    assert field[0] == 6
+    assert field[999] == 27
+    assert field[555] == 30
 
 
 def test_watershed_1():
@@ -184,26 +179,26 @@ def test_watershed_1():
     myfield.field[555] = 28
     myfield.field[664] = 0
     idx, label = myfield.custom_watershed()
-    assert_equal(np.size(idx), 2)
-    assert_equal(tuple(idx), (555, 999))
-    assert_equal((label[776], label[666], label[123]), (1, 0, 0))
+    assert np.size(idx) == 2
+    assert tuple(idx) == (555, 999)
+    assert (label[776], label[666], label[123]) == (1, 0, 0)
 
 
 def test_watershed_4():
     myfield = basic_field_3()
     idx, label = myfield.custom_watershed()
-    assert_true(np.size(idx) == 9)
-    assert_true(np.unique(
+    assert np.size(idx) == 9
+    assert np.unique(
             [label[555], label[0], label[9], label[90], label[99], label[900],
-             label[909], label[990], label[999]]).size == 9)
+             label[909], label[990], label[999]]).size == 9
+
 
-    
 def test_watershed_2():
     myfield = basic_field_2()
     myfield.field[555] = 10
     myfield.field[664] = 0
     idx, label = myfield.custom_watershed()
-    assert_true(np.size(idx) == 9)
+    assert np.size(idx) == 9
 
 
 def test_watershed_3():
@@ -211,20 +206,20 @@ def test_watershed_3():
     myfield.field[555] = 10
     myfield.field[664] = 0
     idx, label = myfield.custom_watershed(0,11)
-    assert_true(np.size(idx)==8)
+    assert np.size(idx)==8
 
 
 def test_bifurcations_1():
     myfield = basic_field()
     idx, parent,label = myfield.threshold_bifurcations()
-    assert_true(idx == 999)
-    assert_true(parent == 0)
+    assert idx == 999
+    assert parent == 0
 
 
 def test_bifurcations_2():
     myfield = basic_field_2()
     idx, parent, label = myfield.threshold_bifurcations()
-    assert_true(np.size(idx) == 15)
+    assert np.size(idx) == 15
 
 
 
@@ -234,8 +229,8 @@ def test_geodesic_kmeans(nbseeds=3):
     seeds = np.argsort(nr.rand(myfield.V))[:nbseeds]
     seeds, label, inertia = myfield.geodesic_kmeans(seeds)
     assert_array_equal(label[seeds], np.arange(nbseeds))
-    assert_true(np.array([i in np.unique(label)
-                          for i in np.arange(nbseeds)]).all())
+    assert np.array([i in np.unique(label)
+                          for i in np.arange(nbseeds)]).all()
 
 
 def test_constrained_voronoi(nbseeds=3):
@@ -244,15 +239,15 @@ def test_constrained_voronoi(nbseeds=3):
     seeds = np.argsort(nr.rand(myfield.V))[:nbseeds]
     label = myfield.constrained_voronoi(seeds)
     assert_array_equal(label[seeds], np.arange(nbseeds))
-    assert_true(np.array([i in np.unique(label)
-                          for i in np.arange(nbseeds)]).all())
+    assert np.array([i in np.unique(label)
+                          for i in np.arange(nbseeds)]).all()
 
 
 def test_constrained_voronoi_2(nbseeds=3):
     # Test the geodisc k-means algorithm
     xyz, x = np.zeros((30, 3)), np.arange(30)
     xyz[:, 0] = x
-    y = np.array((x // 10), np.float)
+    y = np.array((x // 10), np.float64)
     myfield = field_from_graph_and_data(wgraph_from_3d_grid(xyz, 6),  y)
     seeds = np.array([1, 18, 25])
     label = myfield.constrained_voronoi(seeds)
@@ -263,27 +258,27 @@ def test_subfield():
     myfield = basic_field_random()
     valid = nr.rand(myfield.V) > 0.1
     sf = myfield.subfield(valid)
-    assert_equal(sf.V, np.sum(valid))
+    assert sf.V == np.sum(valid)
 
 
 def test_subfield2():
     myfield = basic_field_random()
     valid = np.zeros(myfield.V)
     sf = myfield.subfield(valid)
-    assert_true(sf is None)
+    assert sf is None
 
 
 def test_ward1():
     myfield = basic_field_random()
     lab, J = myfield.ward(10)
-    assert_equal(lab.max(), 9)
+    assert lab.max() == 9
 
 
 def test_ward2():
     myfield = basic_field_random()
     Lab, J1 = myfield.ward(5)
     Lab, J2 = myfield.ward(10)
-    assert_true(J1 > J2)
+    assert J1 > J2
 
 
 def test_field_from_coo_matrix():
@@ -291,9 +286,4 @@ def test_field_from_coo_matrix():
     V = 10
     a = np.random.rand(V, V) > .9
     fi = field_from_coo_matrix_and_data(sps.coo_matrix(a), a)
-    assert_equal(fi.E, a.sum())
-
-
-if __name__ == '__main__':
-    import nose
-    nose.run(argv=['', __file__])
+    assert fi.E == a.sum()
