@@ -3,19 +3,19 @@
 """
 Linear filter(s).  For the moment, only a Gaussian smoothing filter
 """
-from __future__ import absolute_import
 
 import gc
 
 import numpy as np
-import numpy.fft as fft
 import numpy.linalg as npl
+from numpy import fft
 
-from nipy.utils import seq_prod
-from nipy.core.api import Image, AffineTransform
+from nipy.core.api import AffineTransform, Image
 from nipy.core.reference.coordinate_map import product
+from nipy.utils import seq_prod
 
-class LinearFilter(object):
+
+class LinearFilter:
     '''
     A class to implement some FFT smoothers for Image objects.
     By default, this does a Gaussian kernel smooth. More choices
@@ -76,7 +76,7 @@ class LinearFilter(object):
             * 2 + 2).astype(np.intp)
         self.fkernel = np.zeros(self.shape)
         slices = [slice(0, kernel.shape[i]) for i in range(len(kernel.shape))]
-        self.fkernel[slices] = kernel
+        self.fkernel[tuple(slices)] = kernel
         self.fkernel = fft.rfftn(self.fkernel)
         return kernel
 
@@ -155,7 +155,7 @@ class LinearFilter(object):
             nslice = 1
         else:
             raise NotImplementedError('expecting either 3 or 4-d image')
-        in_data = inimage.get_data()
+        in_data = inimage.get_fdata()
         for _slice in range(nslice):
             if in_data.ndim == 4:
                 data = in_data[_slice]
@@ -174,16 +174,18 @@ class LinearFilter(object):
             if self.location != 0.0:
                 data += self.location
             gc.collect()
-            # Write out data 
+            # Write out data
             if in_data.ndim == 4:
                 _out[_slice] = data
             else:
                 _out = data
             _slice += 1
         gc.collect()
-        _out = _out[[slice(self._kernel.shape[i] // 2,
-                           self.bshape[i] + self._kernel.shape[i] // 2)
-                     for i in range(len(self.bshape))]]
+        slicer = tuple(
+            slice(self._kernel.shape[i] // 2,
+                  self.bshape[i] + self._kernel.shape[i] // 2)
+            for i in range(len(self.bshape)))
+        _out = _out[slicer]
         if inimage.ndim == 3:
             return Image(_out, coordmap=self.coordmap)
         else:
@@ -194,7 +196,7 @@ class LinearFilter(object):
     def _presmooth(self, indata):
         slices = [slice(0, self.bshape[i], 1) for i in range(len(self.shape))]
         _buffer = np.zeros(self.shape)
-        _buffer[slices] = indata
+        _buffer[tuple(slices)] = indata
         return fft.rfftn(_buffer)
 
 
@@ -258,7 +260,6 @@ def _crop(X, tol=1.0e-10):
         m = [I[i].min() for i in range(n)]
         M = [I[i].max() for i in range(n)]
         slices = [slice(m[i], M[i]+1, 1) for i in range(n)]
-        return X[slices]
+        return X[tuple(slices)]
     else:
         return np.zeros((1,)*n)
-
