@@ -11,31 +11,21 @@ Roche, Alexis (2011) A four-dimensional registration algorithm with application
 to joint correction of motion and slice timing in fMRI. *Medical Imaging, IEEE
 Transactions on*;  30:1546--1554
 """
-from __future__ import absolute_import
-from __future__ import print_function
 
 import os
 import warnings
 
 import numpy as np
-
-from ...externals.six import string_types
-
+from nibabel import io_orientation
 from nibabel.affines import apply_affine
 
-from ...fixes.nibabel import io_orientation
+from ...core.image.image_spaces import as_xyz_image, make_xyz_image, xyz_affine
 from ...io.nibcompat import get_header
-from ...core.image.image_spaces import (make_xyz_image,
-                                        xyz_affine,
-                                        as_xyz_image)
 from ..slicetiming import timefuncs
-from .affine import Rigid, Affine
+from ._registration import _cspline_sample3d, _cspline_sample4d, _cspline_transform
+from .affine import Affine, Rigid
 from .optimizer import configure_optimizer, use_derivatives
-from .type_check import (check_type, check_type_and_shape)
-from ._registration import (_cspline_transform,
-                            _cspline_sample3d,
-                            _cspline_sample4d)
-
+from .type_check import check_type, check_type_and_shape
 
 VERBOSE = os.environ.get('NIPY_DEBUG_PRINT', False)
 INTERLEAVED = None
@@ -116,7 +106,7 @@ def tr_from_header(images):
             raise ValueError('TR inconsistent between images.')
     return images_tr
 
-class Image4d(object):
+class Image4d:
     """
     Class to represent a sequence of 3d scans (possibly acquired on a
     slice-by-slice basis).
@@ -156,7 +146,7 @@ class Image4d(object):
         self._shape = self._data.shape
         self._init_timing_parameters()
 
-    def get_data(self):
+    def get_fdata(self):
         if self._data is None:
             self._load_data()
         return self._data
@@ -214,7 +204,7 @@ class Image4d(object):
 
 
 
-class Realign4dAlgorithm(object):
+class Realign4dAlgorithm:
 
     def __init__(self,
                  im4d,
@@ -267,12 +257,12 @@ class Realign4dAlgorithm(object):
         if time_interp:
             self.timestamps = im4d.tr * np.arange(self.nscans)
             self.scanner_time = im4d.scanner_time
-            self.cbspline = _cspline_transform(im4d.get_data())
+            self.cbspline = _cspline_transform(im4d.get_fdata())
         else:
             self.cbspline = np.zeros(self.dims, dtype='double')
             for t in range(self.dims[3]):
                 self.cbspline[:, :, :, t] =\
-                    _cspline_transform(im4d.get_data()[:, :, :, t])
+                    _cspline_transform(im4d.get_fdata()[:, :, :, t])
 
         # The reference scan conventionally defines the head
         # coordinate system
@@ -560,12 +550,12 @@ def single_run_realign4d(im4d,
     speedup : int or sequence
       If a sequence, implement a multi-scale realignment
     """
-    if not type(loops) in (list, tuple, np.array):
+    if type(loops) not in (list, tuple, np.array):
         loops = [loops]
     repeats = len(loops)
 
     def format_arg(x):
-        if not type(x) in (list, tuple, np.array):
+        if type(x) not in (list, tuple, np.array):
             x = [x for i in range(repeats)]
         else:
             if not len(x) == repeats:
@@ -648,7 +638,7 @@ def realign4d(runs,
     """
 
     # Single-session case
-    if not type(runs) in (list, tuple, np.array):
+    if type(runs) not in (list, tuple, np.array):
         runs = [runs]
     nruns = len(runs)
     if nruns == 1:
@@ -719,7 +709,7 @@ def realign4d(runs,
     return ctransforms, transforms, transfo_mean
 
 
-class Realign4d(object):
+class Realign4d:
 
     def __init__(self, images, tr, slice_times=None, slice_info=None,
                  affine_class=Rigid):
@@ -777,10 +767,10 @@ class Realign4d(object):
         self._runs = []
         # Note that, the affine of each run may be different. This is
         # the case, for instance, if the subject exits the scanner
-        # inbetween sessions.
+        # in between sessions.
         for im in images:
             xyz_img = as_xyz_image(im)
-            self._runs.append(Image4d(xyz_img.get_data,
+            self._runs.append(Image4d(xyz_img.get_fdata,
                                       xyz_affine(xyz_img),
                                       tr,
                                       slice_times=slice_times,
@@ -984,7 +974,7 @@ class SpaceTimeRealign(Realign4d):
             n_slices = images[0].shape[slice_axis]
         else:
             n_slices = images.shape[slice_axis]
-        if isinstance(slice_times, string_types):
+        if isinstance(slice_times, str):
             slice_times = timefuncs.SLICETIME_FUNCTIONS[slice_times]
         if hasattr(slice_times, '__call__'):
             slice_times = slice_times(n_slices, tr)
