@@ -14,7 +14,7 @@ int ngb6 [] = {1,0,0,
 	       0,1,0,
 	       0,-1,0,
 	       0,0,1,
-	       0,0,-1}; 
+	       0,0,-1};
 
 int ngb26 [] = {1,0,0,
 		-1,0,0,
@@ -23,36 +23,36 @@ int ngb26 [] = {1,0,0,
 		1,1,0,
 		-1,-1,0,
 		1,-1,0,
-		-1,1,0, 
+		-1,1,0,
 		1,0,1,
 		-1,0,1,
 		0,1,1,
-		0,-1,1, 
+		0,-1,1,
 		1,1,1,
 		-1,-1,1,
 		1,-1,1,
-		-1,1,1, 
+		-1,1,1,
 		1,0,-1,
 		-1,0,-1,
 		0,1,-1,
-		0,-1,-1, 
+		0,-1,-1,
 		1,1,-1,
 		-1,-1,-1,
 		1,-1,-1,
-		-1,1,-1, 
+		-1,1,-1,
 		0,0,1,
-		0,0,-1}; 
+		0,0,-1};
 
 
 
 static int* _select_neighborhood_system(int ngb_size) {
   if (ngb_size == 6)
     return ngb6;
-  else if (ngb_size == 26) 
+  else if (ngb_size == 26)
     return ngb26;
   else {
     fprintf(stderr, "Unknown neighborhood system\n");
-    return NULL; 
+    return NULL;
   }
 }
 
@@ -65,7 +65,7 @@ static int* _select_neighborhood_system(int ngb_size) {
   Compute exp[-2 * beta * SUM_j (U * qj)] for a given voxel, where the
   sum is on the neighbors.
 
-  ppm assumed C-contiguous double (X, Y, Z, K) 
+  ppm assumed C-contiguous double (X, Y, Z, K)
   ref assumed C-contiguous double (NPTS, K)
   XYZ assumed C-contiguous npy_intp (NPTS, 3)
 */
@@ -77,35 +77,35 @@ particular voxel */
 static void _ngb_integrate(double* res,
 			   const PyArrayObject* ppm,
 			   npy_intp x,
-			   npy_intp y, 
+			   npy_intp y,
 			   npy_intp z,
-			   const double* U, 
+			   const double* U,
 			   const int* ngb,
 			   npy_intp ngb_size)
 {
   npy_intp xn, yn, zn, pos, ngb_idx, k, kk;
   const int* buf_ngb;
-  const double* ppm_data = (double*)ppm->data; 
+  const double* ppm_data = (double*)PyArray_DATA(ppm);
   double *buf, *buf_ppm, *q, *buf_U;
-  npy_intp K = ppm->dimensions[3]; 
-  npy_intp u2 = ppm->dimensions[2]*K; 
-  npy_intp u1 = ppm->dimensions[1]*u2;
-  npy_intp posmax = ppm->dimensions[0]*u1 - K;
+  npy_intp K = PyArray_DIMS(ppm)[3];
+  npy_intp u2 = PyArray_DIMS(ppm)[2]*K;
+  npy_intp u1 = PyArray_DIMS(ppm)[1]*u2;
+  npy_intp posmax = PyArray_DIMS(ppm)[0]*u1 - K;
 
   /*  Re-initialize output array */
   memset((void*)res, 0, K*sizeof(double));
 
   /* Loop over neighbors */
-  buf_ngb = ngb; 
+  buf_ngb = ngb;
   for (ngb_idx=0; ngb_idx<ngb_size; ngb_idx++) {
-    xn = x + *buf_ngb; buf_ngb++; 
+    xn = x + *buf_ngb; buf_ngb++;
     yn = y + *buf_ngb; buf_ngb++;
     zn = z + *buf_ngb; buf_ngb++;
     pos = xn*u1 + yn*u2 + zn*K;
 
     /* Ignore neighbor if outside the grid boundaries */
     if ((pos < 0) || (pos > posmax))
-      continue; 
+      continue;
 
     /* Compute U*q */
     buf_ppm = (double*)ppm_data + pos;
@@ -114,13 +114,13 @@ static void _ngb_integrate(double* res,
 	*buf += *buf_U * *q;
   }
 
-  return; 
+  return;
 }
 
 
-void ve_step(PyArrayObject* ppm, 
+void ve_step(PyArrayObject* ppm,
 	     const PyArrayObject* ref,
-	     const PyArrayObject* XYZ, 
+	     const PyArrayObject* XYZ,
 	     const PyArrayObject* U,
 	     int ngb_size,
 	     double beta)
@@ -128,14 +128,14 @@ void ve_step(PyArrayObject* ppm,
 {
   npy_intp k, x, y, z, pos;
   double *p, *buf, *ppm_data;
-  double psum, tmp;  
+  double psum, tmp;
   PyArrayIterObject* iter;
-  int axis = 1; 
-  npy_intp K = ppm->dimensions[3]; 
-  npy_intp u2 = ppm->dimensions[2]*K; 
-  npy_intp u1 = ppm->dimensions[1]*u2;
-  const double* ref_data = (double*)ref->data;
-  const double* U_data = (double*)U->data;
+  int axis = 1;
+  npy_intp K = PyArray_DIMS(ppm)[3];
+  npy_intp u2 = PyArray_DIMS(ppm)[2]*K;
+  npy_intp u1 = PyArray_DIMS(ppm)[1]*u2;
+  const double* ref_data = (double*)PyArray_DATA(ref);
+  const double* U_data = (double*)PyArray_DATA(U);
   npy_intp* xyz;
   int* ngb;
 
@@ -143,12 +143,12 @@ void ve_step(PyArrayObject* ppm,
   ngb = _select_neighborhood_system(ngb_size);
 
   /* Pointer to the data array */
-  ppm_data = (double*)ppm->data;
-  
-  /* Allocate auxiliary vectors */
-  p = (double*)calloc(K, sizeof(double)); 
+  ppm_data = (double*)PyArray_DATA(ppm);
 
-  /* Loop over points */ 
+  /* Allocate auxiliary vectors */
+  p = (double*)calloc(K, sizeof(double));
+
+  /* Loop over points */
   iter = (PyArrayIterObject*)PyArray_IterAllButAxis((PyObject*)XYZ, &axis);
 
   while(iter->index < iter->size) {
@@ -168,30 +168,30 @@ void ve_step(PyArrayObject* ppm,
       psum += tmp;
       *buf = tmp;
     }
-    
+
     /* Normalize to unitary sum */
-    pos = x*u1 + y*u2 + z*K; 
-    if (psum > TINY) 
+    pos = x*u1 + y*u2 + z*K;
+    if (psum > TINY)
       for (k=0, buf=p; k<K; k++, pos++, buf++)
-	ppm_data[pos] = *buf/psum; 
+	ppm_data[pos] = *buf/psum;
     else
       for (k=0, buf=p; k<K; k++, pos++, buf++)
-	ppm_data[pos] = (*buf+TINY/(double)K)/(psum+TINY); 
+	ppm_data[pos] = (*buf+TINY/(double)K)/(psum+TINY);
+
+    /* Update iterator */
+    PyArray_ITER_NEXT(iter);
 
-    /* Update iterator */ 
-    PyArray_ITER_NEXT(iter); 
-  
   }
 
-  /* Free memory */ 
+  /* Free memory */
   free(p);
   Py_XDECREF(iter);
 
-  return; 
+  return;
 }
 
 
-/* 
+/*
    Given an array of indices representing points in a regular 3d grid,
    compute the list of index pairs corresponding to connected points
    according to a given neighborhood system.
@@ -209,11 +209,11 @@ PyArrayObject* make_edges(const PyArrayObject* idx,
 {
   int* ngb = _select_neighborhood_system(ngb_size);
   PyArrayIterObject* iter = (PyArrayIterObject*)PyArray_IterNew((PyObject*)idx);
-  int* buf_ngb; 
+  int* buf_ngb;
   npy_intp xi, yi, zi, xj, yj, zj;
-  npy_intp u2 = idx->dimensions[2]; 
-  npy_intp u1 = idx->dimensions[1]*u2;
-  npy_intp u0 = idx->dimensions[0]*u1;
+  npy_intp u2 = PyArray_DIMS(idx)[2];
+  npy_intp u1 = PyArray_DIMS(idx)[1]*u2;
+  npy_intp u0 = PyArray_DIMS(idx)[0]*u1;
   npy_intp mask_size = 0, n_edges = 0;
   npy_intp idx_i;
   npy_intp *buf_idx;
@@ -222,18 +222,18 @@ PyArrayObject* make_edges(const PyArrayObject* idx,
   npy_intp pos;
   PyArrayObject* edges;
   npy_intp dim[2] = {0, 2};
- 
+
   /* First loop over the input array to determine the mask size */
   while(iter->index < iter->size) {
     buf_idx = (npy_intp*)PyArray_ITER_DATA(iter);
     if (*buf_idx >= 0)
       mask_size ++;
-    PyArray_ITER_NEXT(iter); 
+    PyArray_ITER_NEXT(iter);
   }
 
   /* Allocate the array of edges using an upper bound of the required
      memory space */
-  edges_data = (npy_intp*)malloc(2 * ngb_size * mask_size * sizeof(npy_intp)); 
+  edges_data = (npy_intp*)malloc(2 * ngb_size * mask_size * sizeof(npy_intp));
 
   /* Second loop over the input array */
   PyArray_ITER_RESET(iter);
@@ -242,8 +242,8 @@ PyArrayObject* make_edges(const PyArrayObject* idx,
   while(iter->index < iter->size) {
 
     xi = iter->coordinates[0];
-    yi = iter->coordinates[1]; 
-    zi = iter->coordinates[2]; 
+    yi = iter->coordinates[1];
+    zi = iter->coordinates[2];
     buf_idx = (npy_intp*)PyArray_ITER_DATA(iter);
     idx_i = *buf_idx;
 
@@ -253,7 +253,7 @@ PyArrayObject* make_edges(const PyArrayObject* idx,
       for (ngb_idx=0; ngb_idx<ngb_size; ngb_idx++) {
 
 	/* Get neighbor coordinates */
-	xj = xi + *buf_ngb; buf_ngb++; 
+	xj = xi + *buf_ngb; buf_ngb++;
 	yj = yi + *buf_ngb; buf_ngb++;
 	zj = zi + *buf_ngb; buf_ngb++;
 	pos = xj*u1 + yj*u2 + zj;
@@ -261,7 +261,7 @@ PyArrayObject* make_edges(const PyArrayObject* idx,
 	/* Store edge if neighbor is within the mask */
 	if ((pos < 0) || (pos >= u0))
 	  continue;
-	buf_idx = (npy_intp*)idx->data + pos;
+	buf_idx = (npy_intp*)PyArray_DATA(idx) + pos;
 	if (*buf_idx < 0)
 	  continue;
 	buf_edges[0] = idx_i;
@@ -271,19 +271,19 @@ PyArrayObject* make_edges(const PyArrayObject* idx,
 
       }
     }
-    
+
     /* Increment iterator */
-    PyArray_ITER_NEXT(iter); 
-    
+    PyArray_ITER_NEXT(iter);
+
   }
 
   /* Reallocate edges array to account for connections suppressed due to masking */
-  edges_data = realloc((void *)edges_data, 2 * n_edges * sizeof(npy_intp)); 
+  edges_data = realloc((void *)edges_data, 2 * n_edges * sizeof(npy_intp));
   dim[0] = n_edges;
   edges = (PyArrayObject*) PyArray_SimpleNewFromData(2, dim, NPY_INTP, (void*)edges_data);
 
   /* Transfer ownership to python (to avoid memory leaks!) */
-  edges->flags = (edges->flags) | NPY_OWNDATA;
+  PyArray_ENABLEFLAGS(edges, NPY_ARRAY_OWNDATA);
 
   /* Free memory */
   Py_XDECREF(iter);
@@ -292,14 +292,14 @@ PyArrayObject* make_edges(const PyArrayObject* idx,
 }
 
 
-/* 
+/*
    Compute the interaction energy:
 
    sum_i,j qi^T U qj
-   = sum_i qi^T sum_j U qj   
-   
+   = sum_i qi^T sum_j U qj
+
 */
-double interaction_energy(PyArrayObject* ppm, 
+double interaction_energy(PyArrayObject* ppm,
 			  const PyArrayObject* XYZ,
 			  const PyArrayObject* U,
 			  int ngb_size)
@@ -307,54 +307,54 @@ double interaction_energy(PyArrayObject* ppm,
 {
   npy_intp k, x, y, z, pos;
   double *p, *buf;
-  double res = 0.0, tmp;  
+  double res = 0.0, tmp;
   PyArrayIterObject* iter;
-  int axis = 1; 
+  int axis = 1;
   double* ppm_data;
-  npy_intp K = ppm->dimensions[3]; 
-  npy_intp u2 = ppm->dimensions[2]*K; 
-  npy_intp u1 = ppm->dimensions[1]*u2;
-  npy_intp* xyz; 
-  const double* U_data = (double*)U->data;
+  npy_intp K = PyArray_DIMS(ppm)[3];
+  npy_intp u2 = PyArray_DIMS(ppm)[2]*K;
+  npy_intp u1 = PyArray_DIMS(ppm)[1]*u2;
+  npy_intp* xyz;
+  const double* U_data = (double*)PyArray_DATA(U);
   int* ngb;
 
   /* Neighborhood system */
   ngb = _select_neighborhood_system(ngb_size);
 
   /* Pointer to ppm array */
-  ppm_data = (double*)ppm->data;
+  ppm_data = (double*)PyArray_DATA(ppm);
 
   /* Allocate auxiliary vector */
-  p = (double*)calloc(K, sizeof(double)); 
-  
-  /* Loop over points */ 
+  p = (double*)calloc(K, sizeof(double));
+
+  /* Loop over points */
   iter = (PyArrayIterObject*)PyArray_IterAllButAxis((PyObject*)XYZ, &axis);
   while(iter->index < iter->size) {
-    
-    /* Compute the average ppm in the neighborhood */ 
-    xyz = PyArray_ITER_DATA(iter); 
+
+    /* Compute the average ppm in the neighborhood */
+    xyz = PyArray_ITER_DATA(iter);
     x = xyz[0];
     y = xyz[1];
     z = xyz[2];
     _ngb_integrate(p, ppm, x, y, z, U_data, (const int*)ngb, ngb_size);
-    
+
     /* Calculate the dot product qi^T p where qi is the local
        posterior */
-    tmp = 0.0; 
-    pos = x*u1 + y*u2 + z*K; 
+    tmp = 0.0;
+    pos = x*u1 + y*u2 + z*K;
     for (k=0, buf=p; k<K; k++, pos++, buf++)
       tmp += ppm_data[pos]*(*buf);
 
-    /* Update overall energy */ 
-    res += tmp; 
+    /* Update overall energy */
+    res += tmp;
 
-    /* Update iterator */ 
-    PyArray_ITER_NEXT(iter); 
+    /* Update iterator */
+    PyArray_ITER_NEXT(iter);
   }
 
-  /* Free memory */ 
+  /* Free memory */
   free(p);
   Py_XDECREF(iter);
 
-  return res; 
+  return res;
 }
