@@ -21,12 +21,10 @@ It implements 3 approaches:
 
 Author : Bertrand Thirion, Yaroslav Halchenko, 2008-2012
 """
-from __future__ import print_function
-from __future__ import absolute_import
 
 import numpy as np
-from numpy.linalg import pinv
 import scipy.stats as st
+from numpy.linalg import pinv
 
 
 def check_p_values(p_values):
@@ -52,10 +50,9 @@ def check_p_values(p_values):
     if np.any(np.isnan(p_values)):
         raise ValueError("%d values are NaN" % (sum(np.isnan(p_values))))
     if p_values.min() < 0:
-        raise ValueError("Negative p-values. Min=%g" % (p_values.min(),))
+        raise ValueError(f"Negative p-values. Min={p_values.min():g}")
     if p_values.max() > 1:
-        raise ValueError("P-values greater than 1! Max=%g" % (
-                p_values.max(),))
+        raise ValueError(f"P-values greater than 1! Max={p_values.max():g}")
     return p_values
 
 
@@ -146,15 +143,15 @@ def fdr(p_values=None, verbose=0):
     q = q[inverse_order]
 
     if verbose:
-        import matplotlib.pylab as mp
-        mp.figure()
-        mp.xlabel('Input p-value')
-        mp.plot(p_values, q, '.')
-        mp.ylabel('Associated fdr')
+        import matplotlib.pyplot as plt
+        plt.figure()
+        plt.xlabel('Input p-value')
+        plt.plot(p_values, q, '.')
+        plt.ylabel('Associated fdr')
     return q
 
 
-class NormalEmpiricalNull(object):
+class NormalEmpiricalNull:
     """Class to compute the empirical null normal fit to the data.
 
     The data which is used to estimate the FDR, assuming a Gaussian null
@@ -208,7 +205,7 @@ class NormalEmpiricalNull(object):
         medge = ledge + 0.5 * step
 
         # remove null bins
-        hist = hist[hist > 0].astype(np.float)
+        hist = hist[hist > 0].astype(np.float64)
         medge = medge[:-1][hist > 0]  # edges include rightmost outer
 
         # fit the histogram
@@ -265,8 +262,7 @@ class NormalEmpiricalNull(object):
             self.plot(efp, alpha)
 
         if efp[-1] > alpha:
-            print("the maximal value is %f , the corresponding FDR is %f "
-                  % (self.x[ - 1], efp[ - 1]))
+            print("the maximal value is {:f} , the corresponding FDR is {:f} ".format(self.x[ - 1], efp[ - 1]))
             return np.inf
         j = np.argmin(efp[:: - 1] < alpha) + 1
         return 0.5 * (self.x[ - j] + self.x[ - j + 1])
@@ -357,10 +353,10 @@ class NormalEmpiricalNull(object):
         g = self.p0 * st.norm.pdf(medge, self.mu, self.sigma)
         hist /= step
 
-        import matplotlib.pylab as mp
+        import matplotlib.pyplot as plt
         if mpaxes is None:
-            mp.figure()
-            ax = mp.subplot(1, 1, 1)
+            plt.figure()
+            ax = plt.subplot(1, 1, 1)
         else:
             ax = mpaxes
         if bar:
