@@ -17,7 +17,7 @@ general, there might be some other parameters (i.e. sympy.Symbol
 instances) that are not Terms.
 
 The design matrix is made up of columns that are the derivatives of mean
-with respect to everything that is not a Term, evaluted at a recarray
+with respect to everything that is not a Term, evaluated at a recarray
 that has field names given by [str(t) for t in self.terms].
 
 For those familiar with R's formula syntax, if we wanted a design matrix
@@ -65,7 +65,7 @@ like the following::
 With the Formula, it looks like this:
 
 >>> r = np.rec.array([
-...     (43, 51, 30, 39, 61, 92, 45), (63, 64, 51, 54, 63, 73, 47), 
+...     (43, 51, 30, 39, 61, 92, 45), (63, 64, 51, 54, 63, 73, 47),
 ...     (71, 70, 68, 69, 76, 86, 48), (61, 63, 45, 47, 54, 84, 35),
 ...     (81, 78, 56, 66, 71, 83, 47), (43, 55, 49, 44, 54, 49, 34),
 ...     (58, 67, 42, 56, 66, 68, 35), (71, 75, 50, 55, 70, 66, 41),
@@ -88,10 +88,10 @@ With the Formula, it looks like this:
 >>> f.mean
 _b0*x1 + _b1*x3 + _b2*x1*x3 + _b3
 
-The I is the "intercept" term, I have explicity not used R's default of
+The I is the "intercept" term, I have explicitly not used R's default of
 adding it to everything.
 
->>> f.design(r)  #doctest: +STRUCTARR_EQUAL
+>>> f.design(r)  #doctest: +FIX +FLOAT_CMP
 array([(51.0, 39.0, 1989.0, 1.0), (64.0, 54.0, 3456.0, 1.0),
        (70.0, 69.0, 4830.0, 1.0), (63.0, 47.0, 2961.0, 1.0),
        (78.0, 66.0, 5148.0, 1.0), (55.0, 44.0, 2420.0, 1.0),
@@ -106,30 +106,28 @@ array([(51.0, 39.0, 1989.0, 1.0), (64.0, 54.0, 3456.0, 1.0),
        (66.0, 50.0, 3300.0, 1.0), (37.0, 58.0, 2146.0, 1.0),
        (54.0, 48.0, 2592.0, 1.0), (77.0, 63.0, 4851.0, 1.0),
        (75.0, 74.0, 5550.0, 1.0), (57.0, 45.0, 2565.0, 1.0),
-       (85.0, 71.0, 6035.0, 1.0), (82.0, 59.0, 4838.0, 1.0)], 
+       (85.0, 71.0, 6035.0, 1.0), (82.0, 59.0, 4838.0, 1.0)],
       dtype=[('x1', '<f8'), ('x3', '<f8'), ('x1*x3', '<f8'), ('1', '<f8')])
 '''
-from __future__ import print_function
-from __future__ import absolute_import
 
-import warnings
 import itertools
+import warnings
 from string import ascii_letters, digits
 
 import numpy as np
-from scipy.linalg import pinv
-
 import sympy
+from scipy.linalg import pinv
 from sympy import Dummy, default_sort_key
-from sympy.utilities.lambdify import (implemented_function, lambdify)
+from sympy.utilities.lambdify import implemented_function, lambdify
 
-from nipy.utils import _NoValue, VisibleDeprecationWarning
-from nipy.utils.compat3 import to_str
-
-from nipy.algorithms.utils.matrices import matrix_rank, full_rank
+from nipy.algorithms.utils.matrices import full_rank, matrix_rank
 
 # Legacy repr printing from numpy.
-from nipy.testing import legacy_printing as setup_module  # noqa
+from nipy.utils import VisibleDeprecationWarning, _NoValue
+
+
+def _to_str(s):
+    return s.decode('latin1') if isinstance(s, bytes) else str(s)
 
 
 @np.deprecate(message = "Please use sympy.Dummy instead of this function")
@@ -157,6 +155,7 @@ def make_dummy(name):
 def define(*args, **kwargs):
     # Moved to utils module
     import warnings
+
     from . import utils
     warnings.warn('Please use define function from utils module',
                   DeprecationWarning,
@@ -175,7 +174,7 @@ class Term(sympy.Symbol):
     recarray used to create a design matrix.
 
     >>> t = Term('x')
-    >>> xval = np.array([(3,),(4,),(5,)], np.dtype([('x', np.float)]))
+    >>> xval = np.array([(3,),(4,),(5,)], np.dtype([('x', np.float64)]))
     >>> f = t.formula
     >>> d = f.design(xval)
     >>> print(d.dtype.descr)
@@ -203,7 +202,7 @@ T = Term('t')
 
 
 def terms(names, **kwargs):
-    ''' Return list of terms with names given by `names`
+    r''' Return list of terms with names given by `names`
 
     This is just a convenience in defining a set of terms, and is the
     equivalent of ``sympy.symbols`` for defining symbols in sympy.
@@ -216,7 +215,7 @@ def terms(names, **kwargs):
     names : str or sequence of str
        If a single str, can specify multiple ``Term``s with string
        containing space or ',' as separator.
-    \\**kwargs : keyword arguments
+    \*\*kwargs : keyword arguments
        keyword arguments as for ``sympy.symbols``
 
     Returns
@@ -254,7 +253,7 @@ class FactorTerm(Term):
 
     def __new__(cls, name, level):
         # Names or levels can be byte strings
-        new = Term.__new__(cls, "%s_%s" % (to_str(name), to_str(level)))
+        new = Term.__new__(cls, f"{_to_str(name)}_{_to_str(level)}")
         new.level = level
         new.factor_name = name
         return new
@@ -276,7 +275,7 @@ class Beta(sympy.Dummy):
 
 
 def getparams(expression):
-    """ Return the parameters of an expression that are not Term 
+    """ Return the parameters of an expression that are not Term
     instances but are instances of sympy.Symbol.
 
     Examples
@@ -295,12 +294,12 @@ def getparams(expression):
     >>> getparams(f.mean*sympy.exp(th))
     [_b0, _b1, _b2, theta]
     """
-    atoms = set([])
+    atoms = set()
     expression = np.array(expression)
     if expression.shape == ():
         expression = expression.reshape((1,))
     if expression.ndim > 1:
-        expression = expression.reshape((np.product(expression.shape),))
+        expression = expression.reshape((np.prod(expression.shape),))
     for term in expression:
         atoms = atoms.union(sympy.sympify(term).atoms())
     params = []
@@ -323,12 +322,12 @@ def getterms(expression):
     >>> getterms(f.mean)
     [x, y, z]
     """
-    atoms = set([])
+    atoms = set()
     expression = np.array(expression)
     if expression.shape == ():
         expression = expression.reshape((1,))
     if expression.ndim > 1:
-        expression = expression.reshape((np.product(expression.shape),))
+        expression = expression.reshape((np.prod(expression.shape),))
     for e in expression:
         atoms = atoms.union(e.atoms())
     terms = []
@@ -377,7 +376,7 @@ def make_recarray(rows, names, dtypes=None, drop_name_dim=_NoValue):
     Create a recarray with named columns from a list or ndarray of `rows` and
     sequence of `names` for the columns. If `rows` is an ndarray, `dtypes` must
     be None, otherwise we raise a ValueError. Otherwise, if `dtypes` is None,
-    we cast the data in all columns in `rows` as np.float. If `dtypes` is not
+    we cast the data in all columns in `rows` as np.float64. If `dtypes` is not
     None, the routine uses `dtypes` as a dtype specifier for the output
     structured array.
 
@@ -407,22 +406,22 @@ def make_recarray(rows, names, dtypes=None, drop_name_dim=_NoValue):
 
     >>> arr = np.array([[3, 4], [4, 6], [6, 8]])
     >>> make_recarray(arr, ['x', 'y'],
-    ...               drop_name_dim=True) #doctest: +STRUCTARR_EQUAL
+    ...               drop_name_dim=True) #doctest: +FIX
     array([(3, 4), (4, 6), (6, 8)],
           dtype=[('x', '<i8'), ('y', '<i8')])
     >>> make_recarray(arr, ['x', 'y'],
-    ...               drop_name_dim=False) #doctest: +STRUCTARR_EQUAL
+    ...               drop_name_dim=False) #doctest: +FIX
     array([[(3, 4)],
            [(4, 6)],
            [(6, 8)]],
           dtype=[('x', '<i8'), ('y', '<i8')])
     >>> r = make_recarray(arr, ['w', 'u'], drop_name_dim=True)
     >>> make_recarray(r, ['x', 'y'],
-    ...               drop_name_dim=True) #doctest: +STRUCTARR_EQUAL
+    ...               drop_name_dim=True) #doctest: +FIX
     array([(3, 4), (4, 6), (6, 8)],
           dtype=[('x', '<i8'), ('y', '<i8')])
     >>> make_recarray([[3, 4], [4, 6], [7, 9]], 'wv',
-    ...               [np.float, np.int])  #doctest: +STRUCTARR_EQUAL
+    ...               [np.float64, np.int_])  #doctest: +FIX +FLOAT_CMP
     array([(3.0, 4), (4.0, 6), (7.0, 9)],
           dtype=[('w', '<f8'), ('v', '<i8')])
 
@@ -440,9 +439,9 @@ def make_recarray(rows, names, dtypes=None, drop_name_dim=_NoValue):
         return _recarray_from_array(rows, names, drop_name_dim)
     # Structured array from list
     if dtypes is None:
-        dtype = np.dtype([(n, np.float) for n in names])
+        dtype = np.dtype([(n, np.float64) for n in names])
     else:
-        dtype = np.dtype([(n, d) for n, d in zip(names, dtypes)])
+        dtype = np.dtype(list(zip(names, dtypes)))
     # Peek at first value in iterable
     irows = iter(rows)
     row0 = next(irows)
@@ -454,7 +453,7 @@ def make_recarray(rows, names, dtypes=None, drop_name_dim=_NoValue):
     return np.array([tuple(r) for r in irows], dtype)
 
 
-class Formula(object):
+class Formula:
     """ A Formula is a model for a mean in a regression model.
 
     It is often given by a sequence of sympy expressions, with the mean
@@ -491,7 +490,7 @@ class Formula(object):
 
     def _getterms(self):
         t = self._terms
-        # The Rmode flag is meant to emulate R's implicit addition of an 
+        # The Rmode flag is meant to emulate R's implicit addition of an
         # intercept to every formula. It currently cannot be changed.
         Rmode = False
         if Rmode:
@@ -513,17 +512,17 @@ class Formula(object):
                     "variables in front.")
 
     def _getdiff(self):
-        params = sorted(list(set(getparams(self.mean))), key=default_sort_key)
+        params = sorted(set(getparams(self.mean)), key=default_sort_key)
         return [sympy.diff(self.mean, p).doit() for p in params]
     design_expr = property(_getdiff)
 
     def _getdtype(self):
         vnames = [str(s) for s in self.design_expr]
-        return np.dtype([(n, np.float) for n in vnames])
+        return np.dtype([(n, np.float64) for n in vnames])
     dtype = property(_getdtype, doc='The dtype of the design matrix of the Formula.')
 
     def __repr__(self):
-        return "Formula(%r)" % (list(self.terms),)
+        return f"Formula({list(self.terms)!r})"
 
     def __getitem__(self, key):
         """ Return the term such that str(term) == key.
@@ -541,7 +540,7 @@ class Formula(object):
         try:
             idx = names.index(key)
         except ValueError:
-            raise ValueError('term %s not found' % key)
+            raise ValueError(f'term {key} not found')
         return self.terms[idx]
 
     @staticmethod
@@ -569,9 +568,10 @@ class Formula(object):
         for d in drop:
             del(f[d])
         if keep:
-            return np.sum([t for n, t in f.items() if n in keep])
+            elements = [t for n, t in f.items() if n in keep]
         else:
-            return np.sum(list(f.values()))
+            elements = f.values()
+        return sum(elements, start=Formula([]))
 
     def subs(self, old, new):
         """ Perform a sympy substitution on all terms in the Formula
@@ -708,7 +708,7 @@ class Formula(object):
         o = np.array(other)
         if s.shape != o.shape:
             return False
-        return np.alltrue(np.equal(np.array(self), np.array(other)))
+        return np.all(np.equal(np.array(self), np.array(other)))
 
     def _setup_design(self):
         """ Initialize design
@@ -773,11 +773,11 @@ class Formula(object):
         # a list
         self._f = lambdify(newparams + newterms, d, ("numpy"))
 
-        # The input to self.design will be a recarray of that must 
+        # The input to self.design will be a recarray of that must
         # have field names that the Formula will expect to see.
         # However, if any of self.terms are FactorTerms, then the field
         # in the recarray will not actually be in the Term.
-        # 
+        #
         # For example, if there is a Factor 'f' with levels ['a','b'],
         # there will be terms 'f_a' and 'f_b', though the input to
         # design will have a field named 'f'. In this sense,
@@ -795,11 +795,11 @@ class Formula(object):
         preterm = list(set(preterm))
 
         # There is also an argument for parameters that are not
-        # Terms. 
+        # Terms.
 
-        self._dtypes = {'param':np.dtype([(str(p), np.float) for p in params]),
-                        'term':np.dtype([(str(t), np.float) for t in terms]),
-                        'preterm':np.dtype([(n, np.float) for n in preterm])}
+        self._dtypes = {'param':np.dtype([(str(p), np.float64) for p in params]),
+                        'term':np.dtype([(str(t), np.float64) for t in terms]),
+                        'preterm':np.dtype([(n, np.float64) for n in preterm])}
 
         self.__terms = terms
 
@@ -819,7 +819,7 @@ class Formula(object):
            Recarray including fields that are not Terms in
            getparams(self.design_expr)
         return_float : bool, optional
-           If True, return a np.float array rather than a np.recarray
+           If True, return a np.float64 array rather than a np.recarray
         contrasts : None or dict, optional
            Contrasts. The items in this dictionary should be (str,
            Formula) pairs where a contrast matrix is constructed for
@@ -843,23 +843,21 @@ class Formula(object):
         # The input to design should have field names for all fields in self._dtypes['preterm']
         if not set(preterm_recarray.dtype.names).issuperset(self._dtypes['preterm'].names):
             raise ValueError("for term, expecting a recarray with "
-                             "dtype having the following names: %r"
-                             % (self._dtypes['preterm'].names,))
+                             "dtype having the following names: {!r}".format(self._dtypes['preterm'].names))
         # The parameters should have field names for all fields in self._dtypes['param']
         if param_recarray is not None:
             if not set(param_recarray.dtype.names).issuperset(self._dtypes['param'].names):
                 raise ValueError("for param, expecting a recarray with "
-                                 "dtype having the following names: %r"
-                                 % (self._dtypes['param'].names,))
+                                 "dtype having the following names: {!r}".format(self._dtypes['param'].names))
         # If the only term is an intercept,
         # the return value is a matrix of 1's.
         if list(self.terms) == [sympy.Number(1)]:
-            a = np.ones(preterm_recarray.shape[0], np.float)
+            a = np.ones(preterm_recarray.shape[0], np.float64)
             if not return_float:
-                a = a.view(np.dtype([('intercept', np.float)]))
+                a = a.view(np.dtype([('intercept', np.float64)]))
             return a
         elif not self._dtypes['term']:
-            raise ValueError("none of the expresssions are self.terms "
+            raise ValueError("none of the expressions in self.terms "
                              "are Term instances; shape of resulting "
                              "undefined")
         # The term_recarray is essentially the same as preterm_recarray,
@@ -878,11 +876,11 @@ class Formula(object):
                     factor_col = factor_col.astype('U')
                 fl_ind =  np.array([x == t.level
                                     for x in factor_col]).reshape(-1)
-                term_recarray['%s_%s' % (t.factor_name, t.level)] = fl_ind
+                term_recarray[f'{t.factor_name}_{t.level}'] = fl_ind
         # The lambda created in self._setup_design needs to take a tuple of
         # columns as argument, not an ndarray, so each column
         # is extracted and put into float_tuple.
-        float_array = term_recarray.view(np.float)
+        float_array = term_recarray.view(np.float64)
         float_array.shape = (term_recarray.shape[0], -1)
         float_array = float_array.T
         float_tuple = tuple(float_array)
@@ -924,7 +922,7 @@ class Formula(object):
         if return_float or contrasts:
             # If the design matrix is just a column of 1s
             # return a 1-dimensional array.
-            D = np.squeeze(D.astype(np.float))
+            D = np.squeeze(D.astype(np.float64))
             # If there are contrasts, the pseudo-inverse of D
             # must be computed.
             if contrasts:
@@ -945,7 +943,7 @@ class Formula(object):
             for key, cf in contrasts.items():
                 if not is_formula(cf):
                     cf = Formula([cf])
-                L = cf.design(input, param=param_recarray, 
+                L = cf.design(input, param=param_recarray,
                               return_float=True)
                 cmatrices[key] = contrast_from_cols_or_rows(L, _D, pseudo=pinvD)
             return D, cmatrices
@@ -980,7 +978,7 @@ def natural_spline(t, knots=None, order=3, intercept=False):
     --------
     >>> x = Term('x')
     >>> n = natural_spline(x, knots=[1,3,4], order=3)
-    >>> xval = np.array([3,5,7.]).view(np.dtype([('x', np.float)]))
+    >>> xval = np.array([3,5,7.]).view(np.dtype([('x', np.float64)]))
     >>> n.design(xval, return_float=True)
     array([[   3.,    9.,   27.,    8.,    0.,   -0.],
            [   5.,   25.,  125.,   64.,    8.,    1.],
@@ -1044,9 +1042,9 @@ class Factor(Formula):
         if levelsarr.ndim == 0 and levelsarr.dtype.kind in 'SOU':
             levelsarr = np.asarray(list(levels))
         if levelsarr.dtype.kind not in 'SOU': # the levels are not strings
-            if not np.alltrue(np.equal(levelsarr, np.round(levelsarr))):
+            if not np.all(np.equal(levelsarr, np.round(levelsarr))):
                 raise ValueError('levels must be strings or ints')
-            levelsarr = levelsarr.astype(np.int)
+            levelsarr = levelsarr.astype(np.int_)
         elif levelsarr.dtype.kind == 'S': # Byte strings, convert
             levelsarr = levelsarr.astype('U')
         Formula.__init__(self, [FactorTerm(name, l) for l in levelsarr],
@@ -1063,7 +1061,7 @@ class Factor(Formula):
         """
         if level not in self.levels:
             raise ValueError('level not found')
-        return self["%s_%s" % (self.name, str(level))]
+        return self[f"{self.name}_{str(level)}"]
 
     def _getmaineffect(self, ref=-1):
         v = list(self._terms.copy())
@@ -1120,7 +1118,7 @@ class Factor(Formula):
 
         Examples
         --------
-        >>> data = np.array([(3,'a'),(4,'a'),(5,'b'),(3,'b')], np.dtype([('x', np.float), ('y', 'S1')]))
+        >>> data = np.array([(3,'a'),(4,'a'),(5,'b'),(3,'b')], np.dtype([('x', np.float64), ('y', 'S1')]))
         >>> f1 = Factor.fromcol(data['y'], 'y')
         >>> f2 = Factor.fromcol(data['x'], 'x')
         >>> d = f1.design(data)
@@ -1265,7 +1263,7 @@ class RandomEffects(Formula):
         if self.sigma.shape != (q,q):
             raise ValueError('incorrect shape for covariance '
                              'of random effects, '
-                             'should have shape %r' % ((q,q)))
+                             f'should have shape {q!r}')
         self.char = char
 
     def cov(self, term, param=None):
