@@ -18,8 +18,6 @@ Author: Bertrand Thirion, 2012.
 >>> T2 = t_stat(Y)
 >>> assert(T1.std() < T2.std())
 """
-from __future__ import absolute_import
-from __future__ import print_function
 
 import numpy as np
 
@@ -99,7 +97,7 @@ def t_stat(Y):
     return Y.mean(0) / Y.std(0) * np.sqrt(Y.shape[0] - 1)
 
 
-class MixedEffectsModel(object):
+class MixedEffectsModel:
     """Class to handle multiple one-sample mixed effects models
     """
 
@@ -221,7 +219,7 @@ def two_sample_ftest(Y, V1, group, n_iter=5, verbose=False):
     Y: array of shape (n_samples, n_tests)
        the data
     V1: array of shape (n_samples, n_tests)
-        first-level variance assocated with the data
+        first-level variance associated with the data
     group: array of shape (n_samples)
        a vector of indicators yielding the samples membership
     n_iter: int, optional,
@@ -255,7 +253,7 @@ def two_sample_ttest(Y, V1, group, n_iter=5, verbose=False):
     Y: array of shape (n_samples, n_tests)
        the data
     V1: array of shape (n_samples, n_tests)
-        first-level variance assocated with the data
+        first-level variance associated with the data
     group: array of shape (n_samples)
        a vector of indicators yielding the samples membership
     n_iter: int, optional,
@@ -332,7 +330,7 @@ def mfx_stat(Y, V1, X, column, n_iter=5, return_t=True,
     Y: array of shape (n_samples, n_tests)
        the data
     V1: array of shape (n_samples, n_tests)
-        first-level variance assocated with the data
+        first-level variance associated with the data
     X: array of shape(n_samples, n_regressors)
        the design matrix of the model
     column: int,
