@@ -3,7 +3,6 @@
 """
 Non-linear least squares model
 """
-from __future__ import absolute_import
 __docformat__ = 'restructuredtext'
 
 import numpy as np
@@ -11,10 +10,8 @@ import numpy.linalg as npl
 
 from .model import Model
 
-from nipy.externals.six import Iterator
 
-
-class NLSModel(Model, Iterator):
+class NLSModel(Model):
     """
     Class representing a simple nonlinear least squares model.
     """
