@@ -17,8 +17,6 @@ General reference for regression models:
     Elizabeth A. Peck, G. Geoffrey Vining. Wiley, 2006.
 
 """
-from __future__ import print_function
-from __future__ import absolute_import
 
 __docformat__ = 'restructuredtext en'
 
@@ -26,18 +24,14 @@ import warnings
 
 import numpy as np
 import numpy.linalg as npl
-
-from scipy import stats
 import scipy.linalg as spl
-
-from nibabel.onetime import setattr_on_read
+from nibabel.onetime import auto_attr
+from scipy import stats
 
 from nipy.algorithms.utils.matrices import matrix_rank, pos_recipr
 
-from .model import LikelihoodModel, LikelihoodModelResults
-
 # Legacy repr printing from numpy.
-from nipy.testing import legacy_printing as setup_module  # noqa
+from .model import LikelihoodModel, LikelihoodModelResults
 
 
 class OLSModel(LikelihoodModel):
@@ -85,10 +79,10 @@ class OLSModel(LikelihoodModel):
     array([ 0.25      ,  2.14285714])
     >>> results.t()
     array([ 0.98019606,  1.87867287])
-    >>> print(results.Tcontrast([0,1]))  #doctest: +FP_6DP
+    >>> print(results.Tcontrast([0,1]))  #doctest: +FLOAT_CMP
     <T contrast: effect=2.14285714286, sd=1.14062281591, t=1.87867287326,
     df_den=5>
-    >>> print(results.Fcontrast(np.eye(2)))  #doctest: +FP_6DP
+    >>> print(results.Fcontrast(np.eye(2)))  #doctest: +FLOAT_CMP
     <F contrast: F=19.4607843137, df_den=5, df_num=2>
     """
 
@@ -101,7 +95,7 @@ class OLSModel(LikelihoodModel):
             Data are assumed to be column ordered with
             observations in rows.
         """
-        super(OLSModel, self).__init__()
+        super().__init__()
         self.initialize(design)
 
     def initialize(self, design):
@@ -262,7 +256,7 @@ class OLSModel(LikelihoodModel):
         """
         return X
 
-    @setattr_on_read
+    @auto_attr
     def has_intercept(self):
         """
         Check if column of 1s is in column space of design
@@ -274,7 +268,7 @@ class OLSModel(LikelihoodModel):
             return True
         return False
 
-    @setattr_on_read
+    @auto_attr
     def rank(self):
         """ Compute rank of design matrix
         """
@@ -337,7 +331,7 @@ class ARModel(OLSModel):
     ...     rho, sigma = yule_walker(data["Y"] - results.predicted,
     ...                              order=2,
     ...                              df=model.df_resid)
-    ...     model = ARModel(model.design, rho) #doctest: +FP_6DP
+    ...     model = ARModel(model.design, rho) #doctest: +FLOAT_CMP
     ...
     AR coefficients: [ 0.  0.]
     AR coefficients: [-0.61530877 -1.01542645]
@@ -345,21 +339,21 @@ class ARModel(OLSModel):
     AR coefficients: [-0.7220361  -1.05365352]
     AR coefficients: [-0.72229201 -1.05408193]
     AR coefficients: [-0.722278   -1.05405838]
-    >>> results.theta #doctest: +NP_ALLCLOSE
+    >>> results.theta #doctest: +FLOAT_CMP
     array([ 1.59564228, -0.58562172])
-    >>> results.t() #doctest: +NP_ALLCLOSE
+    >>> results.t() #doctest: +FLOAT_CMP
     array([ 38.0890515 ,  -3.45429252])
-    >>> print(results.Tcontrast([0,1]))  #doctest: +FP_6DP
+    >>> print(results.Tcontrast([0,1]))  #doctest: +FLOAT_CMP
     <T contrast: effect=-0.58562172384377043, sd=0.16953449108110835,
     t=-3.4542925165805847, df_den=5>
-    >>> print(results.Fcontrast(np.identity(2)))  #doctest: +FP_6DP
+    >>> print(results.Fcontrast(np.identity(2)))  #doctest: +FLOAT_CMP
     <F contrast: F=4216.810299725842, df_den=5, df_num=2>
 
     Reinitialize the model, and do the automated iterative fit
 
     >>> model.rho = np.array([0,0])
     >>> model.iterative_fit(data['Y'], niter=3)
-    >>> print(model.rho)  #doctest: +FP_6DP
+    >>> print(model.rho)  #doctest: +FLOAT_CMP
     [-0.7220361  -1.05365352]
     """
 
@@ -375,7 +369,7 @@ class ARModel(OLSModel):
             ndarray, gives initial estimate of rho. Be careful as ``ARModel(X,
             1) != ARModel(X, 1.0)``.
         """
-        if type(rho) is type(1):
+        if type(rho) is int:
             self.order = rho
             self.rho = np.zeros(self.order, np.float64)
         else:
@@ -385,7 +379,7 @@ class ARModel(OLSModel):
             if self.rho.shape == ():
                 self.rho.shape = (1,)
             self.order = self.rho.shape[0]
-        super(ARModel, self).__init__(design)
+        super().__init__(design)
 
     def iterative_fit(self, Y, niter=3):
         """
@@ -601,13 +595,13 @@ def ar_bias_correct(results, order, invM=None):
     cov[0] = sum_sq
     for i in range(1, order + 1):
         cov[i] = np.sum(resid[i:] * resid[0:- i], axis=0)
-    # cov is shape (order + 1, V) where V = np.product(in_shape[1:])
+    # cov is shape (order + 1, V) where V = np.prod(in_shape[1:])
     cov = np.dot(invM, cov)
     output = cov[1:] * pos_recipr(cov[0])
     return np.squeeze(output.reshape((order,) + in_shape[1:]))
 
 
-class AREstimator(object):
+class AREstimator:
     """
     A class to estimate AR(p) coefficients from residuals
     """
@@ -661,10 +655,10 @@ class WLSModel(OLSModel):
     array([ 0.0952381 ,  2.91666667])
     >>> results.t()
     array([ 0.35684428,  2.0652652 ])
-    >>> print(results.Tcontrast([0,1]))  #doctest: +FP_6DP
+    >>> print(results.Tcontrast([0,1]))  #doctest: +FLOAT_CMP
     <T contrast: effect=2.91666666667, sd=1.41224801095, t=2.06526519708,
     df_den=5>
-    >>> print(results.Fcontrast(np.identity(2)))  #doctest: +FP_6DP
+    >>> print(results.Fcontrast(np.identity(2)))  #doctest: +FLOAT_CMP
     <F contrast: F=26.9986072423, df_den=5, df_num=2>
     """
 
@@ -679,7 +673,7 @@ class WLSModel(OLSModel):
                 raise ValueError(
                     'Weights must be scalar or same length as design')
             self.weights = weights.reshape(design_rows)
-        super(WLSModel, self).__init__(design)
+        super().__init__(design)
 
     def whiten(self, X):
         """ Whitener for WLS model, multiplies by sqrt(self.weights)
@@ -715,21 +709,21 @@ class RegressionResults(LikelihoodModelResults):
         self.wY = wY
         self.wresid = wresid
 
-    @setattr_on_read
+    @auto_attr
     def resid(self):
         """
         Residuals from the fit.
         """
         return self.Y - self.predicted
 
-    @setattr_on_read
+    @auto_attr
     def norm_resid(self):
         """
         Residuals, normalized to have unit length.
 
         Notes
         -----
-        Is this supposed to return "stanardized residuals,"
+        Is this supposed to return "standardized residuals,"
         residuals standardized
         to have mean zero and approximately unit variance?
 
@@ -742,7 +736,7 @@ class RegressionResults(LikelihoodModelResults):
         """
         return self.resid * pos_recipr(np.sqrt(self.dispersion))
 
-    @setattr_on_read
+    @auto_attr
     def predicted(self):
         """ Return linear predictor values from a design matrix.
         """
@@ -751,7 +745,7 @@ class RegressionResults(LikelihoodModelResults):
         X = self.model.design
         return np.dot(X, beta)
 
-    @setattr_on_read
+    @auto_attr
     def R2_adj(self):
         """Return the R^2 value for each row of the response Y.
 
@@ -768,7 +762,7 @@ class RegressionResults(LikelihoodModelResults):
         d *= ((self.df_total - 1.) / self.df_resid)
         return 1 - d
 
-    @setattr_on_read
+    @auto_attr
     def R2(self):
         """
         Return the adjusted R^2 value for each row of the response Y.
@@ -782,7 +776,7 @@ class RegressionResults(LikelihoodModelResults):
         d = self.SSE / self.SST
         return 1 - d
 
-    @setattr_on_read
+    @auto_attr
     def SST(self):
         """Total sum of squares. If not from an OLS model this is "pseudo"-SST.
         """
@@ -791,34 +785,34 @@ class RegressionResults(LikelihoodModelResults):
                           "SST inappropriate")
         return ((self.wY - self.wY.mean(0)) ** 2).sum(0)
 
-    @setattr_on_read
+    @auto_attr
     def SSE(self):
         """Error sum of squares. If not from an OLS model this is "pseudo"-SSE.
         """
         return (self.wresid ** 2).sum(0)
 
-    @setattr_on_read
+    @auto_attr
     def SSR(self):
         """ Regression sum of squares """
         return self.SST - self.SSE
 
-    @setattr_on_read
+    @auto_attr
     def MSR(self):
         """ Mean square (regression)"""
         return self.SSR / (self.df_model - 1)
 
-    @setattr_on_read
+    @auto_attr
     def MSE(self):
         """ Mean square (error) """
         return self.SSE / self.df_resid
 
-    @setattr_on_read
+    @auto_attr
     def MST(self):
         """ Mean square (total)
         """
         return self.SST / (self.df_total - 1)
 
-    @setattr_on_read
+    @auto_attr
     def F_overall(self):
         """ Overall goodness of fit F test,
         comparing model to a model with just an intercept.
@@ -836,7 +830,7 @@ class GLSModel(OLSModel):
 
     def __init__(self, design, sigma):
         self.cholsigmainv = npl.cholesky(npl.pinv(sigma)).T
-        super(GLSModel, self).__init__(design)
+        super().__init__(design)
 
     def whiten(self, Y):
         return np.dot(self.cholsigmainv, Y)
