@@ -3,15 +3,13 @@
 """
 Test functions for models.utils
 """
-from __future__ import absolute_import
 
 import numpy as np
+import pytest
+from numpy.testing import assert_array_almost_equal
 
 from .. import utils
 
-from nose.tools import (assert_equal, assert_true, assert_raises)
-from numpy.testing import (assert_array_equal, assert_array_almost_equal)
-
 
 def test_StepFunction():
     x = np.arange(20)
@@ -23,7 +21,7 @@ def test_StepFunction():
 def test_StepFunctionBadShape():
     x = np.arange(20)
     y = np.arange(21)
-    assert_raises(ValueError, utils.StepFunction, x, y)
+    pytest.raises(ValueError, utils.StepFunction, x, y)
     x = np.zeros((2, 2))
     y = np.zeros((2, 2))
-    assert_raises(ValueError, utils.StepFunction, x, y)
+    pytest.raises(ValueError, utils.StepFunction, x, y)
