@@ -13,21 +13,18 @@ Taylor, J.E. & Worsley, K.J. (2008). "Random fields of multivariate
    test statistics, with applications to shape analysis." arXiv:0803.1708
    [math.ST] and Annals of Statistics 36( 2008): 1-27
 """
-from __future__ import print_function
-from __future__ import absolute_import
 
 import numpy as np
 from numpy.linalg import pinv
-
 from scipy import stats
+
 try:
     from scipy.misc import factorial
 except ImportError:
     from scipy.special import factorial
-from scipy.special import gamma, gammaln, beta, hermitenorm
+from scipy.special import beta, gamma, gammaln, hermitenorm
 
 # Legacy repr printing from numpy.
-from nipy.testing import legacy_printing as setup_module  # noqa
 
 
 def binomial(n, k):
@@ -193,10 +190,10 @@ class ECquasi(np.poly1d):
 
     def __setattr__(self, key, val):
         if key == 'exponent':
-            if 2*float(val) % 1 == 0: 
+            if 2*float(val) % 1 == 0:
                 self.__dict__[key] = float(val)
             else:
-                raise ValueError('expecting multiple of a half, got %f' % val)
+                raise ValueError(f'expecting multiple of a half, got {val:f}')
         elif key == 'm':
             if float(val) > 0 or val == np.inf:
                 self.__dict__[key] = val
@@ -235,7 +232,7 @@ class ECquasi(np.poly1d):
         --------
         >>> b = ECquasi([3,4,20], m=30, exponent=4)
         >>> c = ECquasi([1], m=30, exponent=4)
-        >>> b+c #doctest: +IGNORE_DTYPE
+        >>> b+c #doctest: +FIX
         ECquasi(array([ 3,  4, 21]), m=30.000000, exponent=4.000000)
 
         >>> d = ECquasi([1], m=30, exponent=3)
@@ -336,7 +333,7 @@ class ECquasi(np.poly1d):
         --------
         >>> b = ECquasi([3,4,20], m=30, exponent=4)
         >>> c = ECquasi([1,2], m=30, exponent=4)
-        >>> print(b-c)  #doctest: +IGNORE_DTYPE
+        >>> print(b-c)  #doctest: +FIX
         ECquasi(array([ 3,  3, 18]), m=30.000000, exponent=4.000000)
         """
         return self + (other * -1)
@@ -345,9 +342,8 @@ class ECquasi(np.poly1d):
         if not np.isfinite(self.m):
             m = repr(self.m)
         else:
-            m = '%f' % self.m
-        return "ECquasi(%s, m=%s, exponent=%f)" % (
-            repr(self.coeffs), m, self.exponent)
+            m = f'{self.m:f}'
+        return f"ECquasi({repr(self.coeffs)}, m={m}, exponent={self.exponent:f})"
 
     __str__ = __repr__
     __rsub__ = __sub__
@@ -364,7 +360,7 @@ class ECquasi(np.poly1d):
         Examples
         --------
         >>> a = ECquasi([3,4,5])
-        >>> a.deriv(m=2) #doctest: +IGNORE_DTYPE
+        >>> a.deriv(m=2) #doctest: +FIX
         ECquasi(array([6]), m=inf, exponent=0.000000)
 
         >>> b = ECquasi([3,4,5], m=10, exponent=3)
@@ -389,7 +385,7 @@ class ECquasi(np.poly1d):
             return d.deriv(m=m-1)
 
 
-class fnsum(object):
+class fnsum:
     def __init__(self, *items):
         self.items = list(items)
 
@@ -400,7 +396,7 @@ class fnsum(object):
         return v
 
 
-class IntrinsicVolumes(object):
+class IntrinsicVolumes:
     """ Compute intrinsic volumes of products of sets
 
     A simple class that exists only to compute the intrinsic volumes of
@@ -502,7 +498,7 @@ class ECcone(IntrinsicVolumes):
     def integ(self, m=None, k=None):
         raise NotImplementedError # this could be done with stats.t,
                                   # at least m=1
-    
+
     def density(self, x, dim):
         """ The EC density in dimension `dim`.
         """
@@ -562,7 +558,7 @@ def mu_sphere(n, j, r=1):
     """
     if j < n:
         if n-1 == j:
-            return 2 * np.power(np.pi, n/2.) * np.power(r, n-1) / gamma(n/2.) 
+            return 2 * np.power(np.pi, n/2.) * np.power(r, n-1) / gamma(n/2.)
 
         if (n-1-j)%2 == 0:
 
@@ -722,7 +718,7 @@ class ChiBarSquared(ChiSquared):
         sf = 0.
         g = Gaussian()
         for i in range(1, self.dfn+1):
-            sf += binomial(self.dfn, i) * stats.chi.sf(x, i) / np.power(2., self.dfn) 
+            sf += binomial(self.dfn, i) * stats.chi.sf(x, i) / np.power(2., self.dfn)
 
         d = np.array([g.density(np.sqrt(x), j) for j in range(self.dfn)])
         c = np.dot(pinv(d.T), sf)
@@ -761,7 +757,7 @@ def scale_space(region, interval, kappa=1.):
     region = IntrinsicVolumes(region)
 
     D = region.order
- 
+
     out = np.zeros((D+2,))
 
     out[0] = region.mu[0]
@@ -770,10 +766,10 @@ def scale_space(region, interval, kappa=1.):
             out[i] = (1./w1 + 1./w2) * region.mu[i] * 0.5
         for j in range(int(np.floor((D-i+1)/2.)+1)):
             denom = (i + 2*j - 1.)
-            # w^-i/i when i=0 
+            # w^-i/i when i=0
             # according to Keith Worsley the 2005 paper has a typo
             if denom == 0:
-                f = np.log(w2/w1) 
+                f = np.log(w2/w1)
             else:
                 f = (w1**(-i-2*j+1) - w2**(-i-2*j+1)) / denom
             f *= kappa**((1-2*j)/2.) * (-1)**j * factorial(int(denom))
