@@ -1,15 +1,10 @@
-from __future__ import absolute_import
 
 import numpy as np
 from numpy import median as np_median
-
+from numpy.testing import assert_array_almost_equal, assert_array_equal
 from scipy.stats import scoreatpercentile as sp_percentile
 
-from .._quantile import _quantile, _median
-
-from numpy.testing import (assert_array_equal,
-                           assert_array_almost_equal)
-
+from .._quantile import _median, _quantile
 
 NUMERIC_TYPES = sum([np.sctypes[t]
                      for t in ('int', 'uint', 'float', 'complex')],
@@ -38,8 +33,3 @@ def test_quantile():
                 assert_array_almost_equal(
                     _quantile(X, .75, axis=a, interp=True).squeeze(),
                     another_percentile(X, 75, axis=a))
-
-
-if __name__ == "__main__":
-    import nose
-    nose.run(argv=['', __file__])
