@@ -1,29 +1,27 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import absolute_import
 
 import numpy as np
-
-from scipy.special import gammaln, hermitenorm
 import scipy.stats
+from scipy.special import gammaln, hermitenorm
+
 try:
     from scipy.misc import factorial
 except ImportError:
     from scipy.special import factorial
 
+import pytest
+from numpy.testing import assert_almost_equal
+
 from .. import rft
 
-from nose.tools import assert_raises
-
-from numpy.testing import assert_almost_equal, dec
-
 #def rho(x, dim, df=np.inf):
 #    """
-#    EC densities for T and Gaussian (df=inf) random fields. 
+#    EC densities for T and Gaussian (df=inf) random fields.
 #    """
 #
 #    m = df
-#    
+#
 #    if dim > 0:
 #        x = np.asarray(x, np.float64)
 #--jarrod: shouldn't Q be rft.Q??
@@ -42,8 +40,8 @@ from numpy.testing import assert_almost_equal, dec
 #            return scipy.stats.norm.sf(x)
 
 def test_Q():
-    assert_raises(ValueError, rft.Q, -1)
-    assert_raises(ValueError, rft.Q, 0)
+    pytest.raises(ValueError, rft.Q, -1)
+    pytest.raises(ValueError, rft.Q, 0)
     x = np.arange(-9, 10)
     for dim in range(1, 4):
         res = rft.Q(dim)
@@ -70,7 +68,7 @@ def K(dim=4, dfn=7, dfd=np.inf):
     coef = 0
     for j in range(int(np.floor((D-1)/2.)+1)):
         if np.isfinite(m):
-            t = (gammaln((m+n-D)/2.+j) - 
+            t = (gammaln((m+n-D)/2.+j) -
                  gammaln(j+1) -
                  gammaln((m+n-D)/2.))
             t += lbinom(m-1, k-j) - k * np.log(m)
@@ -78,14 +76,14 @@ def K(dim=4, dfn=7, dfd=np.inf):
             _t = np.power(2., -j) / (factorial(k-j) * factorial(j))
             t = np.log(_t)
             t[np.isinf(_t)] = -np.inf
-        t += lbinom(n-1, D-1-j-k) 
-        coef += (-1)**(D-1) * factorial(D-1) * np.exp(t) * np.power(-1.*n, k) 
+        t += lbinom(n-1, D-1-j-k)
+        coef += (-1)**(D-1) * factorial(D-1) * np.exp(t) * np.power(-1.*n, k)
     return np.poly1d(coef[::-1])
 
 
 def F(x, dim, dfd=np.inf, dfn=1):
     """
-    EC densities for F and Chi^2 (dfd=inf) random fields. 
+    EC densities for F and Chi^2 (dfd=inf) random fields.
     """
     m = float(dfd)
     n = float(dfn)
@@ -100,7 +98,7 @@ def F(x, dim, dfd=np.inf, dfn=1):
             t += gammaln((m+n-D)/2.) - gammaln(m/2.)
         else:
             f = x*n
-            t = np.log(f/2.) * (n-D) / 2. - f/2. 
+            t = np.log(f/2.) * (n-D) / 2. - f/2.
         t -= np.log(2*np.pi) * D / 2. + np.log(2) * (D-2)/2. + gammaln(n/2.)
         k *= np.exp(t)
         return k
@@ -172,7 +170,7 @@ def test_polynomial1():
     for dim in range(1,10):
         q = rft.Gaussian().quasi(dim)
         h = hermitenorm(dim-1)
-        yield assert_almost_equal, q.c, h.c
+        assert_almost_equal(q.c, h.c)
 
 
 def test_polynomial2():
@@ -181,10 +179,10 @@ def test_polynomial2():
     for dim in range(1,10):
         q = rft.ChiSquared(dfn=1).quasi(dim)
         h = hermitenorm(dim-1)
-        yield assert_almost_equal, q.c, 2*h.c
+        assert_almost_equal(q.c, 2*h.c)
 
 
-@dec.slow
+# @dec.slow
 def test_polynomial3():
     # EC density of F with infinite dfd is the same as chi^2 --
     # polynomials should be the same.
@@ -192,10 +190,10 @@ def test_polynomial3():
         for dfn in range(5,10):
             q1 = rft.FStat(dfn=dfn, dfd=np.inf).quasi(dim)
             q2 = rft.ChiSquared(dfn=dfn).quasi(dim)
-            yield assert_almost_equal, q1.c, q2.c
+            assert_almost_equal(q1.c, q2.c)
 
 
-@dec.slow
+# @dec.slow
 def test_chi1():
     # EC density of F with infinite dfd is the same as chi^2 -- EC should be the
     # same.
@@ -206,7 +204,7 @@ def test_chi1():
             f = rft.FStat(dfn=dfn, dfd=np.inf)
             chi1 = c.density(dfn*x, dim)
             chi2 = f.density(x, dim)
-            yield assert_almost_equal, chi1, chi2
+            assert_almost_equal(chi1, chi2)
 
 
 def test_chi2():
@@ -217,7 +215,7 @@ def test_chi2():
             c = rft.ChiSquared(dfn=dfn)
             p1 = c.quasi(dim=dim)
             p2 = polyF(dim=dim, dfn=dfn)
-            yield assert_almost_equal, p1.c, p2.c
+            assert_almost_equal(p1.c, p2.c)
 
 
 def test_chi3():
@@ -229,7 +227,7 @@ def test_chi3():
         c = rft.ChiSquared(dfn=1)
         ec1 = g.density(np.sqrt(x), dim)
         ec2 = c.density(x, dim)
-        yield assert_almost_equal, 2*ec1, ec2
+        assert_almost_equal(2*ec1, ec2)
 
 
 def test_T1():
@@ -237,9 +235,9 @@ def test_T1():
     x = np.linspace(0.1,10,100)
     for dfd in [40,50]:
         t = rft.TStat(dfd=dfd)
-        yield assert_almost_equal, t(x), scipy.stats.t.sf(x, dfd)
+        assert_almost_equal(t(x), scipy.stats.t.sf(x, dfd))
     t = rft.TStat(dfd=np.inf)
-    yield assert_almost_equal, t(x), scipy.stats.norm.sf(x)
+    assert_almost_equal(t(x), scipy.stats.norm.sf(x))
 
 
 def test_search():
@@ -254,7 +252,7 @@ def test_search():
     assert_almost_equal(v1, v2)
 
 
-@dec.slow
+# @dec.slow
 def test_search1():
     # Test that the search region works.
     # XXX - we are not testing anything
@@ -275,7 +273,7 @@ def test_search1():
                 v2 += stat.density(x, i) * search.mu[i]
 
 
-@dec.slow
+# @dec.slow
 def test_search2():
     # Test that the search region works.
     search = rft.IntrinsicVolumes([3,4,5])
@@ -338,7 +336,7 @@ def test_search5():
     assert_almost_equal(y, z)
 
 
-@dec.slow
+# @dec.slow
 def test_T2():
     # T**2 is an F with dfn=1
     x = np.linspace(0,5,101)
@@ -348,10 +346,10 @@ def test_T2():
         for dim in range(7):
             y = 2*t.density(x, dim)
             z = f.density(x**2, dim)
-            yield assert_almost_equal, y, z
+            assert_almost_equal(y, z)
 
 
-@dec.slow
+# @dec.slow
 def test_hotelling1():
     # Asymptotically, Hotelling is the same as F which is the same as chi^2.
     x = np.linspace(0.1,10,100)
@@ -359,10 +357,10 @@ def test_hotelling1():
         for dfn in range(5,10):
             h = rft.Hotelling(k=dfn).density(x*dfn, dim)
             f = rft.FStat(dfn=dfn).density(x, dim)
-            yield assert_almost_equal, h, f
+            assert_almost_equal(h, f)
 
 
-@dec.slow
+# @dec.slow
 def test_hotelling4():
     # Hotelling T^2 should just be like taking product with sphere.
     x = np.linspace(0.1,10,100)
@@ -376,9 +374,9 @@ def test_hotelling4():
                 h2 = 2*rft.Hotelling(k=k, dfd=dfd).density(x, dim)
                 h = 2*rft.Hotelling(k=k, dfd=dfd)(x, search=search)
 
-                yield assert_almost_equal, h, t
-                yield assert_almost_equal, h, f
-                yield assert_almost_equal, h, h2
+                assert_almost_equal(h, t)
+                assert_almost_equal(h, f)
+                assert_almost_equal(h, h2)
     search = rft.IntrinsicVolumes([3,4,5])
     for k in range(5, 10):
         p = rft.spherical_search(k)
@@ -389,8 +387,8 @@ def test_hotelling4():
             h2 = 0
             for i in range(search.mu.shape[0]):
                 h2 += 2*rft.Hotelling(k=k, dfd=dfd).density(x, i) * search.mu[i]
-            yield assert_almost_equal, h, f
-            yield assert_almost_equal, h, h2
+            assert_almost_equal(h, f)
+            assert_almost_equal(h, h2)
 
 
 def test_hotelling2():
@@ -415,7 +413,7 @@ def test_hotelling2():
             assert_almost_equal(h, f)
 
 
-@dec.slow
+# @dec.slow
 def test_roy1():
     # EC densities of Roy with dfn=1 should be twice EC densities of Hotelling
     # T^2's.
@@ -425,10 +423,10 @@ def test_roy1():
             for dim in range(7):
                 h = 2*rft.Hotelling(dfd=dfd,k=k).density(x, dim)
                 r = rft.Roy(dfd=dfd,k=k,dfn=1).density(x, dim)
-                yield assert_almost_equal, h, r
+                assert_almost_equal(h, r)
 
 
-@dec.slow
+# @dec.slow
 def test_onesidedF():
     # EC densities of one sided F should be a difference of
     # F EC densities
@@ -439,10 +437,10 @@ def test_onesidedF():
                 f1 = rft.FStat(dfd=dfd,dfn=dfn).density(x, dim)
                 f2 = rft.FStat(dfd=dfd,dfn=dfn-1).density(x, dim)
                 onesided = rft.OneSidedF(dfd=dfd,dfn=dfn).density(x, dim)
-                yield assert_almost_equal, onesided, 0.5*(f1-f2)
+                assert_almost_equal(onesided, 0.5*(f1-f2))
 
 
-@dec.slow
+# @dec.slow
 def test_multivariate_forms():
     # MVform with one sphere is sqrt(chi^2), two spheres is sqrt(Roy) with
     # infinite degrees of freedom.
@@ -453,14 +451,14 @@ def test_multivariate_forms():
         for dim in range(7):
             mx = m.density(x, dim)
             cx = c.density(x**2, dim)
-            yield assert_almost_equal, mx, cx
+            assert_almost_equal(mx, cx)
         for k2 in range(5,10):
             m = rft.MultilinearForm(k1,k2)
             r = rft.Roy(k=k1, dfn=k2, dfd=np.inf)
             for dim in range(7):
                 mx = 2*m.density(x, dim)
                 rx = r.density(x**2/k2, dim)
-                yield assert_almost_equal, mx, rx
+                assert_almost_equal(mx, rx)
 
 
 def test_scale():
@@ -476,26 +474,26 @@ def test_F1():
             for dfd in [40,50,np.inf]:
                 f1 = F(x, dim, dfn=dfn, dfd=dfd)
                 f2 = F_alternative(x, dim, dfn=dfn, dfd=dfd)
-                yield assert_almost_equal, f1, f2
+                assert_almost_equal(f1, f2)
 
 
-@dec.slow
+# @dec.slow
 def test_F2():
     x = np.linspace(0.1,10,100)
     for dim in range(3,7):
         for dfn in range(5,10):
             for dfd in [40,50,np.inf]:
-                f1 = rft.FStat(dfn=dfn, dfd=dfd).density(x, dim) 
+                f1 = rft.FStat(dfn=dfn, dfd=dfd).density(x, dim)
                 f2 = F_alternative(x, dim, dfn=dfn, dfd=dfd)
-                yield assert_almost_equal, f1, f2
+                assert_almost_equal(f1, f2)
 
 
-@dec.slow
+# @dec.slow
 def test_F3():
     x = np.linspace(0.1,10,100)
     for dim in range(3,7):
         for dfn in range(5,10):
             for dfd in [40,50,np.inf]:
-                f1 = rft.FStat(dfn=dfn, dfd=dfd).density(x, dim) 
+                f1 = rft.FStat(dfn=dfn, dfd=dfd).density(x, dim)
                 f2 = F(x, dim, dfn=dfn, dfd=dfd)
-                yield assert_almost_equal, f1, f2
+                assert_almost_equal(f1, f2)
