@@ -1,16 +1,15 @@
-from __future__ import absolute_import
 
 import numpy as np
-
-from scipy.stats import norm
+import pytest
 import scipy.linalg as spl
+from numpy.testing import (
+    assert_almost_equal,
+    assert_array_almost_equal,
+    assert_array_equal,
+)
+from scipy.stats import norm
 
-
-from ..utils import (multiple_mahalanobis, z_score, multiple_fast_inv,
-                     check_cast_bin8)
-from nose.tools import assert_true, assert_equal, assert_raises
-from numpy.testing import (assert_almost_equal, assert_array_almost_equal,
-                           assert_array_equal)
+from ..utils import check_cast_bin8, multiple_fast_inv, multiple_mahalanobis, z_score
 
 
 def test_z_score():
@@ -53,8 +52,8 @@ def test_multiple_fast_inv():
 
 def assert_equal_bin8(actual, expected):
     res = check_cast_bin8(actual)
-    assert_equal(res.shape, actual.shape)
-    assert_true(res.dtype.type == np.uint8)
+    assert res.shape == actual.shape
+    assert res.dtype.type == np.uint8
     assert_array_equal(res, expected)
 
 
@@ -64,13 +63,13 @@ def test_check_cast_bin8():
         assert_equal_bin8(np.array([0, 1, 1, 1], in_dtype), [0, 1, 1, 1])
         assert_equal_bin8(np.array([[0, 1], [1, 1]], in_dtype),
                           [[0, 1], [1, 1]])
-        assert_raises(ValueError, check_cast_bin8,
+        pytest.raises(ValueError, check_cast_bin8,
                       np.array([0, 1, 2], dtype=in_dtype))
     for in_dtype in np.sctypes['float']:
-        assert_equal_bin8(np.array([0, 1, 1, -0], np.float), [0, 1, 1, 0])
-        assert_equal_bin8(np.array([[0, 1], [1, -0]], np.float),
+        assert_equal_bin8(np.array([0, 1, 1, -0], np.float64), [0, 1, 1, 0])
+        assert_equal_bin8(np.array([[0, 1], [1, -0]], np.float64),
                           [[0, 1], [1, 0]])
-        assert_raises(ValueError, check_cast_bin8,
+        pytest.raises(ValueError, check_cast_bin8,
                       np.array([0, 0.1, 1], dtype=in_dtype))
-        assert_raises(ValueError, check_cast_bin8,
+        pytest.raises(ValueError, check_cast_bin8,
                       np.array([0, -1, 1], dtype=in_dtype))
