@@ -13,14 +13,17 @@ This technique can be used to reduce the dimensionality of the data.
 More specifically, the data is projected onto the eigenvectors of the
 covariance matrix.
 """
-from __future__ import absolute_import
 
 import numpy as np
 import numpy.linalg as npl
 
 from ...core.image.image import rollimg
-from ...core.reference.coordinate_map import (io_axis_indices, orth_axes,
-                                              drop_io_dim, AxisError)
+from ...core.reference.coordinate_map import (
+    AxisError,
+    drop_io_dim,
+    io_axis_indices,
+    orth_axes,
+)
 
 
 def pca(data, axis=0, mask=None, ncomp=None, standardize=True,
@@ -34,7 +37,7 @@ def pca(data, axis=0, mask=None, ncomp=None, standardize=True,
     axis : int, optional
        The axis over which to perform PCA (axis identifying
        observations).  Default is 0 (first)
-    mask : ndarray-like (np.bool), optional
+    mask : ndarray-like (np.bool_), optional
        An optional mask, should have shape given by data axes, with
        `axis` removed, i.e.: ``s = data.shape; s.pop(axis);
        msk_shape=s``
@@ -124,7 +127,7 @@ def pca(data, axis=0, mask=None, ncomp=None, standardize=True,
         if not data.shape[1:] == mask.shape:
             raise ValueError('Mask should match dimensions of data other than '
                              'the axis over which to do the PCA')
-    if design_resid == 'mean':
+    if isinstance(design_resid, str) and design_resid == 'mean':
         # equivalent to: design_resid = np.ones((data.shape[0], 1))
         def project_resid(Y):
             return Y - Y.mean(0)[None,...]
@@ -166,7 +169,7 @@ def pca(data, axis=0, mask=None, ncomp=None, standardize=True,
     UX = UX[:,:rank].T
     # calculate covariance matrix in full-rank column space.  The returned
     # array is roughly: YX = dot(UX, data); C = dot(YX, YX.T), perhaps where the
-    # data has been standarized, perhaps summed over slices
+    # data has been standardized, perhaps summed over slices
     C_full_rank  = _get_covariance(data, UX, rmse_scales_func, mask)
     # find the eigenvalues D and eigenvectors Vs of the covariance
     # matrix
@@ -329,10 +332,9 @@ def pca_image(img, axis='t', mask=None, ncomp=None, standardize=True,
     # Which axes are we operating over?
     in_ax, out_ax = io_axis_indices(img.coordmap, axis)
     if None in (in_ax, out_ax):
-        raise AxisError('Cannot identify matching input output axes with "%s"'
-                        % axis)
+        raise AxisError(f'Cannot identify matching input output axes with "{axis}"')
     if not orth_axes(in_ax, out_ax, img.coordmap.affine):
-        raise AxisError('Input and output axes found from "%s" not othogonal '
+        raise AxisError('Input and output axes found from "%s" not orthogonal '
                         'to rest of affine' % axis)
     # Roll the chosen axis to input position zero
     work_img = rollimg(img, axis)
@@ -340,9 +342,9 @@ def pca_image(img, axis='t', mask=None, ncomp=None, standardize=True,
         if not mask.coordmap.similar_to(drop_io_dim(img.coordmap, axis)):
             raise ValueError("Mask should have matching coordmap to `img` "
                              "coordmap with dropped axis %s" % axis)
-    data = work_img.get_data()
+    data = work_img.get_fdata()
     if mask is not None:
-        mask_data = mask.get_data()
+        mask_data = mask.get_fdata()
     else:
         mask_data = None
     # do the PCA
@@ -358,7 +360,7 @@ def pca_image(img, axis='t', mask=None, ncomp=None, standardize=True,
     output_img = img_klass(res['basis_projections'], output_coordmap)
     # We have to roll the axis back to the original position
     output_img = rollimg(output_img, 0, in_ax + 1)
-    key = 'basis_vectors over %s' % axis
+    key = f'basis_vectors over {axis}'
     res[key] = res['basis_vectors']
     res['basis_projections'] = output_img
     # Signal the roll in results
