@@ -6,14 +6,9 @@ by users at the application level. The image provides a coordinate map,
 and the data itself.
 
 """
-from __future__ import absolute_import
 __docformat__ = 'restructuredtext'
 
 # You'd usually use nipy.core.api for these
+
 from . import image
 from .image import Image
-
-from nipy.testing import Tester
-test = Tester().test
-bench = Tester().bench
-
