@@ -60,24 +60,17 @@ Operations on mappings (module level functions)
   range.  For mapping ``m``, this is the same as
   ``product(AffineTransform.identity('concat'), m)``
 """
-from __future__ import absolute_import
 
 import warnings
 
 import numpy as np
 import numpy.linalg as npl
-
-from nibabel.affines import to_matvec, from_matvec
-from ...fixes.nibabel import io_orientation
-
-from .coordinate_system import(CoordinateSystem,
-                               safe_dtype,
-                               is_coordsys,
-                               product as coordsys_product
-                               )
+from nibabel import io_orientation
+from nibabel.affines import from_matvec, to_matvec
 
 # Legacy repr printing from numpy.
-from nipy.testing import legacy_printing as setup_module  # noqa
+from .coordinate_system import CoordinateSystem, is_coordsys, safe_dtype
+from .coordinate_system import product as coordsys_product
 
 # shorthand
 CS = CoordinateSystem
@@ -86,7 +79,7 @@ CS = CoordinateSystem
 TINY = 1e-5
 
 
-class CoordinateMap(object):
+class CoordinateMap:
     """A set of domain and range CoordinateSystems and a function between them.
 
     For example, the function may represent the mapping of a voxel (the
@@ -367,7 +360,7 @@ class CoordinateMap(object):
         """ Return mapping evaluated at x
 
         Also, check x and the return value of self.function for
-        compatiblity with function_domain and function_range coordinate
+        compatibility with function_domain and function_range coordinate
         systems respectively.
 
         Parameters
@@ -430,9 +423,9 @@ class CoordinateMap(object):
 
     def __repr__(self):
         if self.inverse_function is None:
-            return "CoordinateMap(\n   function_domain=%s,\n   function_range=%s,\n   function=%s\n  )" % (self.function_domain, self.function_range, repr(self.function))
+            return f"CoordinateMap(\n   function_domain={self.function_domain},\n   function_range={self.function_range},\n   function={repr(self.function)}\n  )"
         else:
-            return "CoordinateMap(\n   function_domain=%s,\n   function_range=%s,\n   function=%s,\n   inverse_function=%s\n  )" % (self.function_domain, self.function_range, repr(self.function), repr(self.inverse_function))
+            return f"CoordinateMap(\n   function_domain={self.function_domain},\n   function_range={self.function_range},\n   function={repr(self.function)},\n   inverse_function={repr(self.inverse_function)}\n  )"
 
 
     def _checkfunction(self):
@@ -472,7 +465,7 @@ class CoordinateMap(object):
                 and (self.inverse_function == other.inverse_function))
 
 
-class AffineTransform(object):
+class AffineTransform:
     """ Class for affine transformation from domain to a range
 
     This class has an affine attribute, which is a matrix representing
@@ -533,7 +526,7 @@ class AffineTransform(object):
         function_range : :class:`CoordinateSystem`
            output coordinates
         affine : array-like
-           affine homogenous coordinate matrix
+           affine homogeneous coordinate matrix
 
         Notes
         -----
@@ -568,7 +561,7 @@ class AffineTransform(object):
         bottom_row = np.array([0]*self.ndims[0] + [1])
         if not np.all(affine[-1] == bottom_row):
             raise ValueError('the homogeneous transform should have bottom=' + \
-                             'row %s' % repr(bottom_row))
+                             f'row {repr(bottom_row)}')
         self.affine = affine
 
     ###################################################################
@@ -604,14 +597,14 @@ class AffineTransform(object):
 
         Examples
         --------
-        >>> input_cs = CoordinateSystem('ijk', coord_dtype=np.int)
-        >>> output_cs = CoordinateSystem('xyz', coord_dtype=np.int)
+        >>> input_cs = CoordinateSystem('ijk', coord_dtype=np.int_)
+        >>> output_cs = CoordinateSystem('xyz', coord_dtype=np.int_)
         >>> affine = np.array([[1,0,0,1],
         ...                    [0,1,0,1],
         ...                    [0,0,1,1],
         ...                    [0,0,0,1]])
         >>> affine_transform = AffineTransform(input_cs, output_cs, affine)
-        >>> affine_transform([2,3,4]) #doctest: +IGNORE_DTYPE
+        >>> affine_transform([2,3,4]) #doctest: +FIX
         array([3, 4, 5])
 
         The inverse transform, by default, generates a floating point inverse
@@ -625,7 +618,7 @@ class AffineTransform(object):
         `preserve_dtype` flag:
 
         >>> at_inv_preserved = affine_transform.inverse(preserve_dtype=True)
-        >>> at_inv_preserved([2, 6, 12]) #doctest: +IGNORE_DTYPE
+        >>> at_inv_preserved([2, 6, 12]) #doctest: +FIX
         array([  1,   5,  11])
 
         If you `preserve_dtype`, and there is no inverse affine preserving the
@@ -675,7 +668,7 @@ class AffineTransform(object):
         innames : sequence of str or str
            The names of the axes of the domain.  If str, then names
            given by ``list(innames)``
-        outnames : seqence of str or str
+        outnames : sequence of str or str
            The names of the axes of the range. If str, then names
            given by ``list(outnames)``
         params : AffineTransform, array or (array, array)
@@ -717,7 +710,7 @@ class AffineTransform(object):
         innames : sequence of str or str
            The names of the axes of the domain.  If str, then names
            given by ``list(innames)``
-        outnames : seqence of str or str
+        outnames : sequence of str or str
            The names of the axes of the range. If str, then names
            given by ``list(outnames)``
         start : sequence of float
@@ -951,14 +944,14 @@ class AffineTransform(object):
 
         Examples
         --------
-        >>> input_cs = CoordinateSystem('ijk', coord_dtype=np.int)
-        >>> output_cs = CoordinateSystem('xyz', coord_dtype=np.int)
+        >>> input_cs = CoordinateSystem('ijk', coord_dtype=np.int_)
+        >>> output_cs = CoordinateSystem('xyz', coord_dtype=np.int_)
         >>> affine = np.array([[1,0,0,1],
         ...                    [0,1,0,1],
         ...                    [0,0,1,1],
         ...                    [0,0,0,1]])
         >>> affine_transform = AffineTransform(input_cs, output_cs, affine)
-        >>> affine_transform([2,3,4]) #doctest: +IGNORE_DTYPE
+        >>> affine_transform([2,3,4]) #doctest: +FIX
         array([3, 4, 5])
         """
         x = np.asanyarray(x)
@@ -1005,10 +998,9 @@ class AffineTransform(object):
 
     def __repr__(self):
         return ("AffineTransform(\n"
-                "   function_domain=%s,\n"
-                "   function_range=%s,\n"
-                "   affine=%s\n)" %
-                (self.function_domain,
+                "   function_domain={},\n"
+                "   function_range={},\n"
+                "   affine={}\n)".format(self.function_domain,
                  self.function_range,
                  '\n          '.join(repr(self.affine).split('\n'))))
 
@@ -1200,7 +1192,7 @@ def reordered_domain(mapping, order=None):
     ndim = mapping.ndims[0]
     if order is None:
         order = list(range(ndim))[::-1]
-    elif type(order[0]) == type(''):
+    elif type(order[0]) == str:
         order = [mapping.function_domain.index(s) for s in order]
 
     newaxes = [mapping.function_domain.coord_names[i] for i in order]
@@ -1248,7 +1240,7 @@ def shifted_domain_origin(mapping, difference_vector, new_origin):
 
     >>> difference = np.random.standard_normal(5)
 
-    The same affine transforation with a different origin for its domain
+    The same affine transformation with a different origin for its domain
 
     >>> shifted_affine_transform = shifted_domain_origin(affine_transform, difference, 'neworigin')
     >>> shifted_affine_transform.function_domain
@@ -1371,14 +1363,14 @@ def renamed_domain(mapping, newnames, name=''):
     ValueError: no domain coordinate named l
     """
     for key in list(newnames):
-        if type(key) == type(0):
+        if type(key) == int:
             newnames[mapping.function_domain.coord_names[key]] = \
                 newnames[key]
             del(newnames[key])
 
     for key in list(newnames):
         if key not in mapping.function_domain.coord_names:
-            raise ValueError('no domain coordinate named %s' % str(key))
+            raise ValueError(f'no domain coordinate named {str(key)}')
 
     new_coord_names = []
     for n in mapping.function_domain.coord_names:
@@ -1435,14 +1427,14 @@ def renamed_range(mapping, newnames):
     ValueError: no range coordinate named w
     """
     for key in list(newnames):
-        if type(key) == type(0):
+        if type(key) == int:
             newnames[mapping.function_range.coord_names[key]] = \
                 newnames[key]
             del(newnames[key])
 
     for key in list(newnames):
         if key not in mapping.function_range.coord_names:
-            raise ValueError('no range coordinate named %s' % str(key))
+            raise ValueError(f'no range coordinate named {str(key)}')
 
     new_coord_names = []
     for n in mapping.function_range.coord_names:
@@ -1506,7 +1498,7 @@ def reordered_range(mapping, order=None):
     ndim = mapping.ndims[1]
     if order is None:
         order = list(range(ndim))[::-1]
-    elif type(order[0]) == type(''):
+    elif type(order[0]) == str:
         order = [mapping.function_range.index(s) for s in order]
 
     newaxes = [mapping.function_range.coord_names[i] for i in order]
@@ -1693,8 +1685,7 @@ def _compose_cmaps(*cmaps):
         else:
             raise ValueError(
                 'domain and range coordinates do not match: '
-                'domain=%s, range=%s' %
-                (cmap.function_domain.dtype, cur.function_range.dtype))
+                f'domain={cmap.function_domain.dtype}, range={cur.function_range.dtype}')
 
     return cur
 
@@ -1703,7 +1694,7 @@ def _product_cmaps(*cmaps, **kwargs):
     input_name = kwargs.pop('input_name', 'product')
     output_name = kwargs.pop('output_name', 'product')
     if kwargs:
-        raise TypeError('Unexpected kwargs %s' % kwargs)
+        raise TypeError(f'Unexpected kwargs {kwargs}')
     ndimin = [cmap.ndims[0] for cmap in cmaps]
     ndimin.insert(0,0)
     ndimin = tuple(np.cumsum(ndimin))
@@ -1718,9 +1709,9 @@ def _product_cmaps(*cmaps, **kwargs):
         return yy
 
     incoords = coordsys_product(*[cmap.function_domain for cmap in cmaps],
-                                **{'name': input_name})
+                                name=input_name)
     outcoords = coordsys_product(*[cmap.function_range for cmap in cmaps],
-                                **{'name': output_name})
+                                name=output_name)
     return CoordinateMap(incoords, outcoords, function)
 
 
@@ -1730,7 +1721,7 @@ def _product_affines(*affine_mappings, **kwargs):
     input_name = kwargs.pop('input_name', 'product')
     output_name = kwargs.pop('output_name', 'product')
     if kwargs:
-        raise TypeError('Unexpected kwargs %s' % kwargs)
+        raise TypeError(f'Unexpected kwargs {kwargs}')
     if input_name is None:
         input_name = 'product'
     if output_name is None:
@@ -1823,7 +1814,7 @@ def drop_io_dim(cm, axis_id, fix0=True):
     aff = cm.affine.copy()
     # What dimensions did you ask for?
     in_dim, out_dim = io_axis_indices(cm, axis_id, fix0)
-    if not None in (in_dim, out_dim):
+    if None not in (in_dim, out_dim):
         if not orth_axes(in_dim, out_dim, aff, allow_zero=fix0):
             raise AxisError('Input and output dimensions not orthogonal to '
                             'rest of affine')
@@ -1954,7 +1945,7 @@ def axmap(coordmap, direction='in2out', fix0=True):
     """
     in2out = direction in ('in2out', 'both')
     out2in = direction in ('out2in', 'both')
-    if not True in (in2out, out2in):
+    if True not in (in2out, out2in):
         raise ValueError('Direction must be one of "in2out", "out2in", "both"')
     affine = coordmap.affine
     affine = _fix0(affine) if fix0 else affine
@@ -2021,7 +2012,7 @@ def input_axis_index(coordmap, axis_id, fix0=True):
     in_in = axis_id in in_names
     in_out = axis_id in out_names
     if not in_in and not in_out:
-        raise AxisError('Name "%s" not in input or output names' % axis_id)
+        raise AxisError(f'Name "{axis_id}" not in input or output names')
     if in_in:
         in_no = in_names.index(axis_id)
         if not in_out:
@@ -2096,8 +2087,7 @@ def io_axis_indices(coordmap, axis_id, fix0=True):
         elif axis_id in out_dims:
             out_dim = out_dims.index(axis_id)
         else:
-            raise AxisError('No input or output dimension with name (%s)' %
-                            axis_id)
+            raise AxisError(f'No input or output dimension with name ({axis_id})')
         is_str = True
     if out_dim is None:
         out_dim = axmap(coordmap, 'in2out', fix0=fix0)[in_dim]
@@ -2154,7 +2144,7 @@ class CoordMapMakerError(Exception):
     pass
 
 
-class CoordMapMaker(object):
+class CoordMapMaker:
     """ Class to create coordinate maps of different dimensions
     """
     generic_maker = CoordinateMap
@@ -2190,7 +2180,7 @@ class CoordMapMaker(object):
         Parameters
         ----------
         affine : (M, N) array-like
-            Array expressing the affine tranformation
+            Array expressing the affine transformation
         append_zooms : scalar or sequence length E
             If scalar, converted to sequence length E==1. Append E entries to
             the diagonal of `affine` (see examples)
@@ -2311,22 +2301,22 @@ class CoordMapMaker(object):
                                   inv_xform)
 
     def __call__(self, *args, **kwargs):
-        """ Create affine or non-affine coordinate map
+        r""" Create affine or non-affine coordinate map
 
         Parameters
         ----------
-        \\*args :
+        \*args :
             Arguments to ``make_affine`` or ``make_cmap`` methods. We check the
             first argument to see if it is a scalar or an affine, and pass the
-            \\*args, \\*\\*kwargs to ``make_cmap`` or ``make_affine``
+            \*args, \*\*kwargs to ``make_cmap`` or ``make_affine``
             respectively
-        \\*\\*kwargs:
+        \*\*kwargs:
             See above
 
         Returns
         -------
         cmap : ``CoordinateMap`` or ``AffineTransform``
-            Affine if the first \\*arg was an affine array, otherwise a
+            Affine if the first \*arg was an affine array, otherwise a
             Coordinate Map.
         """
         arg0 = np.asarray(args[0])
