@@ -10,18 +10,17 @@ space.  This allows one to compare two CoordinateSystems to determine
 if they are equal.
 
 """
-from __future__ import print_function
-from __future__ import absolute_import
 
 __docformat__ = 'restructuredtext'
 
 import numpy as np
 
+
 class CoordinateSystemError(Exception):
     pass
 
 
-class CoordinateSystem(object):
+class CoordinateSystem:
     """An ordered sequence of named coordinates of a specified dtype.
 
     A coordinate system is defined by the names of the coordinates,
@@ -30,7 +29,7 @@ class CoordinateSystem(object):
     have a name.
 
     >>> names = ['first', 'second', 'third']
-    >>> cs = CoordinateSystem(names, 'a coordinate system', np.float)
+    >>> cs = CoordinateSystem(names, 'a coordinate system', np.float64)
     >>> cs.coord_names
     ('first', 'second', 'third')
     >>> cs.name
@@ -41,7 +40,7 @@ class CoordinateSystem(object):
     The coordinate system also has a ``dtype`` which is the composite
     numpy dtype, made from the (``names``, ``coord_dtype``).
 
-    >>> dtype_template = [(name, np.float) for name in cs.coord_names]
+    >>> dtype_template = [(name, np.float64) for name in cs.coord_names]
     >>> dtype_should_be = np.dtype(dtype_template)
     >>> cs.dtype == dtype_should_be
     True
@@ -49,7 +48,7 @@ class CoordinateSystem(object):
     Two CoordinateSystems are equal if they have the same dtype
     and the same names and the same name.
 
-    >>> another_cs = CoordinateSystem(names, 'not irrelevant', np.float)
+    >>> another_cs = CoordinateSystem(names, 'not irrelevant', np.float64)
     >>> cs == another_cs
     False
     >>> cs.dtype == another_cs.dtype
@@ -72,14 +71,14 @@ class CoordinateSystem(object):
     ndim = 3
     _doc['ndim'] = 'The number of dimensions'
 
-    dtype = np.dtype([('x', np.float),
-                      ('y', np.float),
-                      ('z', np.float)])
+    dtype = np.dtype([('x', np.float64),
+                      ('y', np.float64),
+                      ('z', np.float64)])
     _doc['dtype'] = 'The composite dtype of the CoordinateSystem, ' + \
                     'expresses the fact that there are three numbers, the' + \
                     'first one corresponds to "x" and the second to "y".'
 
-    def __init__(self, coord_names, name='', coord_dtype=np.float):
+    def __init__(self, coord_names, name='', coord_dtype=np.float64):
         """Create a coordinate system with a given name and coordinate names.
 
         The CoordinateSystem has two dtype attributes:
@@ -97,9 +96,9 @@ class CoordinateSystem(object):
            The name of the coordinate system
         coord_dtype : np.dtype, optional
            The dtype of the coord_names.  This should be a built-in
-           numpy scalar dtype. (default is np.float).  The value can
+           numpy scalar dtype. (default is np.float64).  The value can
            by anything that can be passed to the np.dtype constructor.
-           For example ``np.float``, ``np.dtype(np.float)`` or ``f8``
+           For example ``np.float64``, ``np.dtype(np.float64)`` or ``f8``
            all result in the same ``coord_dtype``.
 
         Examples
@@ -120,7 +119,7 @@ class CoordinateSystem(object):
                    np.sctypes['complex'] + np.sctypes['uint'] + [object])
         coord_dtype = np.dtype(coord_dtype)
         if coord_dtype not in sctypes:
-            raise ValueError('Coordinate dtype should be one of %s' % sctypes)
+            raise ValueError(f'Coordinate dtype should be one of {sctypes}')
         # Set all the attributes
         self.name = name
         self.coord_names = coord_names
@@ -133,7 +132,7 @@ class CoordinateSystem(object):
 
     def __setattr__(self, key, value):
         if key in self.__dict__:
-            raise AttributeError('the value of %s has already been set and all attributes are read-only' % key)
+            raise AttributeError(f'the value of {key} has already been set and all attributes are read-only')
         object.__setattr__(self, key, value)
 
     def index(self, coord_name):
@@ -185,8 +184,7 @@ class CoordinateSystem(object):
         -------
         s : string
         """
-        return ("CoordinateSystem(coord_names=%s, name='%s', coord_dtype=%s)" %
-                (self.coord_names, self.name, self.coord_dtype))
+        return ("CoordinateSystem(coord_names={}, name='{}', coord_dtype={})".format(self.coord_names, self.name, self.coord_dtype))
 
 
     def _checked_values(self, arr):
@@ -213,7 +211,7 @@ class CoordinateSystem(object):
         --------
         >>> cs = CoordinateSystem('ijk', coord_dtype=np.float32)
         >>> arr = np.array([1, 2, 3], dtype=np.int16)
-        >>> cs._checked_values(arr) # 1D is OK with matching dimensions 
+        >>> cs._checked_values(arr) # 1D is OK with matching dimensions
         array([[1, 2, 3]], dtype=int16)
         >>> cs._checked_values(arr.reshape(1,3)) # as is 1 by N
         array([[1, 2, 3]], dtype=int16)
@@ -282,9 +280,8 @@ class CoordinateSystem(object):
                                         'CoordinateSystem ndim (%d).\n  %s'
                                         % (arr.shape[-1], self.ndim, str(self)))
         if not np.can_cast(arr.dtype, self.coord_dtype):
-            raise CoordinateSystemError('Cannot cast array dtype %s to '
-                                        'CoordinateSystem coord_dtype %s.\n  %s' %
-                                        (arr.dtype, self.coord_dtype, str(self)))
+            raise CoordinateSystemError('Cannot cast array dtype {} to '
+                                        'CoordinateSystem coord_dtype {}.\n  {}'.format(arr.dtype, self.coord_dtype, str(self)))
         return arr.reshape((-1, self.ndim))
 
 
@@ -336,7 +333,7 @@ def safe_dtype(*dtypes):
     Examples
     --------
     >>> c1 = CoordinateSystem('ij', 'input', coord_dtype=np.float32)
-    >>> c2 = CoordinateSystem('kl', 'input', coord_dtype=np.complex)
+    >>> c2 = CoordinateSystem('kl', 'input', coord_dtype=np.complex_)
     >>> safe_dtype(c1.coord_dtype, c2.coord_dtype)
     dtype('complex128')
 
@@ -378,7 +375,7 @@ def product(*coord_systems, **kwargs):
     ----------
     \*coord_systems : sequence of :class:`CoordinateSystem`
     name : str
-        Name of ouptut coordinate system
+        Name of output coordinate system
 
     Returns
     -------
@@ -387,7 +384,7 @@ def product(*coord_systems, **kwargs):
     Examples
     --------
     >>> c1 = CoordinateSystem('ij', 'input', coord_dtype=np.float32)
-    >>> c2 = CoordinateSystem('kl', 'input', coord_dtype=np.complex)
+    >>> c2 = CoordinateSystem('kl', 'input', coord_dtype=np.complex_)
     >>> c3 = CoordinateSystem('ik', 'in3')
 
     >>> print(product(c1, c2))
@@ -403,7 +400,7 @@ def product(*coord_systems, **kwargs):
     """
     name = kwargs.pop('name', 'product')
     if kwargs:
-        raise TypeError('Unexpected kwargs %s' % kwargs)
+        raise TypeError(f'Unexpected kwargs {kwargs}')
     coords = []
     for c in coord_systems:
         coords += c.coord_names
@@ -415,12 +412,12 @@ class CoordSysMakerError(Exception):
     pass
 
 
-class CoordSysMaker(object):
+class CoordSysMaker:
     """ Class to create similar coordinate maps of different dimensions
     """
     coord_sys_klass = CoordinateSystem
 
-    def __init__(self, coord_names, name='', coord_dtype=np.float):
+    def __init__(self, coord_names, name='', coord_dtype=np.float64):
         """Create a coordsys maker with given axis `coord_names`
 
         Parameters
@@ -431,9 +428,9 @@ class CoordSysMaker(object):
            The name of the coordinate system
         coord_dtype : np.dtype, optional
            The dtype of the coord_names.  This should be a built-in
-           numpy scalar dtype. (default is np.float).  The value can
+           numpy scalar dtype. (default is np.float64).  The value can
            by anything that can be passed to the np.dtype constructor.
-           For example ``np.float``, ``np.dtype(np.float)`` or ``f8``
+           For example ``np.float64``, ``np.dtype(np.float64)`` or ``f8``
            all result in the same ``coord_dtype``.
 
         Examples
