@@ -10,21 +10,17 @@ Examples
 --------
 See documentation for load and save functions for worked examples.
 """
-from __future__ import absolute_import
 
 import os
 
-import numpy as np
-
 import nibabel as nib
+import numpy as np
 from nibabel.spatialimages import HeaderDataError
 
 from ..core.image.image import is_image
+from .nibcompat import get_affine, get_dataobj, get_header
+from .nifti_ref import nifti2nipy, nipy2nifti
 
-from .nifti_ref import (nipy2nifti, nifti2nipy)
-from .nibcompat import get_dataobj, get_affine, get_header
-
-from ..externals.six import string_types
 
 def load(filename):
     """Load an image from the given filename.
@@ -52,7 +48,7 @@ def load(filename):
     >>> img.shape
     (33, 41, 25)
     """
-    if filename.endswith('.mnc'):
+    if str(filename).endswith('.mnc'):
         raise ValueError("Sorry, we can't get the MINC axis names right yet")
     img = nib.load(filename)
     # Deal with older nibabel
@@ -133,12 +129,12 @@ def save(img, filename, dtype_from='data'):
     * SPM Analyze : ['.img', '.img.gz']
     """
     # Try and get nifti
-    dt_from_is_str = isinstance(dtype_from, string_types)
+    dt_from_is_str = isinstance(dtype_from, str)
     if dt_from_is_str and dtype_from == 'header':
         # All done
         io_dtype = None
     elif dt_from_is_str and dtype_from == 'data':
-        io_dtype = img.get_data().dtype
+        io_dtype = img.get_fdata().dtype
     else:
         io_dtype = np.dtype(dtype_from)
     # make new image
@@ -154,7 +150,7 @@ def save(img, filename, dtype_from='data'):
                                   ni_img.get_data_dtype())
         ana_img.to_filename(filename)
     else:
-        raise ValueError('Sorry, we cannot yet save as format "%s"' % ftype)
+        raise ValueError(f'Sorry, we cannot yet save as format "{ftype}"')
     return img
 
 
@@ -181,6 +177,7 @@ def _type_from_filename(filename):
     >>> _type_from_filename('test.mnc')
     'minc'
     '''
+    filename = str(filename)
     if filename.endswith('.gz'):
         filename = filename[:-3]
     elif filename.endswith('.bz2'):
@@ -194,7 +191,7 @@ def _type_from_filename(filename):
         return 'analyze'
     if ext == '.mnc':
         return 'minc'
-    raise ValueError('Strange file extension "%s"' % ext)
+    raise ValueError(f'Strange file extension "{ext}"')
 
 
 def as_image(image_input):
@@ -227,6 +224,6 @@ def as_image(image_input):
     '''
     if is_image(image_input):
         return image_input
-    if isinstance(image_input, string_types):
+    if isinstance(image_input, str):
         return load(image_input)
     raise TypeError('Expecting an image-like object or filename string')
