@@ -1,6 +1,5 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import absolute_import, print_function
 
 import time
 
@@ -16,25 +15,24 @@ def time_ratio(t0,t1):
         return t0/t1
 
 def time_copy_vector(x):
-    t0 = time.clock()
-    y0 = copy_vector(x, 0) 
-    dt0 = time.clock()-t0
-    t1 = time.clock()
-    y1 = copy_vector(x, 1) 
-    dt1 = time.clock()-t1
+    t0 = time.process_time()
+    y0 = copy_vector(x, 0)
+    dt0 = time.process_time()-t0
+    t1 = time.process_time()
+    y1 = copy_vector(x, 1)
+    dt1 = time.process_time()-t1
     ratio = time_ratio(dt0,dt1)
-    print('  using fff_array: %f sec' % dt0)
-    print('  using numpy C API: %f sec' % dt1)
-    print('  ratio: %f' % ratio)
+    print(f'  using fff_array: {dt0:f} sec')
+    print(f'  using numpy C API: {dt1:f} sec')
+    print(f'  ratio: {ratio:f}')
 
-def bench_copy_vector_contiguous(): 
-    x = (1000*np.random.rand(1e6)).astype('int32')
+def bench_copy_vector_contiguous():
+    x = (1000*np.random.rand(1_000_000)).astype('int32')
     print('Contiguous buffer copy (int32-->double)')
     time_copy_vector(x)
 
-def bench_copy_vector_strided(): 
-    x0 = (1000*np.random.rand(2e6)).astype('int32')
+def bench_copy_vector_strided():
+    x0 = (1000*np.random.rand(2_000_000)).astype('int32')
     x = x0[::2]
     print('Non-contiguous buffer copy (int32-->double)')
     time_copy_vector(x)
-
