@@ -1,18 +1,23 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 # Test numpy bindings
-from __future__ import absolute_import
 
 import numpy as np
-
-from .. import (c_types, fff_type, npy_type, copy_vector, pass_matrix,
-                pass_vector, pass_array, pass_vector_via_iterator,
-                sum_via_iterators, copy_via_iterators)
-
-
-from nose.tools import assert_equal
 from numpy.testing import assert_almost_equal, assert_array_equal
 
+from .. import (
+    c_types,
+    copy_vector,
+    copy_via_iterators,
+    fff_type,
+    npy_type,
+    pass_array,
+    pass_matrix,
+    pass_vector,
+    pass_vector_via_iterator,
+    sum_via_iterators,
+)
+
 MAX_TEST_SIZE = 30
 def random_shape(size):
     """
@@ -37,27 +42,27 @@ def test_type_conversions_to_fff():
     for type_key in np.sctypes:
         for npy_t in np.sctypes[type_key]:
             t, nbytes = fff_type(np.dtype(npy_t))
-            if not t == 'unknown type':
-                yield assert_equal, nbytes, np.dtype(npy_t).itemsize
+            if t != 'unknown type':
+                assert nbytes == np.dtype(npy_t).itemsize
 
 
 def test_type_conversions_in_C():
     for t in c_types:
         npy_t, nbytes = npy_type(t)
-        yield assert_equal, npy_t, t
+        assert npy_t == t
 
 
 #
-# Test bindings 
+# Test bindings
 #
 
 def _test_copy_vector(x):
     # use fff
     y0 = copy_vector(x, 0)
     # use numpy
-    y1 = copy_vector(x, 1) 
-    yield assert_equal, y0, x
-    yield assert_equal, y1, x
+    y1 = copy_vector(x, 1)
+    assert_array_equal(y0, x)
+    assert_array_equal(y1, x)
 
 
 def test_copy_vector_contiguous():
@@ -70,12 +75,12 @@ def test_copy_vector_strided():
     _test_copy_vector(x)
 
 """
-def test_copy_vector_int32(): 
+def test_copy_vector_int32():
     x = np.random.rand(1e6).astype('int32')
     print('int32 buffer copy')
     _test_copy_vector(x)
 
-def test_copy_vector_uint8(): 
+def test_copy_vector_uint8():
     x = np.random.rand(1e6).astype('uint8')
     print('uint8 buffer copy')
     _test_copy_vector(x)
@@ -103,9 +108,9 @@ def test_pass_vector_uint8():
 
 def _test_pass_matrix(x):
     y = pass_matrix(x)
-    yield assert_equal, y, x
+    assert_array_equal(y, x)
     y = pass_matrix(x.T)
-    yield assert_equal, y, x.T
+    assert_array_equal(y, x.T)
 
 
 def test_pass_matrix():
@@ -128,9 +133,9 @@ def test_pass_matrix_uint8():
 
 def _test_pass_array(x):
     y = pass_array(x)
-    yield assert_equal, y, x
+    assert_array_equal(y, x)
     y = pass_array(x.T)
-    yield assert_equal, y, x.T
+    assert_array_equal(y, x.T)
 
 
 def test_pass_array():
@@ -139,7 +144,7 @@ def test_pass_array():
     _test_pass_array(x)
 
 
-def test_pass_array_int32(): 
+def test_pass_array_int32():
     d0, d1, d2, d3 = random_shape(4)
     x = (1000*(np.random.rand(d0, d1, d2, d3)-.5)).astype('int32')
     _test_pass_array(x)
@@ -151,24 +156,24 @@ def test_pass_array_uint8():
     _test_pass_array(x)
 
 #
-# Multi-iterator testing 
+# Multi-iterator testing
 #
 
 def _test_pass_vector_via_iterator(X, pos=0):
     """
     Assume X.ndim == 2
     """
-    # axis == 0 
+    # axis == 0
     x = pass_vector_via_iterator(X, axis=0, niters=pos)
-    yield assert_equal, x, X[:, pos]
+    assert_array_equal(x, X[:, pos])
     # axis == 1
     x = pass_vector_via_iterator(X, axis=1, niters=pos)
-    yield assert_equal, x, X[pos, :]
+    assert_array_equal(x, X[pos, :])
 
 
 def test_pass_vector_via_iterator():
     d0, d1 = random_shape(2)
-    X = np.random.rand(d0, d1)-.5 
+    X = np.random.rand(d0, d1)-.5
     _test_pass_vector_via_iterator(X)
 
 
@@ -186,7 +191,7 @@ def test_pass_vector_via_iterator_uint8():
 
 def test_pass_vector_via_iterator_shift():
     d0, d1 = random_shape(2)
-    X = np.random.rand(d0, d1)-.5 
+    X = np.random.rand(d0, d1)-.5
     _test_pass_vector_via_iterator(X, pos=1)
 
 
@@ -205,9 +210,9 @@ def test_pass_vector_via_iterator_shift_uint8():
 def _test_copy_via_iterators(Y):
     for axis in range(4):
         Z = copy_via_iterators(Y, axis)
-        yield assert_equal, Z, Y
+        assert_array_equal(Z, Y)
         ZT = copy_via_iterators(Y.T, axis)
-        yield assert_equal, ZT, Y.T 
+        assert_array_equal(ZT, Y.T)
 
 
 def test_copy_via_iterators():
@@ -231,9 +236,9 @@ def test_copy_via_iterators_uint8():
 def _test_sum_via_iterators(Y):
     for axis in range(4):
         Z = sum_via_iterators(Y, axis)
-        yield assert_almost_equal, Z, Y.sum(axis)
+        assert_almost_equal(Z, Y.sum(axis))
         ZT = sum_via_iterators(Y.T, axis)
-        yield assert_almost_equal, ZT, Y.T.sum(axis)
+        assert_almost_equal(ZT, Y.T.sum(axis))
 
 
 def test_sum_via_iterators():
@@ -252,8 +257,3 @@ def test_sum_via_iterators_uint8():
     d0, d1, d2, d3 = random_shape(4)
     Y = (256*(np.random.rand(d0, d1, d2, d3))).astype('uint8')
     _test_sum_via_iterators(Y)
-
-
-if __name__ == "__main__":
-    import nose
-    nose.run(argv=['', __file__])
