@@ -1,21 +1,19 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
-Conversion mechansims for IO and interaction between volumetric datasets 
+Conversion mechanisms for IO and interaction between volumetric datasets
 and other type of neuroimaging data.
 """
-from __future__ import absolute_import
 import os
 
-import numpy as np
-
 import nibabel as nib
+import numpy as np
 from nibabel.spatialimages import SpatialImage
 
-from nipy.io.nibcompat import get_header, get_affine
+from nipy.io.nibcompat import get_affine, get_header
+
 from .volumes.volume_img import VolumeImg
 
-from nipy.externals.six import string_types
 
 def as_volume_img(obj, copy=True, squeeze=True, world_space=None):
     """ Convert the input to a VolumeImg.
@@ -27,7 +25,7 @@ def as_volume_img(obj, copy=True, squeeze=True, world_space=None):
             VolumeImg. This includes Nifti filenames, pynifti or brifti
             objects, or other volumetric dataset objects.
         copy: boolean, optional
-            If copy is True, the data and affine arrays are copied, 
+            If copy is True, the data and affine arrays are copied,
             elsewhere a view is taken.
         squeeze: boolean, optional
             If squeeze is True, the data array is squeeze on for
@@ -57,14 +55,14 @@ def as_volume_img(obj, copy=True, squeeze=True, world_space=None):
             obj = obj.__copy__()
         return obj
 
-    elif isinstance(obj, string_types):
+    elif isinstance(obj, str):
         if not os.path.exists(obj):
-            raise ValueError("The file '%s' cannot be found" % obj)
+            raise ValueError(f"The file '{obj}' cannot be found")
         obj = nib.load(obj)
         copy = False
 
     if isinstance(obj, SpatialImage):
-        data   = obj.get_data()
+        data   = obj.get_fdata()
         affine = get_affine(obj)
         header = dict(get_header(obj))
         fname = obj.file_map['image'].filename
@@ -80,8 +78,8 @@ def as_volume_img(obj, copy=True, squeeze=True, world_space=None):
         if filename != '':
             header['filename'] = filename
     else:
-        raise ValueError('Invalid type (%s) passed in: cannot convert %s to '
-                    'VolumeImg' % (type(obj), obj))
+        raise ValueError('Invalid type ({}) passed in: cannot convert {} to '
+                    'VolumeImg'.format(type(obj), obj))
 
     if world_space is None and header.get('sform_code', 0) == 4:
         world_space = 'mni152'
@@ -97,7 +95,7 @@ def as_volume_img(obj, copy=True, squeeze=True, world_space=None):
         shape = [val for index, val in enumerate(data.shape)
                      if val !=1 or index < 3]
         data = np.reshape(data, shape)
-    
+
     return VolumeImg(data, affine, world_space, metadata=header)
 
 
@@ -109,8 +107,7 @@ def save(filename, obj):
     for key, value in obj.metadata.items():
         if key in hdr:
             hdr[key] = value
-    img = nib.Nifti1Image(obj.get_data(),
+    img = nib.Nifti1Image(obj.get_fdata(),
                           obj.affine,
                           header=hdr)
     nib.save(img, filename)
-
