@@ -1,9 +1,9 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
-The volume grid class. 
+The volume grid class.
 
-This class represents data lying on a (non rigid, non regular) grid embedded 
+This class represents data lying on a (non rigid, non regular) grid embedded
 in a 3D world represented as a 3+D array.
 """
 
@@ -12,10 +12,10 @@ import copy as copy
 import numpy as np
 from scipy import ndimage
 
-# Local imports
-from .volume_data import VolumeData
 from ..transforms.affine_utils import apply_affine, from_matrix_vector
 
+# Local imports
+from .volume_data import VolumeData
 
 ################################################################################
 # class `VolumeGrid`
@@ -25,7 +25,7 @@ class VolumeGrid(VolumeData):
     """ A class representing data stored in a 3+D array embedded in a 3D
         world.
 
-        This object has data stored in an array-like multidimensional 
+        This object has data stored in an array-like multidimensional
         indexable objects, with the 3 first dimensions corresponding to
         spatial axis and defining a 3D grid that may be non-regular or
         non-rigid.
@@ -39,16 +39,16 @@ class VolumeGrid(VolumeData):
         Attributes
         -----------
 
-        world_space: string 
+        world_space: string
             World space the data is embedded in. For instance `mni152`.
 
-        metadata: dictionnary
-            Optional, user-defined, dictionnary used to carry around
+        metadata: dictionary
+            Optional, user-defined, dictionary used to carry around
             extra information about the data as it goes through
             transformations. The consistency of this information is not
             maintained as the data is modified.
 
-        _data: 
+        _data:
             Private pointer to the data.
 
         Notes
@@ -57,11 +57,11 @@ class VolumeGrid(VolumeData):
         The data is stored in an undefined way: prescalings might need to
         be applied to it before using it, or the data might be loaded on
         demand. The best practice to access the data is not to access the
-        _data attribute, but to use the `get_data` method.
+        _data attribute, but to use the `get_fdata` method.
 
         If the transform associated with the image has no inverse
         mapping, data corresponding to a given world space position cannot
-        be calulated. If it has no forward mapping, it is impossible to
+        be calculated. If it has no forward mapping, it is impossible to
         resample another dataset on the same support.
     """
     #---------------------------------------------------------------------------
@@ -80,26 +80,26 @@ class VolumeGrid(VolumeData):
                 first dimensions being spatial.
             transform: nipy transform object
                 The transformation from voxel to world.
-            metadata : dictionnary, optional
-                Dictionnary of user-specified information to store with
+            metadata : dictionary, optional
+                Dictionary of user-specified information to store with
                 the image.
             interpolation : 'continuous' or 'nearest', optional
                 Interpolation type used when calculating values in
                 different word spaces.
         """
-        if not interpolation in ('continuous', 'nearest'):
+        if interpolation not in ('continuous', 'nearest'):
             raise ValueError('interpolation must be either continuous '
                              'or nearest')
         self._data       = data
         self._transform  = transform
         self.world_space = transform.output_space
         if metadata is None:
-            metadata = dict()
+            metadata = {}
         self.metadata = metadata
         self.interpolation = interpolation
 
 
-    def as_volume_img(self, affine=None, shape=None, 
+    def as_volume_img(self, affine=None, shape=None,
                                         interpolation=None, copy=True):
         if affine is None:
             affine = np.eye(3)
@@ -123,7 +123,7 @@ class VolumeGrid(VolumeData):
                 shape = (np.ceil(xmax - xmin)+1,
                          np.ceil(ymax - ymin)+1,
                          np.ceil(zmax - zmin)+1, )
-        shape = list(shape)
+        shape = [int(s) for s in shape]
         if not len(shape) == 3:
             raise ValueError('The shape specified should be the shape '
                 'the 3D grid, and thus of length 3. %s was specified'
@@ -133,7 +133,7 @@ class VolumeGrid(VolumeData):
         values = self.values_in_world(x, y, z)
         # We import late to avoid circular import
         from .volume_img import VolumeImg
-        return VolumeImg(values, affine, 
+        return VolumeImg(values, affine,
                            self.world_space, metadata=self.metadata,
                            interpolation=self.interpolation)
 
@@ -175,10 +175,10 @@ class VolumeGrid(VolumeData):
 
 
     def get_transform(self):
-        """ Returns the transform object associated with the image which is a 
-            general description of the mapping from the voxel space to the 
+        """ Returns the transform object associated with the image which is a
+            general description of the mapping from the voxel space to the
             world space.
-            
+
             Returns
             -------
             transform : nipy.core.Transform object
@@ -191,18 +191,18 @@ class VolumeGrid(VolumeData):
 
 
     def values_in_world(self, x, y, z, interpolation=None):
-        """ Return the values of the data at the world-space positions given by 
+        """ Return the values of the data at the world-space positions given by
             x, y, z
 
             Parameters
             ----------
             x : number or ndarray
-                x positions in world space, in other words milimeters
+                x positions in world space, in other words millimeters
             y : number or ndarray
-                y positions in world space, in other words milimeters.
+                y positions in world space, in other words millimeters.
                 The shape of y should match the shape of x
             z : number or ndarray
-                z positions in world space, in other words milimeters.
+                z positions in world space, in other words millimeters.
                 The shape of z should match the shape of x
             interpolation : None, 'continuous' or 'nearest', optional
                 Interpolation type used when calculating values in
@@ -238,11 +238,11 @@ class VolumeGrid(VolumeData):
         # See: https://github.com/scipy/scipy/pull/64
         if coords.dtype == np.dtype(np.intp):
             coords = coords.astype(np.dtype(coords.dtype.str))
-        data = self.get_data()
+        data = self.get_fdata()
         data_shape = list(data.shape)
         n_dims = len(data_shape)
         if n_dims > 3:
-            # Iter in a set of 3D volumes, as the interpolation problem is 
+            # Iter in a set of 3D volumes, as the interpolation problem is
             # separable in the extra dimensions. This reduces the
             # computational cost
             data = np.reshape(data, data_shape[:3] + [-1])
@@ -261,4 +261,3 @@ class VolumeGrid(VolumeData):
 
     # Inherit docstring
     values_in_world.__doc__ = VolumeData.values_in_world.__doc__
-
