@@ -4,19 +4,17 @@
 Utilities for extracting masks from EPI images and applying them to time
 series.
 """
-from __future__ import absolute_import
 
 import math
 
 # Major scientific libraries imports
 import numpy as np
-from scipy import ndimage
 
 # Neuroimaging libraries imports
 from nibabel import load, nifti1, save
+from scipy import ndimage
 
-from ..io.nibcompat import get_header, get_affine, get_unscaled_data
-from ..externals.six import string_types
+from ..io.nibcompat import get_affine, get_header, get_unscaled_data
 
 ###############################################################################
 # Operating on connect component
@@ -41,8 +39,8 @@ def largest_cc(mask):
     if not label_nb:
         raise ValueError('No non-zero values: no connected components')
     if label_nb == 1:
-        return mask.astype(np.bool)
-    label_count = np.bincount(labels.ravel().astype(np.int))
+        return mask.astype(np.bool_)
+    label_count = np.bincount(labels.ravel().astype(np.int_))
     # discard 0 the 0 label
     label_count[0] = 0
     return labels == label_count.argmax()
@@ -126,7 +124,7 @@ def compute_mask_files(input_filename, output_filename=None,
         The main of all the images used to estimate the mask. Only
         provided if `return_mean` is True.
     """
-    if isinstance(input_filename, string_types):
+    if isinstance(input_filename, str):
         # One single filename or image
         nim = load(input_filename)  # load the image from the path
         vol_arr = get_unscaled_data(nim)
@@ -159,12 +157,12 @@ def compute_mask_files(input_filename, output_filename=None,
         for index, filename in enumerate(input_filename):
             nim = load(filename)
             if index == 0:
-                first_volume = nim.get_data().squeeze()
+                first_volume = nim.get_fdata().squeeze()
                 mean_volume = first_volume.copy().astype(np.float32)
                 header = get_header(nim)
                 affine = get_affine(nim)
             else:
-                mean_volume += nim.get_data().squeeze()
+                mean_volume += nim.get_fdata().squeeze()
         mean_volume /= float(len(list(input_filename)))
     del nim
     if np.isnan(mean_volume).any():
@@ -246,7 +244,7 @@ def compute_mask(mean_volume, reference_volume=None, m=0.2, M=0.9,
         mask = largest_cc(mask)
 
     if opening > 0:
-        mask = ndimage.binary_opening(mask.astype(np.int),
+        mask = ndimage.binary_opening(mask.astype(np.int_),
                                         iterations=opening)
     return mask.astype(bool)
 
@@ -255,7 +253,7 @@ def compute_mask_sessions(session_images, m=0.2, M=0.9, cc=1, threshold=0.5,
                           exclude_zeros=False, return_mean=False, opening=2):
     """ Compute a common mask for several sessions of fMRI data.
 
-        Uses the mask-finding algorithmes to extract masks for each
+        Uses the mask-finding algorithms to extract masks for each
         session, and then keep only the main connected component of the
         a given fraction of the intersection of all the masks.
 
@@ -282,7 +280,7 @@ def compute_mask_sessions(session_images, m=0.2, M=0.9, cc=1, threshold=0.5,
         threshold. This option is useful if the images have been
         resliced with a large padding of zeros.
     return_mean: boolean, optional
-        if return_mean is True, the mean image accross subjects is
+        if return_mean is True, the mean image across subjects is
         returned.
     opening: int, optional,
              size of  the morphological opening
@@ -296,8 +294,8 @@ def compute_mask_sessions(session_images, m=0.2, M=0.9, cc=1, threshold=0.5,
     """
     mask, mean = None, None
     for index, session in enumerate(session_images):
-        if hasattr(session, 'get_data'):
-            mean = session.get_data()
+        if hasattr(session, 'get_fdata'):
+            mean = session.get_fdata()
             if mean.ndim > 3:
                 mean = mean.mean(-1)
             this_mask = compute_mask(mean, None, m=m, M=M, cc=cc,
@@ -311,7 +309,7 @@ def compute_mask_sessions(session_images, m=0.2, M=0.9, cc=1, threshold=0.5,
         if return_mean:
             this_mask, this_mean = this_mask
             if mean is None:
-                mean = this_mean.astype(np.float)
+                mean = this_mean.astype(np.float64)
             else:
                 mean += this_mean
         this_mask = this_mask.astype(np.int8)
@@ -330,7 +328,7 @@ def compute_mask_sessions(session_images, m=0.2, M=0.9, cc=1, threshold=0.5,
         # Select the largest connected component (each mask is
         # connect, but the half-interesection may not be):
         mask = largest_cc(mask)
-    mask = mask.astype(np.bool)
+    mask = mask.astype(np.bool_)
 
     if return_mean:
         # Divide by the number of sessions
@@ -371,11 +369,11 @@ def intersect_masks(input_masks, output_filename=None, threshold=0.5, cc=True):
     threshold = min(threshold, 1 - 1.e-7)
 
     for this_mask in input_masks:
-        if isinstance(this_mask, string_types):
+        if isinstance(this_mask, str):
             # We have a filename
-            this_mask = load(this_mask).get_data()
+            this_mask = load(this_mask).get_fdata()
         if grp_mask is None:
-            grp_mask = this_mask.copy().astype(np.int)
+            grp_mask = this_mask.copy().astype(np.int_)
         else:
             # If this_mask is floating point and grp_mask is integer, numpy 2
             # casting rules raise an error for in-place addition.
@@ -389,12 +387,12 @@ def intersect_masks(input_masks, output_filename=None, threshold=0.5, cc=True):
         grp_mask = largest_cc(grp_mask)
 
     if output_filename is not None:
-        if isinstance(input_masks[0], string_types):
+        if isinstance(input_masks[0], str):
             nim = load(input_masks[0])
             header = get_header(nim)
             affine = get_affine(nim)
         else:
-            header = dict()
+            header = {}
             affine = np.eye(4)
         header['descrip'] = 'mask image'
         output_image = nifti1.Nifti1Image(grp_mask.astype(np.uint8),
@@ -437,20 +435,20 @@ def series_from_mask(filenames, mask, dtype=np.float32,
     Notes
     -----
     When using smoothing, ensure_finite should be True: as elsewhere non
-    finite values will spread accross the image.
+    finite values will spread across the image.
     """
     assert len(filenames) != 0, (
         'filenames should be a file name or a list of file names, '
-        '%s (type %s) was passed' % (filenames, type(filenames)))
-    mask = mask.astype(np.bool)
+        f'{filenames} (type {type(filenames)}) was passed')
+    mask = mask.astype(np.bool_)
     if smooth:
         # Convert from a sigma to a FWHM:
         smooth /= np.sqrt(8 * np.log(2))
-    if isinstance(filenames, string_types):
+    if isinstance(filenames, str):
         # We have a 4D nifti file
         data_file = load(filenames)
         header = get_header(data_file)
-        series = data_file.get_data()
+        series = data_file.get_fdata()
         if ensure_finite:
             # SPM tends to put NaNs in the data outside the brain
             series[np.logical_not(np.isfinite(series))] = 0
@@ -471,7 +469,7 @@ def series_from_mask(filenames, mask, dtype=np.float32,
         series = np.zeros((mask.sum(), nb_time_points), dtype=dtype)
         for index, filename in enumerate(filenames):
             data_file = load(filename)
-            data = data_file.get_data()
+            data = data_file.get_fdata()
             if ensure_finite:
                 # SPM tends to put NaNs in the data outside the brain
                 data[np.logical_not(np.isfinite(data))] = 0
