@@ -6,17 +6,17 @@ This is meant to provide a unified API to deal with n-d imaged and meshes.
 
 Author: Bertrand Thirion, 2010
 """
-from __future__ import absolute_import
+
 import numpy as np
 import scipy.sparse as sp
+from nibabel import Nifti1Image, load, save
 
-from nibabel import load, Nifti1Image, save
-
-from nipy.io.nibcompat import get_header, get_affine
-from nipy.algorithms.graph import (WeightedGraph, wgraph_from_coo_matrix,
-                                   wgraph_from_3d_grid)
-
-from nipy.externals.six import string_types
+from nipy.algorithms.graph import (
+    WeightedGraph,
+    wgraph_from_3d_grid,
+    wgraph_from_coo_matrix,
+)
+from nipy.io.nibcompat import get_affine, get_header
 
 ##############################################################
 # Ancillary functions
@@ -71,7 +71,7 @@ def smatrix_from_nd_array(mask, nn=0):
     mask : nd array,
            input array, interpreted as a mask
     nn: int, optional
-        nd neighboring system, unsused at the moment
+        nd neighboring system, unused at the moment
 
     Returns
     -------
@@ -201,13 +201,13 @@ def domain_from_binary_array(mask, affine=None, nn=0):
     Parameters
     ----------
     mask: np.array instance
-          a supposedly boolean array that repesents the domain
+          a supposedly boolean array that represents the domain
     affine: np.array, optional
             affine transform that maps the array coordinates
             to some embedding space
             by default, this is np.eye(dim+1, dim+1)
     nn: neighboring system considered
-        unsued at the moment
+        unused at the moment
 
     """
     dim = len(mask.shape)
@@ -226,7 +226,7 @@ def domain_from_image(mim, nn=18):
     Parameters
     ----------
     mim: NiftiIImage instance, or string path toward such an image
-         supposedly a mask (where is used to crate the DD)
+         supposedly a mask (where is used to create the DD)
     nn: int, optional
         neighboring system considered from the image
         can be 6, 18 or 26
@@ -236,11 +236,11 @@ def domain_from_image(mim, nn=18):
     The corresponding StructuredDomain instance
 
     """
-    if isinstance(mim, string_types):
+    if isinstance(mim, str):
         iim = load(mim)
     else:
         iim = mim
-    return domain_from_binary_array(iim.get_data(), get_affine(iim), nn)
+    return domain_from_binary_array(iim.get_fdata(), get_affine(iim), nn)
 
 
 def grid_domain_from_binary_array(mask, affine=None, nn=0):
@@ -249,13 +249,13 @@ def grid_domain_from_binary_array(mask, affine=None, nn=0):
     Parameters
     ----------
     mask: np.array instance
-          a supposedly boolean array that repesents the domain
+          a supposedly boolean array that represents the domain
     affine: np.array, optional
             affine transform that maps the array coordinates
             to some embedding space
             by default, this is np.eye(dim+1, dim+1)
     nn: neighboring system considered
-        unsued at the moment
+        unused at the moment
 
     """
     dim = len(mask.shape)
@@ -276,7 +276,7 @@ def grid_domain_from_image(mim, nn=18):
     Parameters
     ----------
     mim: NiftiIImage instance, or string path toward such an image
-         supposedly a mask (where is used to crate the DD)
+         supposedly a mask (where is used to create the DD)
     nn: int, optional
         neighboring system considered from the image
         can be 6, 18 or 26
@@ -286,11 +286,11 @@ def grid_domain_from_image(mim, nn=18):
     The corresponding NDGridDomain instance
 
     """
-    if isinstance(mim, string_types):
+    if isinstance(mim, str):
         iim = load(mim)
     else:
         iim = mim
-    return grid_domain_from_binary_array(iim.get_data(), get_affine(iim), nn)
+    return grid_domain_from_binary_array(iim.get_fdata(), get_affine(iim), nn)
 
 
 def grid_domain_from_shape(shape, affine=None):
@@ -323,7 +323,7 @@ def grid_domain_from_shape(shape, affine=None):
 ################################################################
 
 
-class MeshDomain(object):
+class MeshDomain:
     """
     temporary class to handle meshes
     """
@@ -412,7 +412,7 @@ def domain_from_mesh(mesh):
     mesh: nibabel gifti mesh instance, or path to such a mesh
 
     """
-    if isinstance(mesh, string_types):
+    if isinstance(mesh, str):
         from nibabel.gifti import read
         mesh_ = read(mesh)
     else:
@@ -423,8 +423,7 @@ def domain_from_mesh(mesh):
     elif len(mesh_.darrays) == 3:
         cor, nor, tri = mesh_.darrays
     else:
-        raise Exception("%d arrays in gifti file (case not handled)" \
-                            % len(mesh_.darrays))
+        raise Exception(f"{len(mesh_.darrays)} arrays in gifti file (case not handled)")
     mesh_dom = MeshDomain(cor.data, tri.data)
 
     vol = mesh_dom.area()
@@ -438,7 +437,7 @@ def domain_from_mesh(mesh):
 ################################################################
 
 
-class DiscreteDomain(object):
+class DiscreteDomain:
     """
     Descriptor of a certain domain that consists of discrete elements that
     are characterized by a coordinate system and a topology:
@@ -756,8 +755,7 @@ class NDGridDomain(StructuredDomain):
             wdata[wdata > 0] = data
 
         nim = Nifti1Image(wdata, self.affine)
-        get_header(nim)['descrip'] = ('mask image representing domain %s'
-                                      % self.id)
+        get_header(nim)['descrip'] = f'mask image representing domain {self.id}'
         if path is not None:
             save(nim, path)
         return nim
@@ -775,10 +773,10 @@ class NDGridDomain(StructuredDomain):
 
         Returns
         -------
-        the correponding set of values
+        the corresponding set of values
 
         """
-        if isinstance(path, string_types):
+        if isinstance(path, str):
             nim = load(path)
         else:
             nim = path
@@ -786,9 +784,9 @@ class NDGridDomain(StructuredDomain):
         if (get_affine(nim) != self.affine).any():
             raise ValueError('nim and self do not have the same referential')
 
-        data = nim.get_data()
+        data = nim.get_fdata()
         feature = data[self.ijk[:, 0], self.ijk[:, 1], self.ijk[:, 2]]
-        if fid is not '':
+        if fid != '':
             self.features[fid] = feature
 
         return feature
