@@ -5,7 +5,6 @@
 Computation of parcellations using a hierarchical approach.
 Author: Bertrand Thirion, 2008
 """
-from __future__ import print_function, absolute_import
 
 from warnings import warn
 
@@ -13,12 +12,12 @@ import numpy as np
 from numpy.random import rand
 
 from nipy.algorithms.clustering.utils import kmeans, voronoi
-from .parcellation import MultiSubjectParcellation
 from nipy.algorithms.graph.field import Field
 from nipy.algorithms.graph.graph import wgraph_from_coo_matrix
 
+from .parcellation import MultiSubjectParcellation
 
-warn('Module nipy.labs.spatial_models.hierarchical_parcellation' + 
+warn('Module nipy.labs.spatial_models.hierarchical_parcellation' +
      'deprecated, will be removed',
      FutureWarning,
      stacklevel=2)
@@ -91,12 +90,12 @@ def _exclusion_map_dep(i, ref, target, targeti):
     i (int): index of the structure under consideration
     ref: Field that represent the topological structure of parcels
          and their standard position
-    target: array of shape (ref.V,3): current posistion of the parcels
+    target: array of shape (ref.V,3): current position of the parcels
     targeti array of shape (n,3): possible new positions for the ith item
 
     Returns
     -------
-    emap: aray of shape (n): a potential that yields the fitness
+    emap: array of shape (n): a potential that yields the fitness
           of the proposed positions given the current configuration
     rmin (double): ancillary parameter
     """
@@ -115,7 +114,7 @@ def _exclusion_map_dep(i, ref, target, targeti):
 
 
 def _exclusion_map(i, ref, target, targeti):
-    """Ancillary function to determin admissible values of some position
+    """Ancillary function to determine admissible values of some position
     within some predefined values
 
     Parameters
@@ -123,12 +122,12 @@ def _exclusion_map(i, ref, target, targeti):
     i (int): index of the structure under consideration
     ref: Field that represent the topological structure of parcels
          and their standard position
-    target= array of shape (ref.V,3): current posistion of the parcels
+    target= array of shape (ref.V,3): current position of the parcels
     targeti array of shape (n,3): possible new positions for the ith item
 
     Returns
     -------
-    emap: aray of shape (n): a potential that yields the fitness
+    emap: array of shape (n): a potential that yields the fitness
           of the proposed positions given the current configuration
     rmin (double): ancillary parameter
     """
@@ -229,7 +228,7 @@ def _optim_hparcel(feature, domain, graphs, nb_parcel, lamb=1., dmax=10.,
     graphs: graph that represents the topology of the parcellation
     anat_coord: array of shape (nvox,3) space defining set of coordinates
     nb_parcel: int
-               the number of desrired parcels
+               the number of desired parcels
     lamb=1.0: parameter to weight position
               and feature impact on the algorithm
     dmax = 10: locality parameter (in the space of anat_coord)
@@ -279,7 +278,7 @@ def _optim_hparcel(feature, domain, graphs, nb_parcel, lamb=1., dmax=10.,
             Fs = feature[s]
             lac = indiv_coord[s]
             target = proto_anat.copy()
-            lseeds = np.zeros(nb_parcel, np.int)
+            lseeds = np.zeros(nb_parcel, np.int_)
             aux = np.argsort(rand(nb_parcel))
             toto = np.zeros(lac.shape[0])
             for j in range(nb_parcel):
@@ -395,7 +394,7 @@ def hparcel(domain, ldata, nb_parcel, nb_perm=0, niter=5, mu=10., dmax=10.,
     nbvox = domain.size
     nb_subj = len(ldata)
     if initial_mask is None:
-        initial_mask = np.ones((nbvox, nb_subj), np.int)
+        initial_mask = np.ones((nbvox, nb_subj), np.int_)
 
     graphs = []
     feature = []
@@ -417,7 +416,7 @@ def hparcel(domain, ldata, nb_parcel, nb_perm=0, niter=5, mu=10., dmax=10.,
         chunksize=chunksize, verbose=verbose)
 
     # write the individual labelling
-    labels = - np.ones((nbvox, nb_subj)).astype(np.int)
+    labels = - np.ones((nbvox, nb_subj)).astype(np.int_)
     for s in range(nb_subj):
         labels[initial_mask[:, s] > -1, s] = all_labels[s]
 
@@ -445,7 +444,7 @@ def perm_prfx(domain, graphs, features, nb_parcel, ldata, initial_mask=None,
     caveat: assumes that the functional dimension is 1
     """
     from ..utils.reproducibility_measures import ttest
-    # permutations for the assesment of the results
+    # permutations for the assessment of the results
     prfx0 = []
     adim = domain.coord.shape[1]
     nb_subj = len(ldata)
@@ -463,7 +462,7 @@ def perm_prfx(domain, graphs, features, nb_parcel, ldata, initial_mask=None,
         all_labels, proto_anat = _optim_hparcel(
             feature, domain, graphs, nb_parcel, lamb, dmax, niter,
             initial_mask, chunksize=chunksize)
-        labels = - np.ones((domain.size, nb_subj)).astype(np.int)
+        labels = - np.ones((domain.size, nb_subj)).astype(np.int_)
         for s in range(nb_subj):
             labels[initial_mask[:, s] > -1, s] = all_labels[s]
 
