@@ -1,27 +1,23 @@
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
-from __future__ import print_function
-from __future__ import absolute_import
 
 import numpy as np
+from nibabel import Nifti1Image, load
 
-from nibabel import load, Nifti1Image
-
-from nipy.io.nibcompat import get_header, get_affine
+from nipy.io.nibcompat import get_affine, get_header
 
 from . import discrete_domain as ddom
 
-from nipy.externals.six import string_types
 
 ##############################################################################
 # class SubDomains
 ##############################################################################
-class SubDomains(object):
+class SubDomains:
     """
     This is a class to represent multiple ROI objects, where the
     reference to a given domain is explicit.
 
-    A mutliple ROI object is a set of ROI defined on a given domain,
+    A multiple ROI object is a set of ROI defined on a given domain,
     each having its own 'region-level' characteristics (ROI features).
 
     Every voxel of the domain can have its own characteristics yet,
@@ -32,7 +28,7 @@ class SubDomains(object):
     ----------
     k : int
       Number of ROI in the SubDomains object
-    label : array of shape (domain.size), dtype=np.int
+    label : array of shape (domain.size), dtype=np.int_
       An array use to define which voxel belongs to which ROI.
       The label values greater than -1 correspond to subregions
       labelling. The labels are recomputed so as to be consecutive
@@ -56,7 +52,7 @@ class SubDomains(object):
         ----------
         domain: ROI instance
           defines the spatial context of the SubDomains
-        label: array of shape (domain.size), dtype=np.int,
+        label: array of shape (domain.size), dtype=np.int_,
           An array use to define which voxel belongs to which ROI.
           The label values greater than -1 correspond to subregions
           labelling. The labels are recomputed so as to be consecutive
@@ -76,7 +72,7 @@ class SubDomains(object):
         if np.size(label) != domain.size:
             raise ValueError('inconsistent labels and domains specification')
         self.domain = domain
-        self.label = np.reshape(label, label.size).astype(np.int)
+        self.label = np.reshape(label, label.size).astype(np.int_)
         # use continuous labels
         self.recompute_labels()
 
@@ -106,7 +102,7 @@ class SubDomains(object):
 
         Notes
         -----
-        This method must be called everytime the MROI structure is modified.
+        This method must be called every time the MROI structure is modified.
         """
         lmap = np.unique(self.label[self.label > - 1])
         for i, k in enumerate(lmap):
@@ -161,11 +157,11 @@ class SubDomains(object):
 
         """
         cp = SubDomains(self.domain, self.label.copy(), id=self.get_id())
-        for fid in self.features.keys():
+        for fid in self.features:
             f = self.get_feature(fid)
             sf = [np.array(f[k]).copy() for k in range(self.k)]
             cp.set_feature(fid, sf)
-        for fid in self.roi_features.keys():
+        for fid in self.roi_features:
             cp.set_roi_feature(fid, self.get_roi_feature(fid).copy())
         return cp
 
@@ -291,7 +287,7 @@ class SubDomains(object):
 
         """
         if fid not in self.features:
-            raise ValueError("the `%s` feature does not exist" % fid)
+            raise ValueError(f"the `{fid}` feature does not exist")
         if id is not None:
             feature = np.asarray(self.features[fid][self.select_id(id)])
         else:
@@ -323,10 +319,9 @@ class SubDomains(object):
             override = False
         # check the feature is already present if setting a single roi
         if fid not in self.features and len(data) != self.k:
-            raise ValueError("`%s` feature does not exist, create it first"
-                             % fid)
+            raise ValueError(f"`{fid}` feature does not exist, create it first")
         if fid in self.roi_features:
-            raise ValueError("a roi_feature called `%s` already exists" % fid)
+            raise ValueError(f"a roi_feature called `{fid}` already exists")
         # check we will not override anything
         if fid in self.features and not override:
             #TODO: raise a warning
@@ -408,7 +403,7 @@ class SubDomains(object):
             summary_feature = rf
 
         if assess_quality:
-            self.set_roi_feature('%s_quality' % fid, feature_quality)
+            self.set_roi_feature(f'{fid}_quality', feature_quality)
         return np.array(summary_feature)
 
     def remove_feature(self, fid):
@@ -455,7 +450,7 @@ class SubDomains(object):
                 f = self.get_roi_feature(fid)
                 for id in self.get_id():
                     res[self.select_id(id, roi=False)] = f[self.select_id(id)]
-            elif fid in self.features.keys():
+            elif fid in self.features:
                 f = self.representative_feature(fid, method=method)
                 for id in self.get_id():
                     res[self.select_id(id, roi=False)] = f[self.select_id(id)]
@@ -516,11 +511,11 @@ class SubDomains(object):
         """
         f = self.get_feature(fid)
         if ax is None:
-            import matplotlib.pylab as mp
-            mp.figure()
-            ax = mp.subplot(111)
+            import matplotlib.pyplot as plt
+            plt.figure()
+            ax = plt.subplot(111)
         ax.boxplot(f)
-        ax.set_title('ROI-level distribution for feature %s' % fid)
+        ax.set_title(f'ROI-level distribution for feature {fid}')
         ax.set_xlabel('Region index')
         ax.set_xticks(np.arange(1, self.k + 1))
         return ax
@@ -569,7 +564,7 @@ class SubDomains(object):
         if fid not in self.roi_features and len(data) != self.k:
             raise ValueError("`%s` feature does not exist, create it first")
         if fid in self.features:
-            raise ValueError("a feature called `%s` already exists" % fid)
+            raise ValueError(f"a feature called `{fid}` already exists")
 
         # modify one particular region
         if id is not None:
@@ -643,11 +638,11 @@ class SubDomains(object):
         else:
             data = -np.ones(self.label.size, dtype=np.int32)
             tmp_image = self.domain.to_image()
-            mask = tmp_image.get_data().copy().astype(bool)
+            mask = tmp_image.get_fdata().copy().astype(bool)
             if not roi:
                 # write a feature
                 if fid not in self.features:
-                    raise ValueError("`%s` feature could not be found" % fid)
+                    raise ValueError(f"`{fid}` feature could not be found")
                 for i in self.get_id():
                     data[self.select_id(i, roi=False)] = \
                         self.get_feature(fid, i)
@@ -738,7 +733,7 @@ def subdomain_from_array(labels, affine=None, nn=0):
     """
     dom = ddom.grid_domain_from_binary_array(
         np.ones(labels.shape), affine=affine, nn=nn)
-    return SubDomains(dom, labels.astype(np.int))
+    return SubDomains(dom, labels.astype(np.int_))
 
 
 def subdomain_from_image(mim, nn=18):
@@ -760,12 +755,12 @@ def subdomain_from_image(mim, nn=18):
     Only labels > -1 are considered
 
     """
-    if isinstance(mim, string_types):
+    if isinstance(mim, str):
         iim = load(mim)
     else:
         iim = mim
 
-    return subdomain_from_array(iim.get_data(), get_affine(iim), nn)
+    return subdomain_from_array(iim.get_fdata(), get_affine(iim), nn)
 
 
 def subdomain_from_position_and_image(nim, pos):
@@ -784,7 +779,7 @@ def subdomain_from_position_and_image(nim, pos):
     coord = np.array([tmp.domain.coord[tmp.label == k].mean(0)
                       for k in range(tmp.k)])
     idx = ((coord - pos) ** 2).sum(1).argmin()
-    return subdomain_from_array(nim.get_data() == idx, get_affine(nim))
+    return subdomain_from_array(nim.get_fdata() == idx, get_affine(nim))
 
 
 def subdomain_from_balls(domain, positions, radii):
