@@ -5,24 +5,21 @@ Utility functions for mutli-subjectParcellation:
 this basically uses nipy io lib to perform IO opermation
 in parcel definition processes
 """
-from __future__ import print_function
-from __future__ import absolute_import
 
-import numpy as np
 import os.path
 from warnings import warn
 
-from nibabel import load, save, Nifti1Image
+import numpy as np
+from nibabel import Nifti1Image, load, save
 
-from nipy.io.nibcompat import get_header, get_affine
 from nipy.algorithms.clustering.utils import kmeans
+from nipy.io.nibcompat import get_affine, get_header
+
+from ..mask import intersect_masks
 from .discrete_domain import grid_domain_from_image
 from .mroi import SubDomains
-from ..mask import intersect_masks
 
-from nipy.externals.six import string_types
-
-warn('Module nipy.labs.spatial_models.parcel_io' + 
+warn('Module nipy.labs.spatial_models.parcel_io' +
      'deprecated, will be removed',
      FutureWarning,
      stacklevel=2)
@@ -46,14 +43,14 @@ def mask_parcellation(mask_images, nb_parcel, threshold=0, output_image=None):
     -------
     wim: Nifti1Imagine instance,  representing the resulting parcellation
     """
-    if isinstance(mask_images, string_types):
+    if isinstance(mask_images, str):
         mask = mask_images
     elif isinstance(mask_images, Nifti1Image):
         mask = mask_images
     else:
         # mask_images should be a list
         mask_data = intersect_masks(mask_images, threshold=0) > 0
-        mask = Nifti1Image(mask_data.astype('u8'),
+        mask = Nifti1Image(mask_data.astype('u1'),
                            get_affine(load(mask_images[0])))
 
     domain = grid_domain_from_image(mask)
@@ -79,7 +76,7 @@ def parcel_input(mask_images, learning_images, ths=.5, fdim=None):
     fdim: int, optional
           if nb_feature (the dimension of the data) used in subsequent analyses
           if greater than fdim,
-          a PCA is perfomed to reduce the information in the data
+          a PCA is performed to reduce the information in the data
           Byd efault, no reduction is performed
 
     Returns
@@ -92,14 +89,14 @@ def parcel_input(mask_images, learning_images, ths=.5, fdim=None):
     nb_subj = len(learning_images)
 
     # get a group-level mask
-    if isinstance(mask_images, string_types):
+    if isinstance(mask_images, str):
         mask = mask_images
     elif isinstance(mask_images, Nifti1Image):
         mask = mask_images
     else:
         # mask_images should be a list
         grp_mask = intersect_masks(mask_images, threshold=ths) > 0
-        mask = Nifti1Image(grp_mask.astype('u8'),
+        mask = Nifti1Image(grp_mask.astype('u1'),
                            get_affine(load(mask_images[0])))
 
     # build the domain
@@ -164,7 +161,7 @@ def write_parcellation_images(Pa, template_path=None, indiv_path=None,
     if template_path is None:
         template_path = os.path.join(swd, "template_parcel.nii")
     if indiv_path is None:
-        indiv_path = [os.path.join(swd, "parcel%s.nii" % subject_id[s])
+        indiv_path = [os.path.join(swd, f"parcel{subject_id[s]}.nii")
                         for s in range(Pa.nb_subj)]
 
     # write the template image
@@ -221,7 +218,7 @@ def parcellation_based_analysis(Pa, test_images, test_id='one_sample',
                      for ti in test_images]).T
     test_data = Pa.make_feature('', np.array(test))
 
-    if test_id is not 'one_sample':
+    if test_id != 'one_sample':
         return test_data
 
     # 2. perform one-sample test
@@ -249,7 +246,7 @@ def fixed_parcellation(mask_image, betas, nbparcel, nn=6, method='ward',
     ----------
     domain/mask_image
     betas: list of paths to activation images from the subject
-    nbparcel, int : number fo desired parcels
+    nbparcel, int : number of desired parcels
     nn=6: number of nearest neighbors  to define the image topology
           (6, 18 or 26)
     method='ward': clustering method used, to be chosen among
@@ -288,7 +285,7 @@ def fixed_parcellation(mask_image, betas, nbparcel, nn=6, method='ward',
     # 1.1 the domain
     domain = grid_domain_from_image(mask_image, nn)
 
-    if method is not 'kmeans':
+    if method != 'kmeans':
         # 1.2 get the main cc of the graph
         # to remove the small connected components
         pass
@@ -308,7 +305,7 @@ def fixed_parcellation(mask_image, betas, nbparcel, nn=6, method='ward',
 
     #step 2: parcellate the data ---------------------------
 
-    if method is not 'kmeans':
+    if method != 'kmeans':
         g = field_from_coo_matrix_and_data(domain.topology, feature)
 
     if method == 'kmeans':
@@ -341,7 +338,7 @@ def fixed_parcellation(mask_image, betas, nbparcel, nn=6, method='ward',
     if fullpath is not None:
         label_image = fullpath
     elif write_dir is not None:
-        label_image = os.path.join(write_dir, "parcel_%s.nii" % method)
+        label_image = os.path.join(write_dir, f"parcel_{method}.nii")
     else:
         label_image = None
 
@@ -350,6 +347,6 @@ def fixed_parcellation(mask_image, betas, nbparcel, nn=6, method='ward',
             fid='id', roi=True, descrip='Intra-subject parcellation image')
         save(lpa_img, label_image)
         if verbose:
-            print("Wrote the parcellation images as %s" % label_image)
+            print(f"Wrote the parcellation images as {label_image}")
 
     return lpa
