@@ -17,13 +17,11 @@ Neuroimage. 2007 Mar;35(1):105-20.
 
 Bertrand Thirion, 2009-2010
 """
-from __future__ import absolute_import
 
 import numpy as np
 
 from nipy.io.nibcompat import get_affine
-from nipy.labs.spatial_models.discrete_domain import \
-    grid_domain_from_binary_array
+from nipy.labs.spatial_models.discrete_domain import grid_domain_from_binary_array
 
 # ---------------------------------------------------------
 # ----- cluster handling functions ------------------------
@@ -162,7 +160,7 @@ def get_peak_position_from_thresholded_map(stat_map, domain, threshold):
 
     # create an image to represent stat_map
     simage = domain.to_image(data=stat_map)
-    
+
     # extract the peaks
     peaks = get_3d_peaks(simage, threshold=threshold, order_th=2)
     if peaks is None:
@@ -191,7 +189,7 @@ def bootstrap_group(nsubj, ngroups):
              the indexes of the subjects in each subgroup
     """
     groupsize = nsubj
-    samples = [(groupsize * np.random.rand(groupsize)).astype(np.int)
+    samples = [(groupsize * np.random.rand(groupsize)).astype(np.int_)
                for i in range(ngroups)]
     return samples
 
@@ -440,7 +438,7 @@ def map_reproducibility(data, vardata, domain, ngroups, method='crfx',
             # randomly swap the sign of x
             x *= (2 * (np.random.rand(len(samples[i])) > 0.5) - 1)
 
-        if method is not 'crfx':
+        if method != 'crfx':
             vx = vardata[:, samples[i]]
         csize = kwargs['csize']
         threshold = kwargs['threshold']
@@ -508,9 +506,9 @@ def peak_reproducibility(data, vardata, domain, ngroups, sigma, method='crfx',
             # apply a random sign swap to x
             x *= (2 * (np.random.rand(len(samples[i])) > 0.5) - 1)
 
-        if method is not 'crfx':
+        if method != 'crfx':
             vx = vardata[:, samples[i]]
-        if method is not 'bsa':
+        if method != 'bsa':
             threshold = kwargs['threshold']
 
             if method == 'crfx':
@@ -596,9 +594,9 @@ def cluster_reproducibility(data, vardata, domain, ngroups, sigma,
             # apply a random sign swap to x
             x *= (2 * (np.random.rand(len(samples[i])) > 0.5) - 1)
 
-        if method is not 'crfx':
+        if method != 'crfx':
             vx = vardata[:, samples[i]]
-        if method is not 'bsa':
+        if method != 'bsa':
             csize = kwargs['csize']
             threshold = kwargs['threshold']
             if method == 'crfx':
@@ -664,9 +662,10 @@ def group_reproducibility_metrics(
                       results of peak-level reproducibility analysis
     """
     from nibabel import load
+
     from ..mask import intersect_masks
 
-    if ((len(variance_images) == 0) & (method is not 'crfx')):
+    if len(variance_images) == 0 and method != 'crfx':
         raise ValueError('Variance images are necessary')
 
     nsubj = len(contrast_images)
@@ -680,9 +679,9 @@ def group_reproducibility_metrics(
     group_con = []
     group_var = []
     for s in range(nsubj):
-        group_con.append(load(contrast_images[s]).get_data()[mask])
+        group_con.append(load(contrast_images[s]).get_fdata()[mask])
         if len(variance_images) > 0:
-            group_var.append(load(variance_images[s]).get_data()[mask])
+            group_var.append(load(variance_images[s]).get_fdata()[mask])
 
     group_con = np.squeeze(np.array(group_con)).T
     group_con[np.isnan(group_con)] = 0
