@@ -3,23 +3,25 @@
 """
 Convenience functions for specifying a design in the GLM
 """
-from __future__ import absolute_import
 
+import itertools
 from functools import reduce
 from operator import mul
-import itertools
 
 import numpy as np
 
-from nipy.algorithms.statistics.utils import combinations
 from nipy.algorithms.statistics.formula import formulae
 from nipy.algorithms.statistics.formula.formulae import (
-    Formula, Factor, Term, make_recarray)
-
-from .utils import (events, blocks, fourier_basis as fourier_basis_sym,
-                    convolve_functions, T)
+    Factor,
+    Formula,
+    Term,
+    make_recarray,
+)
+from nipy.algorithms.statistics.utils import combinations
 
 from .hrf import glover
+from .utils import T, blocks, convolve_functions, events
+from .utils import fourier_basis as fourier_basis_sym
 
 
 def fourier_basis(t, freq):
@@ -30,7 +32,7 @@ def fourier_basis(t, freq):
     Parameters
     ----------
     t : np.ndarray
-        An array of np.float values at which to evaluate
+        An array of np.float64 values at which to evaluate
         the design. Common examples would be the acquisition
         times of an fMRI image.
     freq : sequence of float
@@ -92,7 +94,7 @@ def _build_formula_contrasts(spec, fields, order):
 
     Parameters
     ----------
-    spec : stuctured array
+    spec : structured array
         Structured array containing at least fields listed in `fields`.
     fields : sequence of str
         Sequence of field names containing names of factors.
@@ -142,7 +144,7 @@ def event_design(event_spec, t, order=2, hrfs=(glover,),
        model.  If there is no field other than time, add a single-level
        placeholder event type ``_event_``.
     t : np.ndarray
-       An array of np.float values at which to evaluate the design. Common
+       An array of np.float64 values at which to evaluate the design. Common
        examples would be the acquisition times of an fMRI image.
     order : int, optional
        The highest order interaction to be considered in constructing
@@ -221,7 +223,7 @@ def block_design(block_spec, t, order=2, hrfs=(glover,),
        than 'start' and 'end', add a single-level placeholder block type
        ``_block_``.
     t : np.ndarray
-       An array of np.float values at which to evaluate the design. Common
+       An array of np.float64 values at which to evaluate the design. Common
        examples would be the acquisition times of an fMRI image.
     order : int, optional
        The highest order interaction to be considered in constructing the
@@ -274,9 +276,9 @@ def block_design(block_spec, t, order=2, hrfs=(glover,),
     e_dtype = e_formula.dtype
 
     # Now construct the design in time space
-    block_times = np.array([(s,e) for s, e in zip(block_spec['start'], 
-                                                  block_spec['end'])])
-    convolution_interval = (block_times.min() - convolution_padding, 
+    block_times = np.array(list(zip(block_spec['start'],
+                                                  block_spec['end'])))
+    convolution_interval = (block_times.min() - convolution_padding,
                             block_times.max() + convolution_padding)
 
     t_terms = []
@@ -284,7 +286,7 @@ def block_design(block_spec, t, order=2, hrfs=(glover,),
     for l, h in enumerate(hrfs):
         for n in e_dtype.names:
             B = blocks(block_times, amplitudes=e_X[n])
-            term = convolve_functions(B, h(T), 
+            term = convolve_functions(B, h(T),
                                       convolution_interval,
                                       hrf_interval,
                                       convolution_dt)
@@ -350,7 +352,7 @@ def stack2designs(old_X, new_X, old_contrasts={}, new_contrasts={}):
 
     X = np.hstack([old_X, new_X])
 
-    if set(old_contrasts.keys()).intersection(new_contrasts.keys()) != set([]):
+    if set(old_contrasts.keys()).intersection(new_contrasts.keys()) != set():
         raise ValueError('old and new contrasts must have different names')
 
     for n, c in old_contrasts.items():
@@ -393,14 +395,14 @@ def stack_contrasts(contrasts, name, keys):
     -------
     None
     """
-    if name in contrasts.keys():
-        raise ValueError('contrast "%s" already exists' % name)
+    if name in contrasts:
+        raise ValueError(f'contrast "{name}" already exists')
 
     contrasts[name] = np.vstack([contrasts[k] for k in keys])
 
 
 def stack_designs(*pairs):
-    """ Stack a sequence of design / contrast dictionary pairs
+    r""" Stack a sequence of design / contrast dictionary pairs
 
     Uses multiple calls to :func:`stack2designs`
 
@@ -476,7 +478,7 @@ def block_amplitudes(name, block_spec, t, hrfs=(glover,),
        A recarray having fields ``start, end, amplitude``, or a 2D ndarray /
        array-like with three columns corresponding to start, end, amplitude.
     t : np.ndarray
-       An array of np.float values at which to evaluate the design. Common
+       An array of np.float64 values at which to evaluate the design. Common
        examples would be the acquisition times of an fMRI image.
     hrfs : sequence, optional
        A sequence of (symbolic) HRFs that will be convolved with each block.
@@ -523,7 +525,7 @@ def block_amplitudes(name, block_spec, t, hrfs=(glover,),
                                           convolution_dt))
         contrast = np.zeros(n_hrfs)
         contrast[hrf_no] = 1
-        c_t['{0}_{1:d}'.format(name, hrf_no)] = contrast
+        c_t[f'{name}_{hrf_no:d}'] = contrast
     t_formula = Formula(t_terms)
     tval = make_recarray(t, ['t'])
     X_t = t_formula.design(tval, return_float=True)
