@@ -3,19 +3,13 @@
 """ Testing fmristat hrf module
 
 """
-from __future__ import absolute_import
 
 import numpy as np
 
-from ...utils import T, lambdify_t
 from ... import hrf
+from ...utils import T, lambdify_t
 from ..hrf import spectral_decomposition
 
-from nose.tools import assert_true, assert_false, \
-        assert_equal, assert_raises
-
-from numpy.testing import assert_array_equal, assert_array_almost_equal
-
 
 def test_spectral_decomposition():
     # mainly to test that the second sign follows the first
@@ -24,7 +18,7 @@ def test_spectral_decomposition():
     t = np.linspace(-15,50,3251)
     vals = [val_maker(t) for val_maker in val_makers]
     ind = np.argmax(vals[1])
-    assert_true(vals[0][ind] > 0)
+    assert vals[0][ind] > 0
     # test that we can get several components
     spectral, approx = spectral_decomposition(hrf.glover, ncomp=5)
-    assert_equal(len(spectral), 5)
+    assert len(spectral) == 5
