@@ -6,13 +6,14 @@ Test the design_matrix utilities.
 Note that the tests just look whether the data produced has correct dimension,
 not whether it is exact.
 """
-from __future__ import absolute_import
 
 import numpy as np
 
-from ..experimental_paradigm import (EventRelatedParadigm, BlockParadigm,
-                                     load_paradigm_from_csv_file)
-from nose.tools import assert_true
+from ..experimental_paradigm import (
+    BlockParadigm,
+    EventRelatedParadigm,
+    load_paradigm_from_csv_file,
+)
 
 
 def basic_paradigm():
@@ -83,9 +84,4 @@ def test_paradigm_with_int_condition_ids():
     paradigm1 = basic_paradigm()
     conditions = [0, 0, 0, 1, 1, 1, 2, 2, 2]
     paradigm2 = EventRelatedParadigm(conditions, paradigm1.onset)
-    assert_true((paradigm2.con_id == np.array(conditions).astype('str')).all())
-
-
-if __name__ == "__main__":
-    import nose
-    nose.run(argv=['', __file__])
+    assert (paradigm2.con_id == np.array(conditions).astype('str')).all()
